c      program baytap
c
c     $Id: baytap08.f,v 1.12 2016/03/23 16:12:54 agnew Exp agnew $
c     $Log: baytap08.f,v $
c     Revision 1.12  2016/03/23 16:12:54  agnew
c     Changed monitr from 0 to 1 (line 1773) and fmtd to fmti (1946) to
c     match new compiler requirements.
c
c     Revision 1.11  2014/03/05 23:32:18  agnew
c     fixed misplaced continuation flags on lines 913, 5301, 5303
c
c     Revision 1.10  2013/04/17 04:23:19  agnew
c     fixed mapping so igrp=1 maps to -2, instead of igrp=1 and 2 mapping to
c     -1 (see line   map 1-8 to -2, -1, 1 to 6)
c
c     Revision 1.9  2009/01/31 22:38:19  agnew
c     fixed line 1064 (reading names of more than 3 files)
c     (line 1664, actually)
c
c     Revision 1.8  2008/06/18 20:12:23  agnew
c     Added reading of sinusoids (new style)
c     additional cosmetic changes
c
c     Revision 1.7  2008/06/17 21:39:04  agnew
c     Shrank executable by removing incore from data statement.
c     All times for input and output are now y-m-d-h-m-s
c     All frequencies in output are now in cycle/day
c     Replaced more labels with enddo's; general reformatting.
c
c     Revision 1.6  2008/06/04 21:48:42  agnew
c     changed spectrum values to dB
c
c     Revision 1.5  2008/06/04 18:25:36  agnew
c     Modifications to output format, many do-loops changed to enddo
c
c     Revision 1.4  2008/06/03 17:40:34  agnew
c     Substantial modification to allow reading of free-format input, with
c     parameters being read from control file, and read entirely with
c     keyword= syntax. Added time/date to output series (needs work).
c     Many do loops changed to enddo; many format statements moved.
c     Some changes to format in results file.
c
c     Revision 1.3  2008/05/28 01:27:57  agnew
c     Modified to read data from std in, control from command line,
c     results to command line, aux files from command line (not checked)
c     and decomposed series to std out. Tested with no aux files, matched
c     version 1.1
c
c     Revision 1.2  2008/05/27 19:40:22  agnew
c     No substantive changes: mostly moving format statements,
c      some re-ordering of statements, changes of numbered do-loops
c
c     Revision 1.1  2008/05/26 16:13:49  agnew
c     Initial revision: replaced file reads by blockdata, causing
c      slight changes in some numerical values output
c
c
c        designed and coded by
c
c        Makio Ishiguro
c           The Institute of Statistical Mathematics,
c           4-6-7 Minami-Azabu, Minato-Ku, Tokyo, 106-8569, Japan.
c           Tel. 03-3446-1501           Fax 03-3446-1695
c           e-mail  ishiguro@ism.ac.jp
c
c      and
c
c        Yoshiaki Tamura
c           National Astronomical Observatory, Mizusawa,
c           2-12 Hoshigaoka-cho, Mizusawa-shi, Iwate-ken, 023-0861, Japan.
c           Tel. 0197-22-7131           Fax 0197-22-3410
c           e-mail  tamura@miz.nao.ac.jp
c
c      with revisions (2008) in I/O and program layout by
c        Duncan Carr Agnew
c           Institute of Geophysics and Planetary Physics 0225
c           Scripps Institution of Oceanography
c           University of California
c           La Jolla   CA  92093-0224  USA
c           Tel. 1-858-534-2590
c           email   dagnew@ucsd.edu
c
c     This program decomposes a time series y into the form
c
c     y(i) = tdc(i)+t(i)+s(i)+r(i)+i(i)
c
c     where  tdc=tidal component  t=smooth trend  s=step
c            r=response to the auxiliary phenomena
c            i=irregular (residual)
c
c     This program can be used for data up to length
c     90000, that is hourly sampled data of more than ten years.
c
c     The procedure is based on a Bayesian model and its
c     performance is controlled by the selection of the parameters of
c     the prior distribution.  The construction of the basic model is
c     discussed in the following papers:
c
c     ABIC and statistics:
c       Akaike, H. (1979) Likelihood and the Bayes procedure. a paper
c         presented at the International Meeting on Bayesian Statistics,
c         May 26 - June 2, 1979, Valencia, Spain. to be published in
c         Trabajos de Estadistica.
c       Akaike, H. and Ishiguro, M. (1979) Trend estimation with
c         missing observations.  a paper presented at the International
c         Conference in Statistics in Tokyo, November 28 - 30, 1979,
c         Tokyo.
c       Ishiguro, M. and Akaike, H. (1980) A Bayesian approach to
c         the trading-day adjustment of monthly data.  a paper
c         presented at the International Time Series Meeting,
c         August 14 - 15, 1980, Houston, U.S.A.
c       Ishiguro, m. (1981) Computationally efficient implimentation
c         of a Bayesian seasonal adjustment procedure, Res. Memo. 204,
c         Institute of Statistical Mathematics, Tokyo
c
c     Tidal analysis and program:
c       Ishiguro, M., Akaike, H., Ooe, M. and Nakai, S. (1981)
c         A Bayesian approach to the analysis of earth tides.
c         Proc. 9th Int. Sympos. on Earth Tides, 283-292,
c         held in Aug. 17-22, 1981, in New York.
c       Ishiguro, M. (1981) A Bayesian approach to the analysis of
c         the data of crustal movements, Journal of the Geodetic
c         Society of Japan, 27, 256-262.
c       Ishiguro, M., Sato, T, Tamura, Y. and Ooe, M. (1984)
c         Tidal data analysis  --an introduction to BAYTAP--,
c         Proc. Institute of Statistical Mathematics, 32, 71-85.
c       Ishiguro, M. and Tamura, Y. (1985) BAYTAP-G in TIMSAC 84,
c         Computer Science Monographs, 22, 56-117.
c       Tamura, Y. (1985/1999) BAYTAP-G user's manual.
c       Tamura, Y., Sato, T., Ooe, M. and Ishiguro, M. (1991)
c         A procedure for tidal analysis with a Bayesian information
c         criterion, Geophysical Journal International, 104, 507-516.
c
c     Response method:
c       Munk, W. M. and Cartwright, D. E. (1966) Tidal spectroscopy and
c         prediction, Phil. Trans. Roy. Soc. London, A, 259, 533-581.
c
c     Potential:
c       Cartwright, D. E. and Tayler, R. j. (1971) New computations of
c         the tide-generating potential, Geophys. J. Roy. Astron. Soc.,
c         23, 45-74.
c       Cartwright, D. E. and Edden, A. C. (1973) Corrected tables of
c         tidal harmonics, Geophys. J. Roy. Astron. Soc., 33,
c         253-264.
c       Tamura, Y. (1987) A harmonic development of the tide-generating
c         potential, Marees Terrestres Bulletin d'Information (BIM), 99,
c         6813-6855.
c
c
c     The prior distribution controls the smoothness
c     of the trend by assuming a homogeneous gaussian
c     distribution of difference of component. the
c     choice of the variance of the homogeneous gaussian distribution is
c     realized by maximizing the log likelihood of the Bayesian model.
c     for the purpose of comparison of models with different parameters
c     the criterion ABIC is defined by
c
c          ABIC = - 2 * log( maximum likelihood of the model )
c                 + 2 * ( number of estimated parameters )
c
c     smaller value of ABIC means better fit of the model.
c     the value of the variance of the prior distribution which
c     minimizes ABIC within a prescribed finite set of possible values
c     is used to produce the final output for a particular choice of
c     other parameters.
c     for the comparison of the overall performances of various
c     models the averaged ABIC (avABIC) is useful.
c
c     this program requires the following parameters.  without further
c     specification by the program user, they are respectively set equal
c     to the values given in the parentheses at the ends of their
c     descriptions.
c
c     parameters:
c       span:   number of data to be processed at one time (0)
c               span is automatically selected when span=0
c       shift:  number of data to be shifted
c               shift is automatically selected when span=0
c               to define the new span of data (720)
c       order:  order of differencing of trend (2)
c       ipoten: selection of reference potential (2)
c               potential by cte when ipoten=1
c               potential by tamura when ipoten=2
c       p4flag: flag for 4th order potntial (1)
c               p4flag=1 is valid when ipoten=2
c       iaug:   number of auxiliary datasets (0)
c       lagp:   maximum lag number (3)
c       lagint: lag interval (1)
c       dmin:   lower limit of hyperparameter d (0.25)
c               4*dmin is used for a initial value of d search
c       weight: controls the adaptivity of the inpulse response
c               more data-adaptive with smaller weight (1.0)
c       maxjmp: maximum count of the step within a span (5)
c       lpout:  lp output level (0), lpout=1 is valid when span>0
c       filout: falg for file output through io unit no 16
c               filout=1 is valid when span>0
c       prepro: flag for interpolation (0)
c               prepro=1, 2 or 3 is valid when lpout=1 and span>0
c
c
c     to modify the parameters follow the following example:
c
c       if the user wants to set iaug=1,weight=0.5 and so on,
c       place the cards which contain the following
c       three types of statements on top of the input data (punch one
c       space at the first column of each card) :
c  &param  (on the first card)
c  iaug=1, weight=0.5, and so on, (on the second and later cards)
c  &end  (on the last card)
c     note the comma at the end of each parameter specification.
c
c     input data:
c
c     the following data set should be fed through the card reader
c     in the formats shown in the parentheses.
c
c
c     kind
c       1  gravity tide
c       2  tilt tide n-s
c       3  tilt tide e-w  (or  kind=2, az=90)
c       4  ns strain
c       5  ew strain      (or  kind=4, az=90)
c       6  ne strain      (or  kind=4, az=45)
c       7  for strain data (none dimensional:potential/g/r)
c       8  ocean tide
c ordering of parameters
c       cos part of group 1
c       sin part of group 1
c       cos part of group 2
c       sin part of group 2
c         and so on.
c
c     numerical outputs:
c       trend:  estimated trend
c
c     graphical outputs:
c       original data
c       trend + step
c       irregular
c
c
c     structure
c
c     baytap :->getcmd
c            :->verstr
c            :->prmset
c            :->namels
c            :->prmchk
c            :->tjul
c            :->setgrp
c            :->tbread
c            :->setmwv
c            :->datar2 :->fnormg
c            :         :->tjul
c            :         :->ystpck
c            :         :->datar  :->update
c            :         :->datar3
c            :
c            :->geogr1
c            :->sphas1
c            :->geogr2
c            :->sphas2
c            :->setcos
c            :->tide01
c            :->tide02
c            :->rtitle
c            :->calend
c            :->subsea :->setx   :->yreado,yreadt,yreada
c            :         :         :->hushld
c            :         :         :->setd
c            :         :         :->init
c            :         :         :->exqrcn
c            :         :         :->solve
c            :         :
c            :         :->solve
c            :         :->decode :->yreado,yreadt,yreada
c            :                   :->copy
c            :->ystpck
c            :->frqrsp :->dsp3
c            :->copy
c            :->otlchk
c            :->sautco :->smeadl :->sumf
c            :         :->crosco
c            :         :->cornom
c            :
c            :->sicp2
c            :->snrasp :->fouger
c            :         :->subvcp
c            :         :->dsp3
c            :
c            :->graph3 :->update
c            :         :->kando  :->tjul
c            :
c            :->kando  :->tjul
c
      implicit double precision (a-h,o-z)
c
c     parameter statements in subroutines should be modified
c     consistently with main program.
c
c    for 1mb memory
cc    parameter ( maxh2 =  30000,  maxdc =  2500,  maxout = 1000 )
cc    parameter ( maxgrp = 15,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  500 )
cc    parameter ( maxaux = 1 )
c    for 2mb memory
cc    parameter ( maxh2 =  90000,  maxdc = 10000,  maxout = 3000 )
cc    parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff = 1250 )
cc    parameter ( maxaux = 3 )
c    for 3mb memory ( 3 month data with drift estimation(shift>0) )
cc    parameter ( maxh2 = 200000,  maxdc = 20000,  maxout = 3000 )
cc    parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff = 1250 )
cc    parameter ( maxaux = 3 )
c    for 9mb memory (1 year data with drift estimation(shift>0) )
cc    parameter ( maxh2 = 600000,  maxdc = 30000,  maxout = 9000 )
cc    parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff = 4500 )
cc    parameter ( maxaux = 3 )
c    for 15mb memory (3 year data with drift estimation(shift>0) )
c                    (with file i/o)
cc    parameter ( maxh2 = 1300000,  maxdc = 80000,  maxout = 26000 )
cc    parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff = 4500 )
cc    parameter ( maxaux = 3 )
c    for 21mb memory (3 year data with drift estimation(shift>0) )
c                    (without file i/o)
cc    parameter ( maxh2 = 1500000,  maxdc = 80000,  maxout = 26000 )
cc    parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( maxaux = 3 )
c    for 34mb memory (4 year data with drift estimation(shift>0) )
c                    (without file i/o)
cc    parameter ( maxh2 = 2600000,  maxdc = 110000,  maxout = 36000 )
cc    parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff = 18000 )
cc    parameter ( maxaux = 3 )
c ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c    for 93mb memory (11.4 year (99999 hours) data
c                                 with drift estimation(shift>0) )
c                    (without file i/o)
      parameter ( maxh2 = 7500000,  maxdc = 320000,  maxout =100000 )
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
c ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
c
      parameter ( maxunk = 100 )
      parameter ( maxop2 = maxout + maxunk )
      parameter ( maxclb = 100 )
      parameter ( mxlsta = 50,  mxlstb = 100,  mxotl = 20 )
      parameter ( maxfle = maxaux + 2 )
c
c
      integer    order, span, shift, filout, spectw, prepro, s1wave
      integer    paglen, p4flag, rsperr
      integer    zerorm
      double precision  irreg
c
c arrays for observed tidal and auxiliary data
c
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
c
c arrary for theoretical tides
c
      real       yt(lbuff,2,maxgr2)
c
      dimension  h2(maxh2), dc(maxdc)
      dimension  trend(maxout), data(maxout), irreg(maxout),
     *           tidal(maxop2), respns(maxop2), err(maxop2)
      dimension  amp(maxgrp), phase(maxgrp)
      dimension  center(maxgrp), fcr(maxgrp), fci(maxgrp), cntr(maxgrp)
      dimension  ftrn(10), ftrnbk(10), respc(maxunk)
      dimension  lsmry(3,mxlstb),listir(mxotl),listtr(mxotl),rat(maxfle)
      dimension  jlist(mxlsta), qjump(mxlsta), qqjump(mxlstb)
      dimension  auxmen(maxaux),auxcur(maxaux)
c
      dimension  autco(101), tautco(101)
      dimension  ig1r(22), ig2r(22), fcrr(11), fcri(11)
      dimension  comg(10), comg0(10), tcos(10)
c
      character     mark(4)
      character*5   version
      character*8   pgname
      character*24  dates
      character*39  obuf1
      character*41  obuf2
      character*40  cstnam, cinstr(10), cunit, cassoc(maxaux)
      character*60  who
      character*72  chrbuf
      character*80  ctitle(10)
c
c
      common          h2, dc, trend, data, irreg, tidal, respns, err
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /idata/  order,lagdbl,lagp,njump,span,lag,
     *                ncoef,ith,ithp1,lagint,ifcr
      common /rdata/  weight,dmin,maxitr
      common /lpcnt/  lpout
      common /jstut/  timsys
      common /stngrp/ ig1(36),ig2(36),ngroup,imwave(36)
      common /stngrc/ symbol(36)
      common /vernam/ pgname, version, who
      common /validd/ numuse, maxjmp
      common /inform/ iformt, netalt, etalt(maxclb), tjet(maxclb)
      common /bufota/ yo, yt, ya, incore
      common /prstep/ step00
      common /phase0/ phcorr(4,4)
      common /savews/ ws000(919), ampc0(919), difc0(919), con00(919),
     *                            amps0(919), difs0(919)
      common /dtdmut/ tdmut(130)
      common /auxil/  auxmen,naux
      common/backcom/iback
c
      data  ig1r /   1, 66, 92,114,117,124,127,138,140,147,169,
     *               1,144,202,250,257,267,271,289,293,306,346 /
      data  ig2r /  65, 91,113,116,123,126,137,139,146,168,205,
     *             143,201,249,256,266,270,288,292,305,345,450 /
c
      data ddmin/1.0d0/,nfile/29/
c
c   get file names off command line
c
      call getcmd
c
c     preset parameters
c
      call prmset( ith, order, span, shift, rlim, lpout, filout,
     *             spectw, prepro, weight, iaug, lagp, lagint, maxjmp,
     *             kind, az, dmin, timsys, ifcr, qval, maxitr,
     *             icetgr, s1wave, paglen, ipoten, p4flag, lovenm,
     *             rsperr, sigma1, sigma2, zerorm, nsine,
     *             igrp,ja,jb,jc,hr,jmin,jsec,ndata,delt,
     *             slat,slong,sh,ge,iformt)
c
c     parameter input and check
c
      call namels( ith, order, span, shift, rlim, lpout, filout,
     *             spectw, prepro, weight, iaug, lagp, lagint, maxjmp,
     *             kind, az, dmin, timsys, ifcr, qval, maxitr,
     *             icetgr, s1wave, paglen, ipoten, p4flag, lovenm,
     *             rsperr, sigma1, sigma2, zerorm, nsine,
     *             igrp,ja,jb,jc,hr,jmin,jsec,ndata,delt,
     *             slat,slong,sh,ge,iformt)
c
c number of aux files is from command line
c
      iaug=naux
c
c     parameter check
c
      call prmchk( ith, order, span, shift, rlim, lpout, filout,
     *             spectw, prepro, weight, iaug, lagp, lagint, maxjmp,
     *             kind, az, dmin, timsys, ifcr, qval, maxitr,
     *             icetgr, s1wave, paglen, ipoten, p4flag, lovenm,
     *             rsperr, sigma1, sigma2, zerorm, nsine,
     *             igrp,ja,jb,jc,hr,jmin,jsec,ndata,delt,
     *             slat,slong,sh,ge,iformt)
c
c     header printout
c
      call verstr
      call fdate(dates)
      nf0 = nfile + 1
      nf1 = nfile + maxfle
      write(8, 100) pgname, version, who, dates
  100 format(' Analysis using ',a8,', Version ',a5,' which is ',/,
     1 '  from ',a60,/,'  and which was run on ',a25)
      write(8, 102) maxh2, maxdc, maxout, maxgrp, maxaux, lbuff, maxunk
  102 format(/,
     * '   Arrays dimensioned:',//,
     * '    maxh2  =',i9,' maxdc  =',i9,' maxout =',i9,' maxgrp =',i9,/,
     * '    maxaux =',i9,' lbuff  =',i9,' maxunk =',i9)
c
c
c
      if( ipoten.eq.1 )  then
         iwnd = 205
         iwns = 360
         iwnt = 377
      else if( ipoten.eq.2 )  then
         iwnd = 450
         iwns = 827
         iwnt = 909
      else
         write(8,405)
  405    format(/' ERROR     illegal ipoten')
         stop
      endif
c
c
      if(iback.eq.1) then
         read(7,410) ja,jb,jc,hr,ndata,delt
  410    format(3i5,f5.0,i5,f10.0)
      endif
      ja = mod( ja, 1900 )
c
c
c     allocation of working area
c
      incore = 0
      if( ndata.le.2*lbuff )  incore = 1
      if( incore .ne. 1 )  then
         write(8, 104) nf0,nf1
  104    format('    scratch files ',i3,' to',i3)
         open( 30, status='scratch', form='unformatted' )
         open( 31, status='scratch', form='unformatted' )
         if( iaug.ge.1 )
     *      open( 32, status='scratch', form='unformatted' )
         if( iaug.ge.2 )
     *      open( 33, status='scratch', form='unformatted' )
         if( iaug.ge.3 )
     *      open( 34, status='scratch', form='unformatted' )
      endif
      if(iback.eq.0) then
C         write(8,700)  span,   ith,    shift,  ipoten, lpout,  p4flag,
C     *                 filout, s1wave, maxjmp, icetgr, order,  ifcr,
C     *                 weight, qval,   iaug,   rlim,   lagp,   maxitr,
C     *                 lagint, prepro, dmin,   paglen, timsys, spectw
C  700    format(/,
C     *'  **********      parameters  are         **********'/
C     *'     span   =',i9,   10x, 'ith    =',i9/
C     *'     shift  =',i9,   10x, 'ipoten =',i9/
C     *'     lpout  =',i9,   10x, 'p4flag =',i9/
C     *'     filout =',i9,   10x, 's1wave =',i9/
C     *'     maxjmp =',i9,   10x, 'icetgr =',i9/
C     *'     order  =',i9,   10x, 'ifcr   =',i9/
C     *'     weight =',f9.3, 10x, 'qval   =',f9.1/
C     *'     iaug   =',i9,   10x, 'rlim   =',f9.1/
C     *'     lagp   =',i9,   10x, 'maxitr =',i9/
C     *'     lagint =',i9,   10x, 'prepro =',i9/
C     *'     dmin   =',f9.3, 10x, 'paglen =',i9/
C     *'     timsys =',f9.1, 10x, 'spectw =',i9   )
         if( kind.eq.3 )  az = 90.d0
         if( kind.eq.5 )  az = 90.d0
         if( kind.eq.6 )  az = 45.d0
         write(8,700) span, shift,  dmin,   igrp,  rlim,  kind,    az,
     1                lagp,  iaug,lagint, iformt,filout, lpout,spectw,
     2              paglen,weight,maxjmp, timsys,   ith,ipoten,maxitr,
     3               order, ifcr,   qval, s1wave,p4flag,icetgr,
     4              prepro,lovenm
 700     format(/,'   Parameters have been set to:',//,
     1 '    span   ',i9,' shift  ',i9,' dmin   ',f9.3,' igrp  ',i4,/,
     2 '    rlim   ',f9.1,' kind   ',i9,' az     ',f9.1,/,
     3 '    lagp   ',i9,' iaug   ',i9,' lagint ',i9,/,
     4 '    inform ',i9,' filout ',i9,' lpout  ',i9,//,
     5 '    spectw ',i9,' paglen ',i9,' weight ',f9.3,' maxjmp',i4,/,
     6 '    timsys ',f9.1,' ith    ',i9,' ipoten ',i9,' maxitr',i4,/,
     7 '    order  ',i9,' ifcr   ',i9,' qval   ',f9.1,' s1wave',i4,/,
     8 '    p4flag ',i9,' icetgr ',i9,' prepro ',i9,  ' lovenm',i4,/,
     9 '    nsine  ',i9)
             write(8,725)  sigma1, sigma2, zerorm
  725        format(/'   Data rejection settings:',//,
     *   '    sigma1 =',1pd9.2,'  sigma2 =',1pd9.2,'  zerorm =',i5 )
      endif
c
c  read cosines (if any) and grouping specification
c
      ngroup=0
      ncosgr=0
      ig1(1)=1
      if(iback.eq.0) then
        ncosgr=nsine
        if(ncosgr.ge.1) then
          do kk=1,ncosgr
             read(7,444) comg(kk),iyy,imm,idd,kh,km,ks,comg0(kk)
  444        format(d15.10,i4,5i3,d15.10)
             hhh=kh+km/60.d0+ks/3600.d0
             tcos(kk) = tjul(iyy,imm,idd,hhh)
             comg(kk) = 15.d0*comg(kk)
          enddo
        endif
c  map 1-8 to -2, -1, 1 to 6
        ig2i=igrp-2
        if(ig2i.le.0) ig2i=ig2i-1
        if(igrp.eq.0) ig2i=0
      endif
c
c  backwards-compatible parsing of cosines and other entries
c
      if(iback.eq.1) then
        do i = 1, min0( maxgrp+1, 36 )
           do l = 1, 72
              chrbuf(l:l) = ' '
           enddo
           read(7,415,err=414)  (chrbuf(l:l),l=1,72)
  415      format(72a1)
  414      if(chrbuf(1:3).eq.'cos') go to 436
           if(chrbuf(1:3).eq.'COS') go to 436
           read(chrbuf,420)  ig2i, symbol(i)
  420      format(i5,2x,a8)
           if( ig2i.le.6 .or. ig2i.gt.iwnt )  go to 440
           ig2(i)   = ig2i
           ig1(i+1) = ig2i+1
           ngroup = ngroup+1
           if( ig2i.gt.iwnt .or. ig2i.le.ig1(i) )  then
              write(8,425)   i, ig2i
  425         format(/' ERROR invalid grouping     i =',i3,
     *              '      wave no.=', i8)
              stop
           endif
        enddo
        write(8,435)
  435   format(/' ERROR       too many groups')
        stop
  436   if(chrbuf(1:5).eq.'cos  '.or.chrbuf(1:5).eq.'COS  ' ) then
           ncosgr = ncosgr + 1
           if( ncosgr.gt.10 )  write(8,435)
           if( ncosgr.gt.10 )  stop
           read(chrbuf,437)  comg(ncosgr), iyy,imm,idd,hhh,
     1         comg0(ncosgr)
  437      format(5x,d15.8,3i5,f5.1,d15.8)
           tcos(ncosgr) = tjul(iyy,imm,idd,hhh)
        endif
        do l = 1, 72
          chrbuf(l:l) = ' '
        enddo
        read(7,415,err=454)  (chrbuf(l:l),l=1,72)
  454   if( chrbuf(1:3) .eq. 'cos' )  go to 436
        read(chrbuf,438)  ig2i
  438   format(i5)
  440   continue
      endif
      if( ngroup.eq.0 )  then
         obslen = dble(span)*delt/24.d0
         if( span .eq.0 )  obslen = dble( min0(744,ndata) )*delt/24.d0
         if( shift.eq.0 )  obslen = dble( ndata )*delt/24.d0
         call setgrp( obslen, ig2i, icetgr, ipoten )
      endif
      call tbread( ipoten )
      call setmwv( ipoten )
c
      if( ith.eq.0 )  then
         ngroup = 0
         ifcr   = 0
      endif
c
c     ngroup : number of tidal groups
c     ncosgr : number of cosine waves
c     
      nnngrp = ngroup + ncosgr
      if( nnngrp .gt. maxgrp )  write(8,435)
      if( nnngrp .gt. maxgrp )  stop
c
c
      call datar2(rat,h2,0,ndata,rlim,ja,jb,jc,hr,delt,nfile,
     *            slat,slong,sh,ge, kind,az, zerorm)
c
      if( kind.eq.3 )  az = 90.d0
      if( kind.eq.5 )  az = 90.d0
      if( kind.eq.6 )  az = 45.d0
c
      if(iback.eq.1) then
         write(8,700) span, shift,  dmin,   igrp,  rlim,  kind,    az,
     1                lagp,  iaug,lagint, iformt,filout, lpout,spectw,
     2              paglen,weight,maxjmp, timsys,   ith,ipoten,maxitr,
     3               order, ifcr,   qval, s1wave,p4flag,icetgr,
     4              prepro,lovnm
C         write(8,700)  span,   ith,    shift,  ipoten, lpout,  p4flag,
C     *              filout, s1wave, maxjmp, icetgr, order,  ifcr,
C     *              weight, qval,   iaug,   rlim,   lagp,   maxitr,
C     *              lagint, prepro, dmin,   paglen, timsys, spectw
C         write(8,710)  kind, lovenm
C         if( kind.ge.2 .and. kind.le.6 )  write(8,720)  az
         write(8,725)  sigma1, sigma2, zerorm
      endif
      call htohms(hr,ih,imin,isec)
      write(8,730)  1900+ja, jb, jc, ih, imin,isec,
     1    nint(3600*delt),ndata
  730 format(/' Analysis start time ',i4,'-',i2.2,'-',i2.2,'T',
     1 i2.2,':',i2.2,':',i2.2,'.  Interval',i6,' s, with',/,49x,
     2 i10,' terms',/)
c
      deg = delt
      i61 = 60*spectw + 1
      if(i61.lt. 61)  i61 =  61
      if(i61.gt.361)  i61 = 361
c
      if( s1wave.eq.1 )  then
         if( ipoten.eq.1 )  then
            avc(125) = 15.00000000d0
            amc(124) =  0.d0
ccc         amc(125) = -0.00416d0
            amc(126) =  0.d0
            idn(125,6) = 0
         else if( ipoten.eq.2 )  then
            avc(269) = 15.00000000d0
            amc(267) =  0.d0
            amc(268) =  0.d0
ccc         amc(269) = -0.004145d0
            amc(270) =  0.d0
            idn(269,6) = 0
         endif
      endif
c
c                                        a
c     resonance  =  1  +  --------------------------------
c                          omg - ( omg0 + i * omg0 / 2q )
c
c
      omega0 = 15.0737d0
      q1 = 0.5d0/qval
      if( ifcr.eq.1 )  then
         do n = 1, 11
            if( ipoten.eq.1 )  then
               ng1r = ig1r(n)
               ng2r = ig2r(n)
            else if( ipoten.eq.2 )  then
               ng1r = ig1r(n+11)
               ng2r = ig2r(n+11)
            endif
            sum1 = 0.d0
            sum  = 0.d0
            do i = ng1r, ng2r
               tem  = dabs( amc(i) )
               sum  = sum  + tem
               sum1 = sum1 + avc(i)*tem
            enddo
            centf = sum1/sum
            den = centf/omega0
            dnu = den - 1.d0
            den = dnu**2 + q1**2
            fcrr(n) = dnu/den
            fcri(n) = q1/den
         enddo
      endif
c
c
      do n = 1, ngroup
         ng1  = ig1(n)
         ng2  = ig2(n)
         sum1 = 0.d0
         sum  = 0.d0
         do i = ng1, ng2
            tem  = dabs( amc(i) )
            sum  = sum  + tem
            sum1 = sum1 + avc(i)*tem
         enddo
         center(n) = sum1/sum
         den = center(n)/omega0
         dnu = den - 1.d0
         den = dnu**2 + q1**2
         fcr(n) = dnu/den
         fci(n) = q1/den
         if( center(n).gt.20.d0 )  then
            fcr(n) = 0.d0
            fci(n) = 0.d0
         endif
      enddo
      do n = 1, ncosgr
         center(n+ngroup) = comg(n)
         fcr(n+ngroup) = 0.d0
         fci(n+ngroup) = 0.d0
      enddo
c
      do i = 1, ngroup-1
         if( center(i+1) - center(i) .gt. 8.d0 )  then
            cntr(i) = 0.05d0
         else
            cntr(i) = 1.d0
         endif
      enddo
      do i = max0(ngroup,1), nnngrp
         cntr(i) = 0.001d0
      enddo
c
c
      if( shift .eq. 0 )     span = min0( 744, ndata )
      if( ndata .lt. span )  span = ndata
      if( span .eq. 0 )  then
         if( ndata .le. 960 )  then
            span  = ndata
            shift = ndata
         else
            shift = 720
            ix = (ndata - 24)/shift
            jx =  ndata - 24 - ix*shift
            if( jx .le. 12 )  then
               span = shift + jx + 24
            else
               kx = jx/ix /6*6
               shift = shift + kx
               span  = shift + jx - kx*ix + 24
            endif
         endif
      endif
      write(8,1391)  span, shift
 1391 format(/' *** Actual span =',i6,' and shift =',i6,'    ***')
c
c
c     work area check
c
ccc   if( ith.ne.0 )  ith = ( nnnoup + ifcr )*2
      ith = ( nnngrp + ifcr )*2
c
      iordp1 = order + 1
      lagdbl = 1
      lag    = 0
      ithp1  = ith + 1
      ithaug = ith + iaug
      iaugp2 = iaug + 2
      lagpp1 = lagp + 1
      ncoef = lagdbl*ith + lagpp1*iaug
      n2max = ncoef + iordp1 + maxjmp
      limit = n2max + span
      item1 = iordp1*limit
      item2 = n2max*limit
      write(8,1500)
 1500 format(/,10x,'***** Array Sizes and Allocations *****',/
     *       21x,'size',17x,'allocation',/)
      write(8,1510)  span,   maxout
 1510 format(' span            ',i9,8x,'maxout   ',i9)
      write(8,1520)  ndata,  maxh2-11
 1520 format(' data length     ',i9,8x,'maxh2-11 ',i9)
      write(8,1530)  iaugp2, maxaux+2
 1530 format(' iaug + 2        ',i9,8x,'maxaux+2 ',i9)
      write(8,1540)  n2max,  maxunk
 1540 format(' n2max           ',i9,8x,'maxunk   ',i9)
      write(8,1550)  limit,  maxop2
 1550 format(' limit           ',i9,8x,'maxop2   ',i9)
      write(8,1560)  item1,  maxdc
 1560 format(' (order+1)*limit ',i9,8x,'maxdc    ',i9)
      write(8,1570)  item2,  maxh2
 1570 format(' n2max*limit     ',i9,8x,'maxh2    ',i9)
      write(8,1580)
 1580 format(/,' where n2max = 2*(# groups)*2 + (lagp+1)*iaug +',
     1 ' order + maxjmp + 1',/,
     2       '         and  limit = n2max + span')
      ill = 0
      if(span   .gt. maxout)    ill = 1
      if(ndata  .gt. maxh2-11)  ill = 1
      if(iaugp2 .gt. maxaux+2)  ill = 1
      if(n2max  .gt. maxunk)    ill = 1
      if(limit  .gt. maxop2)    ill = 1
      if(item1  .gt. maxdc)     ill = 1
      if(item2  .gt. maxh2)     ill = 1
c     emergency stop
      if( ill.ne.0 )  then
         write(8,1600)
 1600    format(/' ERROR:  insufficent working area ')
         stop
      endif
c
c
c     data input (continued) and theoretical value computation
c
      jy=ja
      jm=jb
      jd=jc
      hrt=hr
      ncalc=ndata + lag*2
      tem=hr-lag*delt
      nfile = nfile + 1
c
      if( ith.eq.0 )  go to 2490
c
      tj0 = tjul(ja,jb,jc,hr)
      if( ipoten.eq.1 )  then
         call geogr1( kind, slat, sh, ge, az, lovenm )
         call sphas1( tj0, hr, slong )
      else if( ipoten.eq.2 )  then
         tc0 = tj0 + dble(ndata)*delt/24.d0*0.5d0
         call geogr2( kind, slat, sh, ge, az, lovenm )
         call sphas2( tj0, hr, slong, tc0 )
      endif
      if( ncosgr.gt.0 )
     *    call setcos( ncosgr, comg, comg0, tcos, tj0, ipoten )
      nblc = (ncalc - 1)/lbuff + 1
c
      do nb = 1, nblc
        jend = lbuff
        if( nb.eq.nblc )  jend = mod( ncalc-1, lbuff ) + 1
        jstart = lbuff*(nb - 1)
        do n = 1, nnngrp
           ng1 = ig1(n)
           ng2 = ig2(n)
           do j = 1, jend
              jcopy = j
              t = delt*(j-1+jstart)
              if( ipoten.eq.1 )  then
                 call tide01( ng1, ng2, t, ct, st, delt, jcopy )
              else if( ipoten.eq.2 )  then
                 call tide02( ng1, ng2, t, ct, st, delt, jcopy,
     *                        p4flag, tc0 )
              endif
              h2(j)       = ct
              h2(j+lbuff) = st
           enddo
           if( incore.eq.1 )  then
              do j = 1, jend
                 yt(j+jstart,1,2*n-1) = h2(j)
                 yt(j+jstart,1,2*n  ) = h2(j+lbuff)
              enddo
           else
              write(31)  (sngl(h2(j)),j=1,2*lbuff)
           endif
        enddo
        if(ifcr .eq. 1)  then
           do i = 1, 2*lbuff
              h2(i) = 0.d0
           enddo
           do n = 1, 11
              if( ipoten.eq.1 )  then
                 ng1r = ig1r(n)
                 ng2r = ig2r(n)
              else if( ipoten.eq.2 )  then
                 ng1r = ig1r(n+11)
                 ng2r = ig2r(n+11)
              endif
              do j = 1, jend
                 jcopy = j
                 t = delt*(j-1+jstart)
                 if( ipoten.eq.1 )  then
                    call tide01(ng1r,ng2r, t, ct, st, delt, jcopy)
                 else if( ipoten.eq.2 )  then
                    call tide02(ng1r,ng2r, t, ct, st, delt, jcopy,
     1                        p4flag, tc0 )
                 endif
                 h2(j)       = h2(j)      +(fcrr(n)*ct+fcri(n)*st)
                 h2(j+lbuff) = h2(j+lbuff)+(fcrr(n)*st-fcri(n)*ct)
              enddo
           enddo
           if( incore.eq.1 )  then
              do j = 1, jend
                 yt(j+jstart,1,2*nnngrp+1) = h2(j)
                 yt(j+jstart,1,2*nnngrp+2) = h2(j+lbuff)
              enddo
           else
              write(31)  (sngl(h2(j)),j=1,2*lbuff)
           endif
        endif
      enddo
c
      if( incore.ne.1 )  rewind 31
c
 2490 continue
      if(iformt.eq.3) then
        slat2=slat
        sl2=slong
        sh2=sh
        ge2=ge
      endif
c
      do k = 1, iaug
         call datar2(rat,h2,1,ndata,rlim,ja,jb,jc,hr,delt,nfile,
     *               slat2,sl2,sh2,ge2, kind,az, zerorm)
         if( ndata.lt.span )  then
            write(8,2495)
 2495       format(/' ERROR: auxiliary dataset is too short')
            stop
         endif
       enddo
c
c
c
c     reading titles, station name, instrument name, unit and
c     auxiliary data name from control file
c
c
      call rtitle( numtit, numins, ctitle, cstnam,
     *             cinstr, cunit,  cassoc, iaug   )
c
c
c
c**** initialization ****
c
      rlim=1.d25
      do i=1,order
         ftrn(i) = 0.d0
      enddo
      do i=1,101
         autco(i)=0.d0
      enddo
      nsum=0
      n=ndata
      if(shift .ne. 0) n=span
      avsd=0.d0
      avabic=0.d0
      count=0.d0
      ajump=0.d0
      lp=0
c
c
c
c ******************
c *   main block   *
c ******************
c
      do 5400 iiii=1,100
      jlistp=0
      intest=0
      if(iiii.eq.1) intest=order
      njump=intest
      n2=ncoef+1+njump
      istart=1+(iiii-1)*shift
      iend=istart-1+n
c     exit of the main block
      if(iend .gt. ndata)  go to 5500
      call calend(ja,jb,jc,hr,istart,delt,jy,jm,jd,hrt)
      call calend(jy,jm,jd,hrt,n,delt,jy1,jm1,jd1,hrt1)
      write(8, 2801)
      write(8, 3372)
      write(8, 2900)
 2900 format(' **************************************************',
     *        '**************')
      write(8, 3000)
 3000 format(' *                                                 ',
     *        '             *')
      if(iback.eq.0) then 
         call htohms(hrt,kh,km,ks)
         call htohms(hrt1,kh1,km1,ks1)
         write(8,3100) 1900+jy,jm,jd,kh,km,ks,
     1                 1900+jy1,jm1,jd1,kh1,km1,ks1
 3100    format(' *    Start ',i4,5i3,
     1          '    End ',i4,5i3,'      *')
      endif
      if(iback.eq.1) then 
         write(8,3102) 1900+jy,jm,jd,hrt,
     1                 1900+jy1,jm1,jd1,hrt1
 3102    format(' *    start = ',3i4,f5.1,
     1          '  ;   end = ',3i4,f5.1,'    *')
      endif
      write(8, 3000)
      write(8, 2900)
      write(8, 3372)
 2800 format(/)
 2801 format(' ')
 2803 format(' --------------------------------------------------',
     *        '--------------')
c
c
c
c**** main procedure ****
c
      do irty0 = 1, order
         ftrnbk(irty0) = ftrn(irty0)
      enddo
c
      call subsea(ddd,respc,ithaug,abic,trend,respns,irreg,tidal,
     *    ftrn,n,istart,rlim,dc,iordp1,h2,n2,n2max,
     *    data,intest,limit,shift,err,sqe,cntr,sd,
     *    maxdc,maxh2)
c
c
c
c     /*  test version,  incore=1, shift>0  only !  */
c
      if( ( sigma1.gt.1.d25 .and. sigma2.gt.1.d25 ) .or.
     *       incore.ne.1  .or. shift.eq.0 )  go to 90300
c
      do 90200 irty9 = 1, 2
c
      rtyerr = sigma1
      if( irty9.eq.2 )  then
         if( sigma2.ge.sigma1 )  go to 90200
         rtyerr = sigma2
      endif
      if( rtyerr.gt.1.d25 )      go to 90200
c
      iretry = 0
      do irty1 = 1, n
         rtyd1 = dabs(irreg(irty1))
         if( rtyd1.gt.rtyerr .and. rtyd1.lt.1.d25 )  then
            iretry = iretry + 1
            if( iretry.eq.1 )  write(8,90020)  rtyerr
90020 format(///'  maximum error is larger than the limit', f9.3
     *        //'          date          input data   irregular')
            call calend(jy,jm,jd,hrt,irty1,delt,jy2,jm2,jd2,hrt2)
            irty2 = irty1 + istart - 1
ccc         write(8,90030) jy2,jm2,jd2,hrt2, yo(irty2,1),irreg(irty1)
            write(8,90030) 1900+jy2,jm2,jd2,hrt2,
     *                     yo(irty2,1),irreg(irty1)
90030       format(i8,2i3,f5.1, f14.3, f12.3)
            yo(irty2,1) = 1.d30
         endif
      enddo
c
c     subsea again
c
      if( iretry.ne.0 )  then
         write(8,90040)  iretry
90040    format(/'   total', i5, ' data', 7x,'above data might',
     *           ' be removed from input dataset' /// )
c
         intest = 0
         if( iiii.eq.1 )  intest = order
         njump = intest
         n2 = ncoef + 1 + njump
         do irty0 = 1, order
            ftrn(irty0) = ftrnbk(irty0)
         enddo
c
         if( iiii.eq.1 )  then
            ichkmd = 1
         else
            ichkmd = 0
         endif
         call ystpck( yo(istart,1), n, ichkmd )
c
         call subsea(ddd,respc,ithaug,abic,trend,respns,irreg,tidal,
     *       ftrn,n,istart,rlim,dc,iordp1,h2,n2,n2max,
     *       data,intest,limit,shift,err,sqe,cntr,sd,
     *       maxdc,maxh2)
      endif
c
90200 continue
90300 continue
c
c
c
      avabic=avabic+abic
      avsd=avsd+sd*n
      count=count+n
c     skip to the output routine
      if( ith.eq.0 )  go to 3600
c
      do j = 1, ncoef
        err(j) = dsqrt( err(j)*sqe )
      enddo
c
      write(8,3400)
 3400 format(/,' tidal factors    (cos and sin parts)')
      write(8,3402)  ( respc(j), j = 1, 2*nnngrp )
 3402 format('   fact. = ',1p2d13.5,2x,2d13.5,2x,2d13.5)
      write(8,3404)  ( err(j),   j = 1, 2*nnngrp )
 3404 format('   error = ',1p2d13.5,2x,2d13.5,2x,2d13.5)
      if( ifcr.eq.1 )  then
         write(8,3410)
 3410    format(/' fcr factors')
         write(8,3412)  respc(2*nnngrp+1), respc(2*nnngrp+2)
 3412    format( '   fact. =',1p2d14.5)
         write(8,3414)  err  (2*nnngrp+1), err  (2*nnngrp+2)
 3414    format( '   error =',1p2d14.5)
      endif
      do i = 1, iaug
         write(8,3420)  i
 3420    format(/' response weights',8x,'auxiliary dataset no. =',
     1     i3 )
         je = min0( lagp, 5 )
         write(8,3421)  ( j, j = 0, je )
 3421    format( '   lag   =',8x,6(i1,14x) )
         fnm = rat(i+1)
         js = (nnngrp+ifcr)*2 + i*lagpp1
         je = js - lagp
         write(8,3422)  ( respc(j)*fnm, j = js, je, -1 )
 3422    format( '   respc =',1p6d15.5)
         write(8,3424)  ( err(j)*fnm,   j = js, je, -1 )
 3424    format( '   error =',1p6d15.5)
      enddo
      write(8,3430)  sqe
 3430 format(/,' sqe  =',1pd15.5,/)
c
      rad = 3.141592653589793d0/180.d0
c
      write(8,2803)
      write(8,2800)
c
      do ii = 1, numtit
        write(8,3435)  ctitle(ii)
 3435   format(' ',a80)
      enddo
      write(8,3440)  cstnam
 3440 format(05x,'station   ',4x,a40)
      write(8,3445)  slong
 3445 format(05x,'   Lon.=  ',4x,f9.3,' E')
      write(8,3450)  slat
 3450 format(05x,'   Lat.=  ',4x,f9.3,' N')
      write(8,3455)  sh
 3455 format(05x,'   Ht. =  ',4x,f8.3,' M')
      write(8,3460)  cinstr(1)
 3460 format(05x,'Instrument:',4x,a40)
      do ii = 2, numins
         write(8,3465)  cinstr(ii)
 3465    format(05x,'          ',4x,a40)
      enddo
      write(8,3470)  cunit
 3470 format(05x,'amplitude ',4x,a40)
      if(iback.eq.1) then
         write(8,3472)  1900+jy,jm,jd,hrt, 1900+jy1,jm1,jd1,hrt1
 3472    format(/,05x,'From       ',i4,2i3,f5.1,' to ',i4,2i3,f5.1)
      endif
      if(iback.eq.0) then
         call htohms(hrt,kh,km,ks)
         call htohms(hrt1,kh1,km1,ks1)
         write(8,3474) 1900+jy,jm,jd,kh,km,ks,
     1                 1900+jy1,jm1,jd1,kh1,km1,ks1
 3474    format(/,5x,'From       ',i4,5i3,' to ',i4,5i3)
      endif
      write(8,3476)  numuse, n
 3476 format(/05x,'available / block len.',i9,' /',i6)
      if(iback.eq.1) write(8,3480)  pgname,version
 3480 format(/'   Analyzed by ',a8,'    Version ',a5)
      if( ngroup.ge.1 )  then
         if( ipoten.eq.1 )  then
            write(8,3485)
 3485       format('   potential   : Cartwright, Tayler and Edden')
         else if( ipoten.eq.2 )  then
            if( p4flag.eq.0 )  then
               write(8,3486)
 3486          format('   potential   : Tamura, Y., 1987, BIM, 99. ',
     *       '(without P4)' )
            else
               write(8,3487)
 3487          format('   potential   : Tamura, Y., 1987, BIM, 99. ',
     *       '(with P4)')
            endif
         endif
      else
         write(8,3488)
 3488    format('   potential   : none')
      endif
      if(iback.eq.1) write(8,3490)  who
 3490 format('   calculation : ',a60)
c
      write(8,3380)
 3380 format(/,'  grp           symbol     ',
     *       'factor   rmse       phase   rmse    amplitude',
     *       '  rmse',/,43x,'(local, lags negative)',/)
      npp1 = nnngrp*2 + 1
      npp2 = npp1 + 1
      np = 0
      do i = 1, ngroup
        np = np + 1
        sumr =  respc(np)
        if(ifcr .eq. 1)  sumr = sumr + respc(npp1)*fcr(i)
     *                               - respc(npp2)*fci(i)
        errr =  err(np)**2
        if(ifcr .eq. 1)  errr = errr + (err(npp1)*fcr(i))**2
     *                               + (err(npp2)*fci(i))**2
        np = np + 1
        sumi = -respc(np)
        if(ifcr .eq. 1)  sumi = sumi - respc(npp2)*fcr(i)
     *                               - respc(npp1)*fci(i)
        erri =  err(np)**2
        if(ifcr .eq. 1)  erri = erri + (err(npp2)*fcr(i))**2
     *                               + (err(npp1)*fci(i))**2
        amp(i) = dsqrt(sumi**2+sumr**2)
        eamp   = dsqrt( errr*sumr**2 + erri*sumi**2 )/amp(i)
        phase(i) = datan2(sumi,sumr) / rad
        eph    = dsqrt( erri*sumr**2 + errr*sumi**2 )/amp(i)**2 / rad
c
        amplmw = 0.d0
        if(ig2(i).le.iwnd)  
     *           amplmw = dabs( gc(2,1)*amp(i)*amc(imwave(i)) )
        if(ig1(i).gt.iwnd .and. ig2(i).le.iwns)
     *           amplmw = dabs( gc(2,2)*amp(i)*amc(imwave(i)) )
        if(ig1(i).gt.iwns)
     *           amplmw = dabs( gc(3,3)*amp(i)*amc(imwave(i)) )
        ampler = amplmw*eamp/amp(i)
c
        write(8,3390)  i, ig1(i), ig2(i), symbol(i),
     *               amp(i), eamp, phase(i), eph, amplmw, ampler
 3390   format('> ',i2,'  ',i3,'-',i3,': ',a8,
     *         f9.5,' ',f8.5,' ',f10.3,' ',f7.3,' ',
     *         f10.3,' ',f6.3,' ' )
        if( ig2(i).eq.iwnd .or. ig2(i).eq.iwns )  write(8,3372)
      enddo
c
      if( ncosgr.gt.0 )  write(8,3392)
 3392 format(/,20x,'   Results from fitting sinusoids',/,
     *          '   i     Freq (cycle/day)       ',
     *          'amp         err          phase      err',/)
      do i = ngroup+1, nnngrp
         np = np + 1
         sumr = respc(np)
         errr = err(np)**2
         np = np + 1
         sumi = -respc(np)
         erri =  err(np)**2
         amp(i) = dsqrt( sumi**2 + sumr**2 )
         eamp   = dsqrt( errr*sumr**2 + erri*sumi**2 )/amp(i)
         phase(i) = datan2( sumi, sumr ) / rad
         eph    = dsqrt( erri*sumr**2 + errr*sumi**2 )/amp(i)**2 / rad
         write(8,3394)  i, center(i)/15.d0, amp(i), eamp, phase(i), eph
 3394    format(i5,4x,f15.10,4x,f9.5,' +- ',f8.5,4x,f10.3,' +- ',f7.3)
      enddo
      write(8,3510)  abic
 3510 format(//'    Minimum ABIC       =',f11.2)
      write(8,3515)  sd
 3515 format( '    Standard deviation =',f13.4)
      write(8,3520)  weight
 3520 format(/'    Hyperparameter W   =',f12.3)
      write(8,3525)  ddd
 3525 format( '          "        D   =',g12.4)
      if(iformt.ne.1.and.iformt.ne.3)  write(8,3530)  delt
 3530 format(/'    Sample   interval   original   =  0.5 hour' /
     *        '                        resampling =',f5.1,' hour')
      if(iformt.eq.1.or.iformt.eq.3)   write(8,3531)  delt
 3531 format(/'    Sample   interval  (original)  =',f5.1,' hour')
      if(shift.gt.0)  write(8,3535)  span
 3535 format( '                          span     =',i7)
      write(8,3540)  shift
 3540 format( '                          shift    =',i7)
      if(iaug.eq.0)  then
         write(8,3545)
 3545    format(/'    auxiliary data : none')
      else
         write(8,3372)
         do ii=1,iaug
            write(8,3550)  cassoc(ii)
 3550       format( '    Auxiliary data : ',a40)
         enddo
         write(8,3555)  lagp, lagint
 3555    format( '                      maximum lag  =',i3 /
     *           '                      lag interval =',i3 )
      endif
c
c3372 format(1h )
 3372 format( )
c
c     Fourier transform of response weights
c
      if( iaug .ge. 1 )  then
         krespc = (nnngrp+ifcr)*2 + 1
         call frqrsp( rat, respc(krespc), err(krespc), lagint, lagpp1,
     *                iaug, deg, paglen, rsperr )
      endif
c
c     in case
c         theoretical tide : none        (  ith.eq.0 )
c         auxiliary data  : exist       ( iaug.ge.1 )
c
 3600 if( ith.eq.0 .and. iaug.ge.1 )  then
         do j = 1, ncoef
           err(j) = dsqrt( err(j)*sqe )
         enddo
c
         write(8,2800)
         do i = 1, iaug
            write(8,3420)  i
            je = min0( lagp, 5 )
            write(8,3421)  ( j, j = 0, je )
            fnm = rat(i+1)
ccc         js = iaug*lagpp1     /*  bug fixed  '99/11/15  */
            js = i*lagpp1
            je = js - lagp
            write(8,3422)  ( respc(j)*fnm, j = js, je, -1 )
            write(8,3424)  ( err(j)*fnm,   j = js, je, -1 )
         enddo
         write(8,3430)  sqe
c
         call frqrsp( rat, respc(1), err(1), lagint, lagpp1,
     *                iaug, deg, paglen, rsperr )
      endif
c
c
c     numerical output (if filout.eq.1)
c
c     exit of the main block for shift = 0
      if(shift .eq. 0) go to 5700
      do i=1,n
        trend(i)=trend(i)-ajump
      enddo
      nout=n
      if(iend .lt. ndata .and. shift .ne. 0) nout=shift
c
c Write out series decomposed into different parts. In regular mode
c    (back=0) no header written, and each line contains the time
c
c Unlike BAYTAP-G, no unformatted writes allowed, since going to standard out
c
      if(filout.eq.1)  then
         if(iback.eq.1) then
           if( iiii.eq.1 )  write(6,4000)
 4000      format('   *(original data)=(tidal comp.)+(trend)+',
     *       '(response)+(irregular)+(step)' /
     *       '     format is 1h ,i5,5d13.5,        1.d30 and -1.d30',
     *       ' are special marks')
           if( iiii.eq.1 )  write(6,4100)
 4100      format('     i    irregular    trend   ',
     *         '     response    tidal comp.   original')
         endif
         do i=1,nout
            iser=istart-1+i
            if(iback.eq.1) then
                write(6,4200)  iser, irreg(i), trend(i),
     *                      respns(i), tidal(i), data(i)
 4200           format(i6,1p5d13.5)
            else
                call calend(ja,jb,jc,hr,iser,delt,ky,km,kd,hrk)
                call htohms(hrk,kh,kn,ks)
c
c for producing "nontidal" series, irreg=0 if it is missing
c
                if(abs(irreg(i)).gt.rlim) xirr=0
                if(abs(irreg(i)).le.rlim) xirr=irreg(i)
c
c different outputs depending on the number of auxiliary series
c
                if(iaug.eq.0) then
                  write(6,4202)  1900+ky,km,kd,kh,kn,ks,irreg(i),
     1            trend(i),respns(i), tidal(i), xirr+trend(i),data(i)
 4202             format(i4,'-',i2.2,'-',i2.2,'T',i2.2,':',i2.2,':',
     1                   i2.2,'  ',1p6d13.5)
                endif
                if(iaug.gt.0) then
                  do ll=1,iaug
                     if(ya(i,1,ll).ge.99.e28) auxcur(ll) = ya(i,1,ll)
                     if(ya(i,1,ll).lt.99.e28)
     1                  auxcur(ll) = auxmen(ll) + ya(i,1,ll)/rat(ll+1)
                  enddo
                  write(6,4204)  1900+ky,km,kd,kh,kn,ks,irreg(i),
     1            trend(i),respns(i), tidal(i), xirr+trend(i),data(i),
     2            (auxcur(ll),ll=1,iaug)
 4204             format(i4,'-',i2.2,'-',i2.2,'T',i2.2,':',i2.2,':',
     1                   i2.2,'  ',1p9d13.5)
               endif
            endif
         enddo
      endif
c
c     if lpout .ge. 1, step correction and graphical output
c
      item=1+shift-order
      call copy(ftrn,trend,order,item)
      call otlchk(trend,nout,1,listtr,ltr0,h2,mxotl)
      i101=101
      if(i101 .gt. nout-1) i101=nout
      call sautco(h2,tautco,nout-1,i101,lpout)
      if( spectw.ge.1 )  then
         write(8,6410)
 6410    format(/' Spectrum of trend')
         call sicp2(tautco,51,nout,h2,l,sgme2,oaic)
         call snrasp(h2,dc,h2,sgme2,l,0,i61,deg,paglen)
      endif
      do i = 1, i101
         autco(i) = ( autco(i)*dble(nsum) + tautco(i)*dble(nout) )
     *             / dble( nsum + nout )
      enddo
      nsum=nsum+nout
      call otlchk(irreg,nout,0,listir,lir0,h2,mxotl)
      item=istart-1+shift
      jtem=ncoef + njump + 1
      jpchk = 0
      do i = 1, nout
        if( data(i).le.-rlim .and. jpchk.ne.1 )  then
           jtem = jtem - 1
           ajump0 = respc(jtem)
           jpchk = 1
        endif
        if(jpchk.ne.0 .and. dabs(data(i)).le.rlim )  then
           ajump = ajump + ajump0
           jpchk = 0
           ijump = istart + i - 1
           if( lpout.ge.2 )  write(8,3900)  ajump0, ijump
 3900      format(' step ',1pd13.4,'  at', i5)
           jlistp = jlistp + 1
           if( jlistp.gt.mxlsta )  then
              write(8,4410)
 4410         format(/' ERROR: too many steps: stopped at main')
              stop
           endif
           jlist(jlistp) = i - 1
           qjump(jlistp) = ajump0
        endif
        trend(i) = trend(i) + ajump
      enddo
c
      if( jpchk.eq.1 .and. span.gt.nout )  then
         ijump = istart + nout - 1
         if( lpout.ge.2 )  write(8,3900)  ajump0, ijump
         jlistp = jlistp + 1
         if( jlistp.gt.mxlsta )  then
            write(8,4410)
            stop
         endif
         jlist(jlistp) = nout
         qjump(jlistp) = ajump0
      endif
c
c   printer plot of data (in backwards-compatible mode only)
c
      if( lpout.ge.1.and.iback.eq.1)
     *   call graph3( data, trend, irreg, respns, tidal, nout,
     *                prepro, rlim, jy, jm, jd, hrt, delt )
c
c
c
c     assessment of the result of the present span
c
c     emergency exit (buffer over flow)
      if(lp .ge. mxlstb)  go to 5200
      if(ddd .lt. ddmin)  then
         lp=lp+1
         lsmry(1,lp)=istart
         lsmry(2,lp)=iend
         lsmry(3,lp)=0
      endif
      lir=1
      ltr=1
      ljp=1
c     emergency exit (buffer over flow)
 4800 if(lp .ge. mxlstb)  go to 5200
         mir=1000000
         mtr=mir
         mjp=mir
         if(lir .le. lir0) mir=listir(lir)
         if(ltr .le. ltr0) mtr=listtr(ltr)
         if(ljp .le. jlistp) mjp=jlist(ljp)
         min=900000
         indxir=0
         indxtr=0
         indxjp=0
         if(min .ge. mir)  then
            min=mir
            indxir=1
         endif
         if(min .ge. mtr)  then
            min=mtr
            indxtr=1
            if(mtr .lt. mir) indxir=0
         endif
         if(min .ge. mjp)  then
            min=mjp
            indxjp=1
            if(mjp .lt. mir) indxir=0
            if(mjp .lt. mtr) indxtr=0
         endif
         ix=indxir + 2*indxtr + 4*indxjp
c        exit
         if(ix .eq. 0)  go to 5200
         lp=lp+1
         lsmry(1,lp)=0
         lsmry(2,lp)=min + istart - 1
         lsmry(3,lp)=ix
         if(indxir .eq. 1) lir=lir+1
         if(indxtr .eq. 1) ltr=ltr+1
         if(indxjp .eq. 0)  go to 4800
         qqjump(lp)=qjump(ljp)
         ljp=ljp+1
      go to 4800
c
c
c
c     preparation for the next span
c
 5200 continue
      if( jpchk .eq. 1 )  ajump = ajump + ajump0
      jpchk = 0
      do i=1,order
         ftrn(i)=ftrn(i)+ajump
      enddo
 5400 continue
c
c *****************************
c *   end of the main block   *
c *****************************
c
c
c
c     summary output
c
 5500 continue
      if( iiii.gt.2 )  then
         write(8,6410)
         call sicp2(autco,51,nsum,tautco,l,sgme2,oaic)
         call snrasp(tautco,dc,h2,sgme2,l,0,i61,deg,paglen)
      endif
c
      write(8,5800)
 5800 format(/' *** Summary of the Analysis ***')
      if(iback.eq.0) write(8,5900)
 5900 format(/ 7x, 'Date', 17x, 'Date', 16x, 'ABIC   Trend',
     *           '  Irregular      Step         -Step/factor' )
      if(iback.eq.1) write(8,5902)
 5902 format(/ 7x, 'Date', 17x, 'Date', 12x, 'ABIC   Trend',
     *           '  Irregular      Step         -Step/factor' )
      if( lp.le.0 )  then
        write(8,5910)
 5910   format(/ 7x, 'None' // )
      else
        do i=1,lp
           it0=lsmry(1,i)
           it1=lsmry(2,i)
           id=lsmry(3,i)
           if(it0 .ne. 0)
     *     call calend(ja,jb,jc,hr,it0,delt,jy,jm,jd,hrt)
           call calend(ja,jb,jc,hr,it1,delt,jy1,jm1,jd1,hrt1)
           if(iback.eq.0) then
              call htohms(hrt,kh,km,ks)
              call htohms(hrt1,kh1,km1,ks1)
              if(it0.ne.0) write(obuf2,6002) 1900+jy,jm,jd,kh,km,ks,
     *                                   1900+jy1,jm1,jd1,kh1,km1,ks1
 6002         format(i4,5i3,' - ',i4,5i3)
              if(it0.eq.0) write(obuf2,6102) 1900+jy1,jm1,jd1,
     1                                                    kh1,km1,ks1
 6102         format(i4,5i3,22x)
           endif
           if(iback.eq.1) then
              if(it0 .ne. 0) write(obuf1,6000) 1900+jy,jm,jd,hrt,
     *                                   1900+jy1,jm1,jd1,hrt1
 6000         format(3i4,f6.1,' - ',3i4,f6.1)
              if(it0 .eq. 0) write(obuf1,6100) 1900+jy1,jm1,jd1,hrt1
 6100         format(3i4,f6.1,21x)
           endif
           do kk=1,3
              mark(kk) = ' '
           enddo
           id1=id/2
           indxir=id - id1*2
           indxjp=id1/2
           indxtr=id1 - indxjp*2
           if(id .eq. 0)      mark(1) = '*'
           if(indxtr .eq. 1)  mark(2) = '*'
           if(indxir .eq. 1)  mark(3) = '*'
           if(indxjp .eq. 0) then
              if(iback.eq.0) write(8,6202)  obuf2, (mark(k),k=1,3)
 6202         format(' ',a41,6x,a1,7x,a1,7x,a1,6x,1pd11.4,d18.5)
              if(iback.eq.1) write(8,6200)  obuf1, (mark(k),k=1,3)
 6200         format(' ',a39,6x,a1,7x,a1,7x,a1,6x,1pd11.4,d18.5)
           endif
           if(indxjp. eq. 1)  then
              call kando( coef, jy1, jm1, jd1, hrt1, 1 )
              qnjump = - qqjump(i) / coef
              if(iback.eq.0)
     1          write(8,6202) obuf2,(mark(k),k=1,3),qqjump(i),qnjump
              if(iback.eq.1)
     1          write(8,6200) obuf1,(mark(k),k=1,3),qqjump(i),qnjump
           endif
      enddo
      endif
c
c     entry in case of shift = 0
c
 5700 continue
      if( iiii.le.2 )  stop
      avabic=avabic/count
      avsd=avsd/count
      avabic=avabic*ndata
      write(8,6400) avabic,avsd
 6400 format(/' *avABIC =',f13.2,'   avsd =',1pd12.4 //)
      stop
      end
c
c===========================================================================
c
c          End of main program: subroutines start here.
c
c===========================================================================
c
      subroutine getcmd
c
c get file names off command line: these are assigned to the following
c  unit numbers:
c        7: control file
c        8: results file
c        11-13: auxiliary input files, if present
c        5 (standard in):  input time series
c        6 (standard out): output time series (decomposed)
c
      character*80 dum
      logical lexist
      double precision auxmen
      parameter ( maxaux = 3 )
      dimension auxmen(maxaux)
      common /auxil/  auxmen,naux
      if(iargc().lt.2.or.iargc().gt.5) then
         write(6,100) 
 100     format(/,'Usage: cat data | baytap08 control results',
     1            ' [aux1 [aux2 [aux2]]] > decomposed-series ',/)
         stop
      endif
      call getarg(1,dum)
      inquire(file=dum,exist=lexist)
      if(.not.lexist) then
        write(6,102) dum
 102    format(' No file ',a)
        stop
      endif
      open(7,file=dum,status='old')
      call getarg(2,dum)
      open(8,file=dum,status='unknown')
      if(iargc().eq.2) return
      naux=iargc()-2
      do i=1,naux
        call getarg(2+i,dum)
        inquire(file=dum,exist=lexist)
        if(.not.lexist) then
          write(6,102) dum
          stop
        endif
        open(10+i,file=dum,status='old')
      enddo
      return
      end
c===========================================================================
      subroutine prmset( ith, order, span, shift, rlim, lpout, filout,
     *                   spectw, prepro, weight,
     *                   iaug, lagp, lagint, maxjmp,
     *                   kind, az, dmin, timsys, ifcr, qval, maxitr,
     *                   icetgr, s1wave, paglen, ipoten, p4flag, lovenm,
     *                   rsperr, sigma1, sigma2, zerorm, nsine,
     *                   igrp,ja,jb,jc,hr,jmin,jsec,ndata,delt,
     *                   slat,slong,sh,ge,inform)
c
      implicit double precision (a-h,o-z)
      integer  order, span, shift, filout, spectw, prepro, s1wave
      integer  paglen, p4flag, rsperr
      integer  zerorm
      common/backcom/iback
c
      az     =    0.d0
      iback  =    0
      delt   =    1
      dmin   =    0.25d0
      filout =    0
      hr     =    0
      iaug   =    0
      icetgr =    1
      ifcr   =    0
      igrp   =    0
      inform =    3
      ipoten =    2
      ith    =    1
      ja     =    2000
      jb     =    1
      jc     =    1
      jmin   =    0
      jsec   =    0
      kind   =   99
      lagint =    1
      lagp   =    3
      lovenm =    2
      lpout  =    0
      maxitr =   21
      maxjmp =    5
      ndata  =    0
      nsine  =    0
      order  =    2
      p4flag =    1
      paglen =   66
      prepro =    0
      qval   = 1150.d0
      rlim   =    1.d25
      rsperr =    0
      s1wave =    0
      shift  =  720
      sigma1 =    1.d30
      sigma2 =    1.d30
      slat   =   39.135170
      slong  =  141.132826
      sh     =  117.000
      ge     =  fnormg(slat,sh)
      span   =  744
      spectw =    0
      timsys =    0.d0
      weight =    1.d0
      zerorm =    0
c
      return
      end
c===========================================================================
      subroutine namels( ith, order, span, shift, rlim, lpout, filout,
     *                   spectw, prepro, weight,
     *                   iaug, lagp, lagint, maxjmp,
     *                   kind, az, dmin, timsys, ifcr, qval, maxitr,
     *                   icetgr, s1wave, paglen, ipoten, p4flag, lovenm,
     *                   rsperr, sigma1, sigma2, zerorm, nsine,
     *                   igrp,ja,jb,jc,hr,jmin,jsec,ndata,delt,
     *                   slat,slong,sh,ge,inform)
c
c     simulation of namelist read routine
c
      implicit double precision (a-h,o-z)
c
      integer  order, span, shift, filout, spectw, prepro, s1wave
      integer  paglen, p4flag, rsperr
      integer  zerorm
      character*6   vnam, pname(2)
      character*8   fmti, fmtd
      character*20  fmt20
      character*72  buff
      common/backcom/iback
      data  monitr  /  1  /
      data  pname   / '&PARAM', '&param' /
c
c
      ill = 0
      ist = 0
c
   10 continue
      do i = 1, 72
        buff(i:i) = ' '
      enddo
      read(7,12,end=100,err=20)  (buff(i:i),i=1,72)
   12 format(72a1)
   20 continue
c
c
      i = 0
   40 i = i + 1
      if( i.gt.72 )  go to 10
      if( buff(i:i).eq.' ' .or. buff(i:i).eq.',' )  go to 40
c
c     find one symbol
      is = i
      ielim = is + 6
   50 i  = i + 1
      if( i.gt.72 )  go to 60
      if( i.gt.ielim )  then
         write(8,52)  buff
   52    format(/' ERROR in namels, symbol too long ',/,
     1           '  rec: ',a72)
         ill = 1
         go to 10
      endif
      if( buff(i:i).ne.'=' .and. buff(i:i).ne.' ' )  go to 50
   60 ie = i - 1
      il = i - is
      vnam       = '      '
      vnam(1:il) = buff(is:ie)
c
c
      if( vnam.eq.pname(1) .or. vnam.eq.pname(2) )  then
         ist = 1
         go to 40
      else if( vnam.eq.'&END  ' .or. vnam.eq.'&end  ' )  then
         if( ill.ne.0 )  stop
         if( ist.eq.0 )  then
            write(8,62)  pname(1), buff
  62        format(/' ERROR in namels       no  ',a6,/,
     1              '  rec : ',a72)
            stop
         endif
c
c before exiting, set gravity if not set
c
         if(ge.eq.0) ge = fnormg(slat,sh)
         return
      else if( ist.eq.0 )  then
         write(8,62)  pname(1), buff
         stop
      endif
c
c
   70 i = i + 1
      if( i.gt.72 )  then
         write(8,72)  buff
   72    format(/' ERROR in namels         =    not found',/,
     1           '  rec : ',a72)
         ill = 1
         go to 10
      endif
      if( buff(i:i).eq.' ' .or. buff(i:i).eq.'='  )  go to 70
c
c     find one value
      is = i
   80 i  = i + 1
      if( i.gt.72 )  then
         write(8,82)  buff
   82    format(/' ERROR in namels       value  not found',/,
     1           '  rec : ',a72)
         ill = 1
         go to 10
      endif
      if( buff(i:i).ne.',' .and. buff(i:i).ne.' ' )  go to 80
      ie = i - 1
      il = i - is
c
c     print out parameters for debug
c
      if( monitr.ge.1 )  then
         fmt20 = '(1x,a6,1x,i2,2x,a72)'
         write(fmt20(18:19),'(i2)')  il
         write(8,fmt20)  vnam, il, buff(is:ie)
      endif
c
      write(fmti,'(a2,i2,a4)')  '(i', il, ')   '
      write(fmtd,'(a2,i2,a4)')  '(f', il, '.0) '
      if(      vnam.eq.'AZ    ' .or. vnam.eq.'az    ' )  then
                      read(buff(is:ie),fmtd)  az
      else if( vnam.eq.'BACKW ' .or. vnam.eq.'backw ' )  then
                      read(buff(is:ie),fmti)  iback
      else if( vnam.eq.'DAY   ' .or. vnam.eq.'day   ' )  then
                      read(buff(is:ie),fmti)  jc
      else if( vnam.eq.'DELTA ' .or. vnam.eq.'delta ' )  then
                      read(buff(is:ie),fmtd)  delt
      else if( vnam.eq.'DMIN  ' .or. vnam.eq.'dmin  ' )  then
                      read(buff(is:ie),fmtd)  dmin
      else if( vnam.eq.'GRAV  ' .or. vnam.eq.'grav  ' )  then
                      read(buff(is:ie),fmtd)  ge
      else if( vnam.eq.'FILOUT' .or. vnam.eq.'filout' )  then
                      read(buff(is:ie),fmti)  filout
      else if( vnam.eq.'HR    ' .or. vnam.eq.'hr    ' )  then
                      read(buff(is:ie),fmtd)  hr
      else if( vnam.eq.'HT    ' .or. vnam.eq.'ht    ' )  then
                      read(buff(is:ie),fmtd)  sh
      else if( vnam.eq.'IAUG  ' .or. vnam.eq.'iaug  ' )  then
                      read(buff(is:ie),fmti)  iaug
      else if( vnam.eq.'ICETGR' .or. vnam.eq.'icetgr' )  then
                      read(buff(is:ie),fmti)  icetgr
      else if( vnam.eq.'IFCR  ' .or. vnam.eq.'ifcr  ' )  then
                      read(buff(is:ie),fmti)  ifcr
      else if( vnam.eq.'IGRP  ' .or. vnam.eq.'igrp  ' )  then
                      read(buff(is:ie),fmti)  igrp
      else if( vnam.eq.'INFORM' .or. vnam.eq.'inform' )  then
                      read(buff(is:ie),fmti)  inform
      else if( vnam.eq.'IPOTEN' .or. vnam.eq.'ipoten' )  then
                      read(buff(is:ie),fmti)  ipoten
      else if( vnam.eq.'ITH   ' .or. vnam.eq.'ith   ' )  then
                      read(buff(is:ie),fmti)  ith
      else if( vnam.eq.'KIND  ' .or. vnam.eq.'kind  ' )  then
                      read(buff(is:ie),fmti)  kind
      else if( vnam.eq.'LAGINT' .or. vnam.eq.'lagint' )  then
                      read(buff(is:ie),fmti)  lagint
      else if( vnam.eq.'LAGP  ' .or. vnam.eq.'lagp  ' )  then
                      read(buff(is:ie),fmti)  lagp
      else if( vnam.eq.'LAT   ' .or. vnam.eq.'lat   ' )  then
                      read(buff(is:ie),fmtd)  slat
      else if( vnam.eq.'LONG  ' .or. vnam.eq.'long  ' )  then
                      read(buff(is:ie),fmtd)  slong
      else if( vnam.eq.'LOVENM' .or. vnam.eq.'lovenm' )  then
                      read(buff(is:ie),fmti)  lovenm
      else if( vnam.eq.'LPOUT ' .or. vnam.eq.'lpout ' )  then
                      read(buff(is:ie),fmti)  lpout
      else if( vnam.eq.'MAXITR' .or. vnam.eq.'maxitr' )  then
                      read(buff(is:ie),fmti)  maxitr
      else if( vnam.eq.'MAXJMP' .or. vnam.eq.'maxjmp' )  then
                      read(buff(is:ie),fmti)  maxjmp
      else if( vnam.eq.'MON   ' .or. vnam.eq.'mon   ' )  then
                      read(buff(is:ie),fmti)  jb
      else if( vnam.eq.'MIN   ' .or. vnam.eq.'min   ' )  then
                      read(buff(is:ie),fmti)  jmin
      else if( vnam.eq.'NDATA ' .or. vnam.eq.'ndata ' )  then
                      read(buff(is:ie),fmti)  ndata
      else if( vnam.eq.'NTERM ' .or. vnam.eq.'nterm ' )  then
                      read(buff(is:ie),fmti)  ndata
      else if( vnam.eq.'NSINE ' .or. vnam.eq.'nsine ' )  then
                      read(buff(is:ie),fmti)  nsine
      else if( vnam.eq.'ORDER ' .or. vnam.eq.'order ' )  then
                      read(buff(is:ie),fmti)  order
      else if( vnam.eq.'P4FLAG' .or. vnam.eq.'p4flag' )  then
                      read(buff(is:ie),fmti)  p4flag
      else if( vnam.eq.'PAGLEN' .or. vnam.eq.'paglen' )  then
                      read(buff(is:ie),fmti)  paglen
      else if( vnam.eq.'PREPRO' .or. vnam.eq.'prepro' )  then
                      read(buff(is:ie),fmti)  prepro
      else if( vnam.eq.'QVAL  ' .or. vnam.eq.'qval  ' )  then
                      read(buff(is:ie),fmtd)  qval
      else if( vnam.eq.'RLIM  ' .or. vnam.eq.'rlim  ' )  then
                      read(buff(is:ie),fmtd)  rlim
      else if( vnam.eq.'RSPERR' .or. vnam.eq.'rsperr' )  then
                      read(buff(is:ie),fmti)  rsperr
      else if( vnam.eq.'S1WAVE' .or. vnam.eq.'s1wave' )  then
                      read(buff(is:ie),fmti)  s1wave
      else if( vnam.eq.'SEC   ' .or. vnam.eq.'sec   ' )  then
                      read(buff(is:ie),fmti)  jsec
      else if( vnam.eq.'SHIFT ' .or. vnam.eq.'shift ' )  then
                      read(buff(is:ie),fmti)  shift
      else if( vnam.eq.'SIGMA1' .or. vnam.eq.'sigma1' )  then
                      read(buff(is:ie),fmtd)  sigma1
      else if( vnam.eq.'SIGMA2' .or. vnam.eq.'sigma2' )  then
                      read(buff(is:ie),fmtd)  sigma2
      else if( vnam.eq.'SLAT  ' .or. vnam.eq.'slat  ' )  then
                      read(buff(is:ie),fmtd)  slat
      else if( vnam.eq.'SLONG ' .or. vnam.eq.'slong ' )  then
                      read(buff(is:ie),fmtd)  slong
      else if( vnam.eq.'SPAN  ' .or. vnam.eq.'span  ' )  then
                      read(buff(is:ie),fmti)  span
      else if( vnam.eq.'SPECTW' .or. vnam.eq.'spectw' )  then
                      read(buff(is:ie),fmti)  spectw
      else if( vnam.eq.'TIMSYS' .or. vnam.eq.'timsys' )  then
                      read(buff(is:ie),fmtd)  timsys
      else if( vnam.eq.'WEIGHT' .or. vnam.eq.'weight' )  then
                      read(buff(is:ie),fmtd)  weight
      else if( vnam.eq.'YEAR  ' .or. vnam.eq.'year  ' )  then
                      read(buff(is:ie),fmti)  ja
      else if( vnam.eq.'ZERORM' .or. vnam.eq.'zerorm' )  then
                      read(buff(is:ie),fmti)  zerorm
      else
         write(8,92)  vnam, buff
   92    format(/' Warning in namels     symbol ',a6,
     1          ' not found',/,'  rec : ',a72)
      endif
c
      go to 40
c
c  get to the part below only if actual EOF encountered
c
  100 write(8,102)  buff
  102 format(/' ERROR in namels       no  &end',/,
     1        '  rec : ',a72)
      stop
c
c
      end
c===========================================================================
      subroutine prmchk( ith, order, span, shift, rlim, lpout, filout,
     *                   spectw, prepro, weight,
     *                   iaug, lagp, lagint, maxjmp,
     *                   kind, az, dmin, timsys, ifcr, qval, maxitr,
     *                   icetgr, s1wave, paglen, ipoten, p4flag, lovenm,
     *                   rsperr, sigma1, sigma2, zerorm, nsine,
     *                   igrp,ja,jb,jc,hr,jmin,jsec,ndata,delt,
     *                   slat,slong,sh,ge,inform)
c
      implicit double precision (a-h,o-z)
      integer  order, span, shift, filout, spectw, prepro, s1wave
      integer  paglen, p4flag, rsperr
      integer  zerorm
      if( dmin .ge. 250.d0 )  dmin = 128.d0
      if( dmin .le.   0.d0 )  dmin = 1.d0/256.d0
      if( filout .gt. 1 )     filout =  1
      if( filout .lt. 0 )     filout =  0
      if( iaug   .lt. 0 )     iaug   =  0
      if( iback  .lt. 0 )     iback  =  0
      if( iback  .gt. 1 )     iback  =  1
      if( icetgr .gt. 2 )     icetgr =  2
      if( icetgr .lt. 1 )     icetgr =  1
      if( ifcr   .gt. 1 )     ifcr   =  1
      if( ifcr   .lt. 0 )     ifcr   =  0
      if( igrp   .gt. 8 )     igrp   =  8
      if( igrp   .lt. 0 )     igrp   =  0
      if( inform .gt. 3 )     inform =  3
      if( inform .lt.-1 )     inform = -1
      if( ith    .gt. 1 )     ith    =  1
      if( ith    .lt. 0 )     ith    =  0
      if( ith    .eq. 0 )  then
         ifcr   = 0
         ipoten = 1
      endif
      if( ipoten .gt. 2 )     ipoten =  2
      if( ipoten .lt. 1 )     ipoten =  1
      if( ipoten .eq. 1 )  then
         p4flag = 0
      else
         if( p4flag. gt. 1 )  p4flag =  1
         if( p4flag. lt. 0 )  p4flag =  0
      endif
      if( kind   .gt. 8 )     kind   = 99
      if( kind   .lt. 1 )     kind   = 99
      if( kind.ge.4 .and. kind.le.6 )  lovenm = 1
      if( lagint .lt. 1 )     lagint =  1
      if( lagp   .lt. 0 )     lagp   =  0
      if( lovenm .gt. 2 )     lovenm =  0
      if( lovenm .lt. 0 )     lovenm =  0
      if( lpout  .gt. 2 )     lpout  =  2
      if( lpout  .lt. 0 )     lpout  =  0
      if( maxitr .gt.30 )     maxitr = 30
      if( maxitr .lt. 1 )     maxitr =  1
      if( maxjmp .lt. 0 )     maxjmp =  0
      if( ndata  .lt. 0 )     ndata  =  0
      if( nsine  .lt. 0 )     nsine  =  0
      if( order  .gt. 3 )     order  =  3
      if( order  .lt. 2 )     order  =  2
      if( paglen .gt.66 )     paglen = 66
      if( paglen .lt.66 )     paglen = 60
      if( prepro .gt. 3 )     prepro =  3
      if( prepro .lt. 0 )     prepro =  0
      if( qval   .gt.1.d5 )   qval   =  1.d5
      if( qval   .lt.1.d1 )   qval   =  1.d1
      if( rlim .lt. -1.d25 )  rlim   = -1.d25
      if( rlim .gt.  1.d25 )  rlim   =  1.d25
      if( rlim .lt. -1.d25 )  rlim   = -1.d25
      if( rsperr .ne. 0 )     rsperr =  1
      if( s1wave .gt. 1 )     s1wave =  1
      if( s1wave .lt. 0 )     s1wave =  0
      if( shift  .lt. 0 )     shift  =  0
      if( shift  .eq. 0 )  then
         filout = 0
         lpout  = 0
         prepro = 0
      endif
      if( sigma1 .le. 0.0d0 )  sigma1 = 1.d30
      if( sigma2 .le. 0.0d0 )  sigma2 = 1.d30
      if( span .ne. 0 )  then
        if( span  .lt. 24 )   span   = 24
        if( shift .gt. span ) shift  = span
      endif
      if( spectw .gt. 6 )     spectw =  6
      if( spectw .lt. 0 )     spectw =  0
      if( weight .gt. 1.d2 )  weight =  1.d2
      if( weight .lt. 0.d0 )  weight =  0.d0
      if( zerorm .gt. 1 )      zerorm = 1
      if( zerorm .lt. 0 )      zerorm = 0
c
      if( dabs(az).gt.360.d0 ) then
         write(8,100)  az
  100    format(/,' INVALID azimuth:          az   =',f10.1,/)
         stop
      endif
      if( nsine.gt.10 ) then
         write(8,102)  nsine
  102    format(/,' INVALID         nsine   =',i10,/)
         stop
      endif
      if( dabs(timsys).gt.24.d0 ) then
         write(8,110)  timsys
  110    format(/,' INVALID local time:     timsys =',f10.1/)
         stop
      endif
      if(dabs(slat).gt.90.d0.or.dabs(slong).ge.360.d0.or.
     1 dabs(sh).gt.8850.d0.or.ge.lt.977.d0.or.ge.gt.984.d0) then
         write(8,120) slat,slong,sh,ge
  120    format(/,' ERROR in coordinates/grav :',2f9.3,f6.0,f8.3,/)
         stop
      endif
      if(delt.lt.0.01d0.or.delt.gt.4.d0) then
         write(8,122) delt
  122    format(/,' ERROR in sample interval (hr) ',g13.4,/)
         stop
      endif
      if(ja.gt.2030.or.ja.lt.1900.or.jb.gt.12.or.jb.lt.1.or.jc.gt.31
     1  .or.jc.lt.1.or.hr.lt.0.d0.or.hr.gt.24.d0.or.jmin.lt.0.or.
     2      jmin.gt.60.or.jsec.lt.0.or.jsec.gt.60) then
         write(8,124) ja,jb,jc,hr,jmin,jsec
  124    format(/,' ERROR in start time, given as ',i4,2i3,f5.0,2i3,/)
         stop
      endif
c
c convert times to internal standard of y m d h
c
      hr=hr+(jmin+(jsec/60.d0))/60.d0
      return
      end
c===========================================================================
      subroutine setgrp( obslen, igrplv, icetgr, ipoten )
c
c     gets grouping of waves (auto)
c
      implicit double precision (a-h,o-z)
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
      parameter ( mtblen = 31 )
      character*8  symbol, ksymbl(maxgrp,8)
      character*8  ksym31,ksym32,ksym41,ksym42
      dimension kg2(maxgrp,8)
      common /stngrp/ ig1(36),ig2(36),ngroup,imwave(36)
      common /stngrc/ symbol(36)
c
c   common blocks to bring information from blockdata segments
c
      common/group31/kg231(maxgrp,8),ksym31(maxgrp,8)
      common/group32/kg232(maxgrp,8),ksym32(maxgrp,8)
      common/group41/kg241(maxgrp,8),ksym41(maxgrp,8)
      common/group42/kg242(maxgrp,8),ksym42(maxgrp,8)
c
      if( igrplv.eq.0 )  then
         j = 1
         if( obslen.ge.   8.d0 )  j = 2
         if( obslen.ge.  16.d0 )  j = 3
         if( obslen.ge. 180.d0 )  j = 4
         if( obslen.ge. 364.d0 )  j = 5
         if( obslen.ge.2000.d0 )  j = 6
      else if( igrplv.ge.-2 .and. igrplv.le.6 )  then
         j = igrplv + 2
         if( igrplv.lt.0 )  j = igrplv + 3
      else
         write(8,200) igrplv
  200    format(/' ERROR       stopped at setgrp     igrplv =', i5)
         stop
      endif
c
c
      if( icetgr.ge.1 .and. icetgr.le.2 )  then
         igx = icetgr
      else
         write(8,210)  icetgr
  210    format(/' Warning in setgrp           icetgr =',i8)
         igx = 1
      endif
c
c   get the group information wanted
c
      if( ipoten.eq.1 .and. igx.eq.1 )  then
        do i=1,maxgrp
         do k=1,8
           kg2(i,k)=kg231(i,k)
           ksymbl(i,k)=ksym31(i,k)
         enddo
        enddo
      else if( ipoten.eq.1 .and. igx.eq.2 )  then
        do i=1,maxgrp
         do k=1,8
           kg2(i,k)=kg232(i,k)
           ksymbl(i,k)=ksym32(i,k)
         enddo
        enddo
      else if( ipoten.eq.2 .and. igx.eq.1 )  then
        do i=1,maxgrp
         do k=1,8
           kg2(i,k)=kg241(i,k)
           ksymbl(i,k)=ksym41(i,k)
         enddo
        enddo
      else if( ipoten.eq.2 .and. igx.eq.2 )  then
        do i=1,maxgrp
         do k=1,8
           kg2(i,k)=kg242(i,k)
           ksymbl(i,k)=ksym42(i,k)
         enddo
        enddo
      endif
c
c     find number of groups
c
      do i = 1, maxgrp
         if( kg2(i,j).ne.0 ) ngroup = i
      enddo
      if( ngroup.gt.36 )  then
         write(8,240)
  240    format(/' ERROR in setgrp          too many groups')
         stop
      endif
      do i = 1, ngroup
        ig2(i) = kg2(i,j)
        symbol(i) = ksymbl(i,j)
      enddo
      ig1(1) = 1
      do i = 2, ngroup
        ig1(i) = kg2(i-1,j) + 1
      enddo
      return
      end
c===========================================================================
      subroutine tbread( ipoten )
      implicit double precision (a-h,o-z)
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     1                gc(4,4),idn(919,8),ip(919)
c
c  common blocks from blockdata
c 
      common/hart3/avc3(377),amc3(377),ip3(377),idn3(377,6)
      common/hart4/avc4(919),amc4(919),amc24(919),ip4(919),idn4(919,8)
c
      if( ipoten.eq.1 )  then
         do i = 1,377
            avc(i)=avc3(i)
            amc(i)=amc3(i)
            do j=1,6
              idn(i,j)=idn3(i,j)
            enddo
            ip(i)=ip3(i)
         enddo
      else if( ipoten.eq.2 )  then
c  only do 1-909 since we do not use order-4
         do i = 1,909
            avc(i)=avc4(i)
            amc(i)=amc4(i)
            amc2(i)=amc24(i)
            do j=1,8
              idn(i,j)=idn4(i,j)
            enddo
            ip(i)=ip4(i)
         enddo
      else
         write(8,130)
  130    format(/' ERROR     ipoten?')
         stop
      endif
      return
      end
c===========================================================================
      subroutine setmwv( ipoten )
c
c     imwave(i) : main wave no. in each group
c                 except( mu2 ---> 2n2 )
c
      implicit double precision (a-h,o-z)
c
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /stngrp/ ig1(36),ig2(36),ngroup,imwave(36)
c
c
      if( ipoten.eq.1 )  then
         iwn1 = 240
         iwn2 = 233
         iwn3 = 377
      else if( ipoten.eq.2 )  then
         iwn1 = 534
         iwn2 = 520
         iwn3 = 909
      endif
c
c
      do i = 1, ngroup
         js = ig1(i)
         je = ig2(i)
         nw = 0
         amp = 0.d0
         do j = js, je
            if( dabs(amc(j)).lt.amp )  go to 10
            amp = dabs(amc(j))
            nw = j
   10       continue
         enddo
         if( nw.eq.iwn1 .and. js.le.iwn2 )  nw = iwn2
         if( nw.lt.1 .or. nw.gt.iwn3 )  then
            write(8,200)  i, nw
  200       format(/' ERROR at setmwv        i, nw =', 2i6 )
            stop
         endif
         imwave(i) = nw
      enddo
      return
      end
c===========================================================================
      subroutine datar2( rat,y,iy,ndata,rlim,la,lb,lc,hlr,delt,nfile,
     *                   slat,slong,sh,g, kind,az, zerorm)
c
c     this subroutine reads data y from unit number mt
c
c     inputs
c       iy     :  0: tidal data;  1: auxiliary data
c       slat,slong,ht--may be set as parameters, will be overriden if'
c            these are set in format types -1 through 2
c
c  From common block:
c
c       iformt :  format type; set as parameter or (old version)
c                 read here from control file
c                 types arei:
c                  3 free-format with title line
c                  1 free-format with fixed header
c                  0 fixed format, 4 decimals
c                 -1 fixed format, 5 decimals
c                  2 fixed format, 7 decimals
c
c     outputs
c
c       y     :  data vector
c       ndata :  data length
c
      implicit double precision (a-h,o-z)
c
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  1250 )
cc    parameter ( lbuff =  4500 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( lbuff = 18000 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
      parameter ( maxclb = 100 )
c
      dimension  y(*), rat(*)
      dimension  etal(maxclb),  tje(maxclb)
      dimension  jacal(maxclb), jbcal(maxclb), jccal(maxclb)
      dimension  hdcal(maxclb)
      dimension  deltck(6), x1(12)
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
      dimension auxmen(maxaux)
      real       yt(lbuff,2,maxgr2)
      integer    zerorm
c
      character*4   xa(12), dummy
      character*10  cckind
      character*80  title
c
      save  dif, jabcls,mt,ifrst
c
C      common /lpcnt/  lpout
      common /inform/ iformt, netalt, etalt(maxclb), tjet(maxclb)
      common /bufota/ yo, yt, ya, incore
      common /prstep/ step00
      common/backcom/iback
      common /auxil/  auxmen,naux
c
      data  irat   / 0 /
      data  deltck / 0.5d0, 1.d0, 1.5d0, 2.d0, 3.d0, 6.d0 /
      data  eps12  / 1.d-12 /
      data  ifrst  / 0 /
      data  imk/0/
c
c    read format flag and step flag from control file (old format)
c
      istflg = 0
      iform=iformt
      if(iback.eq.1) then
         read(7,5000,err=5001)  iform, istflg
 5000    format(5x,2i5)
      endif
 5001 if(iform.eq.2.and.iback.eq.1)  then
         read(7,5000)  mtc
         if( mtc.le.0 .or. mtc.eq.5 .or. mtc.eq.16
     *      .or. (mtc.ge.30 .and. mtc.le.34)
     *      .or. mtc.eq.95 .or. mtc.ge.100        )  then
            write(8,6000)  mtc
 6000       format(/' invalid i/o unit number       unit =',i5)
            stop
         endif
      endif
c
c set unit numbers for data (5) and aux series (11-13, done by incrementing)
c 
      if(iy.eq.0) then
        mt=5
        if(iback.eq.1) iformt=iform
      endif
      if(iy.eq.1) then
        if(ifrst.eq.0) then
          ifrst=1
          mt=10
        endif
        mt=mt+1
      endif
c
c    get title of dataset--first line of all files
c
      do i = 1, 80
        title(i:i) = ' '
      enddo
      read(mt,5010,err=5008)  (title(i:i),i=1,80)
 5010 format(80a1)
 5008 if(iy.eq.0) write(8,6010)  title
 6010 format(//' *****  Top of tidal data  *****' // ' ',a80)
      if(iy.eq.1) write(8,6012)  title
 6012 format(//' *****  Top of auxiliary data  *****' // ' ',a80)
c
c    latitude, longitude, altitude, gravity (fixed and fixed/free)
c      kind also read in fixed format, mode 2
c
      if(iform.ne.3) then
         g      = 0.d0
         cckind = '          '
         read(mt,5020,err=5018)  slat, slong, sh, g, cckind
 5020    format(4f10.0,a10)
 5018    if( g.eq.0.d0 )  g = fnormg( slat, sh )
         write(8,6020)  slat, slong, sh, g
 6020    format(/'   latitude  longitude    height   gravity' /
     *           f11.4,f11.4,f10.2,f10.4 / )
c
         ill = 0
         if( dabs(slat) .gt.  90.d0 )  ill = 1
         if( dabs(slong).ge. 360.d0 )  ill = 1
         if( dabs(sh)   .gt.9999.d0 )  ill = 1
         if( g.lt.977.d0 .or. g.ge.984.d0 )  ill = 1
         if( ill.ne.0 )  then
            write(8,6030)
 6030       format(/' ERROR: geographical parameters may be wrong')
            stop
         endif
      endif
c
c    free format
c
      irat = irat + 1
      if( iform.eq.3 )  then
          if(iy.eq.0) write(8,6020)  slat, slong, sh, g
          call datar3(rat,irat,y,iy,ndata,rlim,la,lb,lc,hlr,delt,
     *               nfile,mt,dif, zerorm)
          if( iy.eq.0 )  step00 = 0.d0
          return
      endif
c
c    fixed/free (aka user-defined) format
c
      if( iform.eq.1 )  then
          call datar(rat,irat,y,iy,ndata,rlim,la,lb,lc,hlr,delt,
     *               nfile,mt,dif, zerorm)
          if( iy.eq.0 )  step00 = 0.d0
          return
      endif
c
c    rest of this routine is for fixed format
c
c    kind of tidal dataset from header for iform = 2
c
      if( kind.eq.99 .and. iform.eq.2 .and. iy.eq.0 )  then
         if( cckind(1:7).eq.'gravity' )  kind = 1
         if( cckind(1:5).eq.'tilt ' )  then
            if( cckind(6:7).eq.'ns' )  then
               kind = 2
            else if( cckind(6:7).eq.'ew' )  then
               kind = 3
            else
               kind = 2
               read(cckind(6:10),'(f5.1)')  az
            endif
         endif
         if( cckind(1:6).eq.'strain' )  kind = 7
         if( cckind(1:6).eq.'ocean ' )  kind = 8
      endif
      if( kind.le.0 .or. kind.ge.9 )  then
         write(8,6040)  kind
 6040    format(/' ERROR invalid kind      kind =',i5)
         stop
      endif
c
c    start time, sampling interval
c
      if( hlr.lt.0.d0 .or. hlr.gt.23.5d0 )  then
         write(8,6050)  hlr
 6050    format(/' ERROR at datar2      invalid time      hour =',
     1          f8.1)
         stop
      endif
c
      ill = 1
      do i = 1, 6
         if( dabs( delt - deltck(i) ) .lt. eps12 )  ill = 0
      enddo
      if( ill.ne.0 )  then
         write(8,6060)  delt
 6060    format(/' ERROR at datar2      invalid sampling interval',
     1           '      delt =', f8.1 )
         stop
      endif
c
      hlrc = delt * dble( idint( (hlr+0.001d0) / delt ) )
      if( dabs(hlrc-hlr) .gt. eps12 )  write(8,6070)  hlrc
 6070 format(/' warning     beginning time is exchanged',
     *        '     time =',f5.1 /)
      hlr = hlrc
c
      iymda = la*10000 + lb*100 + lc
      iymda = iymda*10 + idint( (hlr+0.001d0)/6.d0 ) + 1
      isampl= idint( (delt+0.001d0)/0.5d0 )
c
c
c    calibration data
c
      if( iform.eq.2 )  then
         read(mtc,5060)  dummy
 5060    format(a4)
         read(mtc,5060)  dummy
         dummy = dummy
         i = 1
   20    read(mtc,5080,end=40)  ja,jb,jc,hd,  etal(i)
 5080    format(3i5,f5.0,f10.5)
         tje(i) = tjul(ja,jb,jc,hd)
         jacal(i) = ja
         jbcal(i) = jb
         jccal(i) = jc
         hdcal(i) = hd
         netal = i
         i = i + 1
         if( i.le.maxclb )  go to 20
         write(8,6090)  i
 6090    format(/' ERROR: too many calibration values    n =',i5/
     *        ' modify maxclb in parameter statements')
         stop
      else
         read(mt,5070)  netal
 5070    format(i5)
         do i = 1, netal
            if( i.gt.maxclb )  then
               write(8,6090)  i
               stop
            endif
            read(mt,5080)  ja,jb,jc,hd,  etal(i)
            tje(i) = tjul(ja,jb,jc,hd)
            jacal(i) = ja
            jbcal(i) = jb
            jccal(i) = jc
            hdcal(i) = hd
         enddo
      endif
c
   40 if( netal.lt.2 )  then
         write(8,6100)  netal
 6100    format(/' ERROR too few calibration cards      n =',i5)
         stop
      else if( netal.le.6 )  then
         do i = 1, netal
           write(8,6080) jacal(i),jbcal(i),jccal(i),hdcal(i),etal(i)
 6080      format(' y,m,d,hr =', i6,i4,i4,  f6.1,'      calib.=',
     1            1pd13.5)
         enddo
      else
         netalx = netal/2
         netaly = netal - netalx*2
         do i = 1, netalx
           j = i + netalx + netaly
           write(8,6082)  jacal(i),jbcal(i),jccal(i),hdcal(i), etal(i),
     *                    jacal(j),jbcal(j),jccal(j),hdcal(j), etal(j)
 6082      format(' y,m,d,hr =', i6,i4,i4,  f6.1,'      calib.=',
     1            1pd13.5, 12x,'y,m,d,hr =', i6,i4,i4,0pf6.1,
     2            '      calib.=',1pd13.5)
         enddo
         if( netaly.eq.1 )
     *     write(8,6080)  jacal(i),jbcal(i),jccal(i),hdcal(i), etal(i)
      endif
c
      netal1 = netal - 1
c
c
c    preparation
c
      jmpchk = 0
      dt     = 0.5d0/24.d0
      iend   = 12/isampl
      ysum   =  0.d0
      ymax   = -1.d25
      ymin   =  1.d25
      num    = 0
      iplus  = idint( ( dmod( hlr+0.001d0, 6.d0 ) + 0.001d0 ) / delt )
      klim   = ( ndata + iplus - 1 ) / iend + 1
      ndatax = 0
      kkk    = 0
      jabc0  = 0
      step   = 0.d0
      netalk = 1
c
c---------------------
c    data reading    |
c---------------------
c
 1000 continue
c
c    data read
c
      if( iform.eq.0 )  then
         read(mt,5200,end=1100) (x1(m),m=1,12),nst,stval,ja,jb,jc,ihc,
     *                          (xa(m),m=1,12), jabc
 5200    format( 12f4.1,i3,f5.1,17x,3i2,i1, t1,12a4,25x,i7 )
         if( xa(1).eq.'9999' )  go to 1100
      else if( iform.eq.-1 )  then
         read(mt,5210,end=1100) (x1(m),m=1,12),nst,stval,ja,jb,jc,ihc,
     *                          (xa(m),m=1,12), jabc
 5210    format( 12f5.1,i3,f5.1,5x,3i2,i1, t1,12(1x,a4),13x,i7 )
         if( x1(1).ge.9999.0 )  go to 1100
      else if( iform.eq.2 )  then
         read(mt,5220,end=1100) ja,jb,jc,ihc,(x1(m),m=1,12),nst,stval,
     *                          jabc, (xa(m),m=1,12)
 5220    format( 3i2,i1,12(f7.1,1x),i2,f8.1, t1,i7,3x,12(a4,4x) )
         if( jabc.ge.9999000 )  go to 1100
c         format(  3i2   i1   12(f7.1,1x)  i2  f8.1    i7    12(a4,4x)
c               y  m  d  1-4   data        stp  offs  ???     ???

      else
         write(8,6200)  iform
 6200    format(/'ERROR    invalid format specification    iform =',i5)
         stop
      endif
c
c
c     check date sequence
      if( jabc0.ne.0 )  then
         if( ihc.le.0 )  then
            write(8,6300)  mt, jabc0, jabc
 6300       format(/' sequence of data is wrong',
     *           '        i/o unit =',i3,'     date =',i8,' /',i8)
            stop
         else if( ihc.eq.1 )  then
            if( jabc0+7.ne.jabc )  then
               if( jc.ne.1 )  then
                  write(8,6300)  mt, jabc0, jabc
                  stop
               endif
               jalx  = jabc0/100000
               jabc0 = jabc0 - jalx*100000
               jblx  = jabc0/1000
               jclx  = (jabc0-jblx*1000)/10
               timlx = tjul( jalx, jblx, jclx, 0.d0 )
               timnw = tjul( ja,   jb,   jc,   0.d0 )
               if( dabs(timnw-timlx-1.d0) .ge. 1.d-12 )  then
                  write(8,6300)  mt, jabc0, jabc
                  stop
               endif
            endif
         else if( ihc.le.4 )  then
            if( jabc0+1.ne.jabc )  then
               write(8,6300)  mt, jabc0, jabc
               stop
            endif
         else
            write(8,6300)  mt, jabc0, jabc
            stop
         endif
      endif
c
      if( nst.lt.0 .or. nst.gt.12 )  then
         write(8,6310)  mt, jabc
 6310    format(/' position of step is wrong',
     *        '        i/o unit =',i3,'     date =',i8)
         stop
      endif
      jabc0 = jabc
c
c
c    skip ?
c
      if(jabc.lt.iymda)  then
         if( nst.eq.0 )       go to 1000
         if( stval.eq.0.d0 )  go to 1000
         hd = 0.5d0 * dble( 12*ihc + nst - 13 )
         t  = tjul( ja, jb, jc, hd )
         do 50 k = netalk, netal1
            if( t.ge.tje(k) .and. t.lt.tje(k+1) )  go to 60
   50       continue
            write(8,6500)
            stop
   60    netalk = k
         det    = ( etal(k+1) - etal(k) ) / ( tje(k+1) - tje(k) )
         sense  = det*( t - tje(k) ) + etal(k)
         step   = step + stval*sense
         go to 1000
      endif
 6500 format(/' invalid calibration card      stopped at datar2')
c
c    end ?, start date check, step
c
      if(kkk.gt.klim)  go to 1100
      kkk = kkk + 1
      if( kkk.eq.1 )  then
         if( iy.eq.0 )  step00 = step
         if( jabc.gt.iymda )  then
            hlr   = dble( (ihc-1)*6 )
            iplus = 0
         endif
         if( iy.eq.0 )  jabcls = jabc
         if( jabcls.ne.jabc )  then
            write(8,6400)
            stop
         endif
         jabcls = jabc
         la = ja
         lb = jb
         lc = jc
      endif
 6400 format(/' ERROR at datar2          incompatible beginning date')
c
c    multiplication of sensitivity
c
      hd  = dble( (ihc-1)*6 )
      tj0 = tjul(ja,jb,jc,hd)
      if( nst.eq.0 )  then
         mskip = isampl
        else
         mskip = 1
      endif
      do 80 m = 1, 12, mskip
         t = tj0 + dt*(m-1)
         do 70 k = netalk, netal1
            if( t.ge.tje(k) .and. t.lt.tje(k+1) )  go to 72
   70       continue
            write(8,6500)
            stop
   72    netalk = k
         det    = ( etal(k+1) - etal(k) ) / ( tje(k+1) - tje(k) )
         sense  = det*( t - tje(k) ) + etal(k)
         if( m.eq.nst )  step = step + stval*sense
         x1(m)  = x1(m)*sense + step
   80 continue
c
c    position of step
c
c      nst  0  1  2  3  4  5  6  7  8  9 10 11 12   original position
c     nstc  0  1  2  3  4  5  6  7  8  9 10 11 12   for isampl =  1
c     nstc  0  1  1  3  3  5  5  7  7  9  9 11 11              =  2
c     nstc  0  1  1  1  4  4  4  7  7  7 10 10 10              =  3
c     nstc  0  1  1  1  1  5  5  5  5  9  9  9  9              =  4
c     nstc  0  1  1  1  1  1  1  7  7  7  7  7  7              =  6
c     nstc  0  1  1  1  1  1  1  1  1  1  1  1  1              = 12
c
      if( nst.eq.0 )  then
         nstc = 0
      else
         nstc = nst - mod( nst-1, isampl )
      endif
c
c    resampling
c
      do 180 i = 1, 12, isampl
         x1i = x1(i)
c
cc       if( xa(i).ne.'    ' )  then
c           normal data
cc          num  = num + 1
cc          ysum = ysum + x1i
cc          ymax = dmax1( ymax, x1i )
cc          ymin = dmin1( ymin, x1i )
cc       else
c           no observation
cc          x1i = 1.d30
cc       endif
c
         if(   xa(i).eq.'    ' .or.
     *       ( zerorm.eq.1 .and. dabs(x1i).lt.1.0d-14 )  )  then
c           no observation
            x1i = 1.d30
         else
c           normal data
            num  = num + 1
            ysum = ysum + x1i
            ymax = dmax1( ymax, x1i )
            ymin = dmin1( ymin, x1i )
         endif
c
         if( iy.eq.0 )  then
            if( i.eq.nstc .and. jmpchk.eq.1 )  then
c              step mark
               if( stval.eq.0.d0 .or. istflg.eq.1 )  x1i = -1.d30
            endif
         else
            if( i.eq.nstc .and. jmpchk.eq.1 .and. stval.eq.0.d0 )  then
               write(8,6600)  mt, jabc
 6600          format(/' warning    i/o unit =', i3,
     *                 '        step correction value of ',
     *                 'auxiliary data are missing       date =', i8 )
               x1i = 1.d30
            endif
         endif
c
         ndatax = ndatax + 1
         if( x1i.lt.1.d20 .and. ndatax.gt.iplus )  jmpchk = 1
         y(ndatax) = x1i
  180 continue
c
      go to 1000
c
c-----------------------------
c    end of data,  saving    |
c-----------------------------
c
 1100 continue
      if( num.le.0 )  then
         write(8,6700)
 6700    format(/' ERROR in datar2:          no data')
         stop
      endif
c
c    normalization
c
      dif0 = ymax - ymin
      if( iy.eq.0 )  dif = dif0
      ratio     = dif/dif0
      rat(irat) = ratio
      if( iy.eq.0 )  then
         write(8,6800)  ratio
 6800    format(/' tidal data has range ratio =',1pd12.4)
      else
         ymean = ysum/num
         imk=imk+1
         auxmen(imk)=ymean
         do i = 1, ndata
            if( dabs(y(i)) .le. 1.d25 )  y(i) = (y(i)-ymean)*ratio
         enddo
         write(8,6810)  ratio, ymean
 6810    format(/' auxiliary data has',
     *           ' range ratio =',1pd12.4,
     *           ' and mean value =',d12.4)
      endif
c
c    saving
c
      nfile = nfile + 1
      if(ndata .gt. ndatax-iplus)  ndata = ndatax - iplus
c
c
      if( iy. eq. 0 )  call ystpck( y(iplus+1), ndata, 1 )
c
c do not check subscript ranges if incore=1
c
      if( incore.eq.1 )  then
         if(iy.eq.0)  then
            do i = 1, ndata
               yo(i,1) = y(i+iplus)
            enddo
         else
            do i = 1, ndata
               ya(i,1,nfile-31) = y(i+iplus)
            enddo
         endif
      else
         nblock = (ndata-1)/lbuff + 1
         is = iplus + 1
         ie = lbuff + iplus
         do j = 1, nblock
            write(nfile)  ( y(i), i = is, ie )
            is = is + lbuff
            ie = ie + lbuff
         enddo
         rewind nfile
      endif
      if( iy.eq.0 )  then
         netalt = netal
         do i = 1, netal
            etalt(i) = etal(i)
            tjet(i)  = tje(i)
         enddo
      endif
      return
      end
c
      double precision function fnormg( anorth, height )
      implicit double precision (a-h,o-z)
      data  r1, r2 / 6378137.d0,     6356752.3141d0 /
      data  g1, g2 / 978.03267715d0, 983.21863685d0 /
      slatit = anorth * 3.14159 26535 89793 d0 / 180.d0
      fnormg = ( r1*g1*dcos(slatit)**2 + r2*g2*dsin(slatit)**2 )
     *   / dsqrt( ( r1*dcos(slatit) )**2 + ( r2*dsin(slatit) )**2 )
     *   - 0.3086d-3*height
      return
      end
c
      double precision function tjul( ja, jb, jc, hr )
c
c       ja   :  last two digits of the year : 1901-1999
c            :       four digits            : 1901-2099
c       jb   :    month
c       jc   :    day
c       hr   :    hour
c
c     julian date in ut from 1900. jan. 0.5
c
      implicit double precision (a-h,o-z)
      dimension  nm(12)
      data  nm/0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334/
      jac = mod( ja, 1900 )
      ill = 0
      if( jac.lt.1 .or. jac.gt.199)  ill = 1
      if( jb.lt.1  .or. jb .gt.12 )  ill = 1
      if( jc.lt.1  .or. jc .gt.31 )  ill = 1
ccc   if( hr.lt.0.d0 .or. hr.gt.24.d0 )  ill = 1
      if( ill.ne.0 ) then
          write(8,100)  ja, jb, jc, hr
  100     format(/' INVALID DATE y,m,d,h =', 3i6, f6.1,' in tjul')
          stop
      endif
      ie = (jac-1)/4
      if( mod(jac,4).eq.0 .and. jb.ge.3 )  ie = ie+1
      jt = 365*jac + ie + nm(jb) + jc
      tj = dble(jt)
      tjul = tj + hr/24.d0 - 0.5d0
      return
      end
c===========================================================================
      subroutine datar(rat,irat,y,iy,ndata,rlim,la,lb,lc,hlr,delt,
     *                 nfile,mt,dif, zerorm)
c
c     this subroutine reads data y from mt.
c     inputs:
c       iy:     0:tidal data;  1:auxiliary data
c       mt:     input device specification
c     outputs:
c       y:      data vector
c       ndata:  data length
c
      implicit double precision (a-h,o-z)
c
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  1250 )
cc    parameter ( lbuff =  4500 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( lbuff = 18000 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
c
      dimension  y(*), rat(*)
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
      real       yt(lbuff,2,maxgr2)
      integer    zerorm
      dimension auxmen(maxaux)
c
      character*80  fmt
c
C      common  /lpcnt/   lpout
      common  /bufota/  yo, yt, ya, incore
      common /auxil/  auxmen,naux
c
      data imk/0/
      data    eps7 /1.d-7/
c
      ymdh = la*10000 + lb*100 + lc + hlr/24.d0
      read(mt,502)  ja, jb, jc, hr0
  502 format(3i5,f10.0)
      ja = mod( ja, 1900 )
      ymdh0 = ja*10000 + jb*100 + jc + hr0/24.d0
      read(mt,501)  ndata0, delt0, rlim
  501 format(i5,f5.0,d15.5)
      kan  = idint( delt/delt0 + eps7 )
      gosa = dabs( delt - delt0*dble(kan) )
      if( gosa.gt.eps7 )  then
         write(8,100)  delt, delt0, kan
         stop
      endif
  100 format(/' invalid sampling interval         stopped at datar'/
     *        ' delt, delt0, kan =', f10.2, f10.2, i8 )
c
c     recover in case of variable record length (recfm=vb)
      do i = 1, 80
         fmt(i:i) = ' '
      enddo
      read(mt,'(72a1)',err=518)  (fmt(i:i),i=1,72)
  518 read(mt,fmt)  (y(i),i=1,ndata0)
      is = 0
      if( ymdh .le. ymdh0+eps7 )  then
         la  = ja
         lb  = jb
         lc  = jc
         hlr = hr0
ccc      if( ymdh .lt. ymdh0-eps7 )  write(8,102)  la, lb, lc, hlr
         if( ymdh .lt. ymdh0-eps7 )  write(8,102)  1900+la, lb, lc, hlr
      else
   11    is = is + 1
         call update(ja,jb,jc,hr0,delt0)
         ymdh0 = ja*10000 + jb*100 + jc + hr0/24.d0
         if( ymdh .gt. ymdh0+eps7 )  go to 11
         if( ymdh .lt. ymdh0-eps7 )  then
            la  = ja
            lb  = jb
            lc  = jc
            hlr = hr0
ccc         write(8,102)  la, lb, lc, hlr
            write(8,102)  1900+la, lb, lc, hlr
         endif
      endif
  102 format(/' start date was changed      y,m,d,h = ',3i5,f6.1/)
      if( kan*(ndata-1)+1 .gt. ndata0-is )  ndata = (ndata0-is)/kan
c
ccc
      if( ndata .le. 1 )  then
          write(8,7000)
          stop
      endif
 7000 format(//'   ERROR      data period and analysis period',
     *         ' are inconsistent' )
ccc
c
c     resampling
c
      jj = is + 1
      y(1) = y(jj)
      if( kan.eq.1 .or. rlim.le.0.d0 )  then
         do j = 2, ndata
            jj = jj + kan
            y(j) = y(jj)
         enddo
      else
         do j = 2, ndata
            ymin = 0.d0
            do kk = jj+1, jj+kan-1
               ymin = dmin1( ymin, y(kk) )
            enddo
            jj = jj + kan
            if( ymin.lt.-rlim )  then
               y(j) = ymin
            else
               y(j) = y(jj)
            endif
         enddo
      endif
c
c finding the mean
c
      rnum = 0.d0
      ysum = 0.d0
      jchk = 0
      ymax = -1.d25
      ymin =  1.d25
      do i = 1, ndata
        if(rlim.gt.0.d0 .and. y(i).lt.-rlim)  then
          if( jchk.eq.0 )  then
c            step --> no obs
             y(i) = 1.d30
          else
c            real step 
             y(i) =-1.d30
             jchk = 0
          endif
        endif   
        if( rlim.gt.0.d0 .and. y(i).gt. rlim )        y(i) = 1.d30
        if( zerorm.eq.1 .and. dabs(y(i)).lt.1.0d-14 ) y(i) = 1.d30
        if( dabs(y(i)) .le. 1.d25 )  then
          jchk = 1
          ymax = dmax1( ymax, y(i) )
          ymin = dmin1( ymin, y(i) )
          ysum = ysum + y(i)
          rnum = rnum + 1.d0
        endif
      enddo
c
c
ccc   if( iy. eq. 0 )  call ystpck( y(1), ndata, 1 )
c
c
      dif0 = ymax - ymin
      if( iy.eq.0 )  dif = dif0
      ratio = dif/dif0
      rat(irat) = ratio
      if( iy.ne.0 )  then
         ymean = ysum/rnum
         imk=imk+1
         auxmen(imk)=ymean
         do i = 1, ndata
            if( dabs(y(i)) .lt. 1.d25 )  y(i) = (y(i)-ymean)*ratio
         enddo
      endif
c
      if( iy.eq.0 )  write(8,6072)  ratio
 6072 format(/' tidal data has range ratio  ',1pd12.4)
      if( iy.ne.0 )  write(8,6074)  ratio, ymean
 6074 format(/' auxiliary data has ',
     *        'range ratio  ',1pd12.4,
     *        ' and mean value ',d12.4)
c
      nfile = nfile + 1
c
c if in core, do not check subscript range
c
      if( incore.eq.1 )  then
         if(iy.eq.0)  then
            do i = 1, ndata
               yo(i,1) = y(i)
            enddo
         else
            do i = 1, ndata
               ya(i,1,nfile-31) = y(i)
            enddo
         endif
      else
         nblock = (ndata-1)/lbuff + 1
         is = 1
         ie = lbuff
         do j = 1, nblock
            write(nfile)  ( y(i), i = is, ie )
            is = is + lbuff
            ie = ie + lbuff
         enddo
         rewind nfile
      endif
      return
      end
c===========================================================================
      subroutine datar3(rat,irat,y,iy,ndata,rlim,la,lb,lc,hlr,delt,
     1                 nfile,mt,dif, zerorm)
c
c     this subroutine reads data y from mt; the file is assumed to
c    contain data only (following one line of tidal information, read
c    in the calling program datar2)
c     inputs:
c       iy:     0 indicates tidal data,  1 auxiliary data
c       mt:     input device number
c       rlim:   max absolute value of data; larger values are flagged as
c               missing
c
c     outputs:
c       y:      data vector
c       ndata:  data length
c
      implicit double precision (a-h,o-z)
c
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  1250 )
cc    parameter ( lbuff =  4500 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( lbuff = 18000 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
c
      dimension  y(*), rat(*)
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
      real       yt(lbuff,2,maxgr2)
      integer    zerorm
      dimension auxmen(maxaux)
c
      common  /bufota/  yo, yt, ya, incore
      common /auxil/  auxmen,naux
      data imk/0/
c
      read(mt,*)  (y(i),i=1,ndata)
c
      rnum = 0.d0
      ysum = 0.d0
      jchk = 0
      ymax = -1.d25
      ymin =  1.d25
      do i = 1, ndata
        if(rlim.gt.0.d0 .and. y(i).lt.-rlim)  then
           if( jchk.eq.0 )  then
c             step --> no obs
              y(i) = 1.d30
           else
c             real step 
              y(i) =-1.d30
              jchk = 0
           endif
        endif   
        if( rlim.gt.0.d0 .and. y(i).gt. rlim )          y(i) = 1.d30
        if(  zerorm.eq.1 .and. dabs(y(i)).lt.1.0d-14 )  y(i) = 1.d30
        if( dabs(y(i)) .le. 1.d25 )  then
           jchk = 1
           ymax = dmax1( ymax, y(i) )
           ymin = dmin1( ymin, y(i) )
           ysum = ysum + y(i)
           rnum = rnum + 1.d0
        endif
      enddo
      dif0 = ymax - ymin
      if( iy.eq.0 )  dif = dif0
      ratio = dif/dif0
      rat(irat) = ratio
      if(iy.ne.0)  then
         ymean = ysum/rnum
         imk=imk+1
         auxmen(imk)=ymean
         do i = 1, ndata
            if( dabs(y(i)) .lt. 1.d25 )  y(i) = (y(i)-ymean)*ratio
         enddo
      endif
c
      if( iy.eq.0 )  write(8,6072)  ratio
 6072 format(/' tidal data has range ratio  ',1pd12.4)
      if( iy.ne.0 )  write(8,6074)  ratio, ymean
 6074 format(/' auxiliary data has ',
     *        'range ratio  ',1pd12.4,
     *        ' and mean value ',d12.4)
c
c  either load internal arrays, or write to scratch files
c   subscript range not checked for internal arrays
c
      nfile = nfile + 1
      if( incore.eq.1 )  then
         if(iy.eq.0)  then
            do i = 1, ndata
               yo(i,1) = y(i)
            enddo
         else
            do i = 1, ndata
              ya(i,1,nfile-31) = y(i)
            enddo
         endif
      else
         nblock = (ndata-1)/lbuff + 1
         is = 1
         ie = lbuff
         do j = 1, nblock
            write(nfile)  ( y(i), i = is, ie )
            is = is + lbuff
            ie = ie + lbuff
         enddo
         rewind nfile
      endif
      return
      end
c===========================================================================
      subroutine update( ja, jb, jc, hr, delt )
      implicit double precision (a-h,o-z)
      dimension    month(12)
      data month / 31,28,31,30,31,30,31,31,30,31,30,31 /
      data eps9  / 1.d-9 /
c
      hr = hr + delt
      if( hr .lt. 24.d0-eps9 )  return
c
    1 hr = hr - 24.d0
      if( dabs(hr) .lt. eps9 )  hr = 0.d0
      jc = jc + 1
      if( hr .ge. 24.d0 )  go to 1
c
    2 m = month(jb)
      if( jb .eq. 2 .and. mod(ja,4) .eq. 0 )  m = m + 1
      if( jc .le. m )   return
c
      jc = jc - m
      jb = jb + 1
      if( jb .le. 12 )  go to 2
c
      jb = 1
      ja = ja + 1
ccc   if( ja .ge. 100 )  ja = mod( ja, 100 )
      go to 2
      end
c===========================================================================
      subroutine ystpck( y, num, mode )
c
c     check of duplicate steps
c
      implicit double precision (a-h,o-z)
      dimension  y(*)
c
cc    write(8,200)
cc    write(8,210)  (y(i), i= 1, num )
cc    write(8,220)
cc200 format(/'  debug output    ystpck (y step check)')
cc210 format(1p6d13.4)
cc220 format(/)
c
c        first block
c
      if( mode .eq. 1 )  then
         istep = 1
      else
         istep = 0
      endif
      do i = 1, num
         if( y(i) .lt. -1.d25 )  then
            if( istep .eq. 0 )  then
c  first step, real step
               istep = 1
            else
c  duplicate step  --> no obs
               y(i) = 1.d30
            endif
         else if( y(i) .le. 1.d25 )  then
c  normal data
            istep = 0
         endif
      enddo
      return
      end
c===========================================================================
      subroutine geogr1( ic, ph, att, ge, az, lovenm )
      implicit double precision (a-h,o-z)
      double precision  k2, k3
      double precision  l2, l3
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /phase0/ phcorr(4,4)
      data  er / 6378160.0d0 /,   ec/3.35289d-03/
      data  k2, k3 / 0.299d0,  0.093d0  /
      data  h2, h3 / 0.606d0,  0.291d0  /
      data  l2, l3 / 0.0840d0, 0.0149d0 /
      data  rad/0.017453292519943d0/
c
c     unit gravity : microgal  tilt : msecarc  strain : 10**(-9)
c          hight :  m  ge : cm/(sec*sec)
c
      fai = ph
      if( fai.ge. 90.d0 )  fai =  89.9999d0
      if( fai.le.-90.d0 )  fai = -89.9999d0
      if( fai.eq.  0.d0 )  fai =   0.0001d0
c
      fg = fai*rad
      ff = (1.d0-ec)**2*dtan(fg)
      fc = datan(ff)
      ep = fg-fc
      ce = dcos(ep)
      se = dsin(ep)
      rc = 1.d0-ec*dsin(fg)**2+att/er
      do j = 1, 3
         do i = 1, 3
           gc(i,j) = 0.d0
           phcorr(i,j) = 0.d0
         enddo
      enddo
      cf  = dcos(fc)
      sf  = dsin(fc)
      c21 = dsin(2.d0*fc)
      c22 = cf*cf
      c31 = cf*(1.d0-5.d0*sf*sf)
      c32 = sf*cf*cf
      c33 = c22*cf
      s21 = dcos(2.d0*fc)
      s31 = sf*(15.d0*c22-4.d0)
      s32 = cf*(1.d0-3.d0*sf*sf)
      s33 = c32
c
      if(ic.eq.1) go to 1
      if(ic.eq.2.or.ic.eq.3) go to 23
      if(ic.eq.4.or.ic.eq.5.or.ic.eq.6) go to 4
      if(ic.eq.7) go to 11
      if(ic.eq.8) go to 12
CC      go to ( 1, 23, 23, 4, 4, 4, 11, 12 ), ic
         write(8,200)  ic
  200    format(/' ERROR at geogr1          invalid kind =',i6)
         stop
c
c     gravity tide
c
    1 c2 = 41.291125d0*rc
      c3 = c2*rc
      gc(2,1) = -2.d0*c2*(c21*ce+s21*se)
      gc(2,2) = -c2*(2.d0*c22*ce-c21*se)
      gc(3,1) = -0.72618d0*c3*(3.d0*c31*ce-s31*se)
      gc(3,2) = -2.59808d0*c3*(3.d0*c32*ce+s32*se)
      gc(3,3) = -3.d0*c3*(c33*ce-s33*se)
      dfact2 = 1.d0 +           h2 -     1.5d0*k2
      dfact3 = 1.d0 + 2.d0/3.d0*h3 - 4.d0/3.d0*k3
      go to 8
c
c     tilt tide    (from north clockwise)
c
   23 c2 = 8.516906d03/ge*rc
      c3 = c2*rc
      gc21n = -2.d0*c2*(s21*ce-c21*se)*(-1.d0)
      gc22n = c2*(c21*ce+2.d0*c22*se) *(-1.d0)
      gc31n = 0.72618d0*c3*(s31*ce-c21*se)*(-1.0)
      gc32n = 2.59808d0*c3*(cf*(2.d0-3.d0*c22)*ce+3.d0*c32*se)*(-1.d0)
      gc33n = 3.d0*c3*(c32*ce+c33*se)*(-1.d0)
      gc21e = 2.d0*c2*sf
      gc22e = 2.d0*c2*cf
      gc31e = 0.72618d0*c3*c31/cf
      gc32e = 2.59808d0*c3*c21
      gc33e = 3.d0*c3*c22
      if( ic.eq.3 )  az = 90.d0
      cosaz = dcos( az*rad )
      sinaz = dsin( az*rad )
      gc(2,1) = dsqrt( (gc21n*cosaz)**2 + (gc21e*sinaz)**2 )
      gc(2,2) = dsqrt( (gc22n*cosaz)**2 + (gc22e*sinaz)**2 )
      gc(3,1) = dsqrt( (gc31n*cosaz)**2 + (gc31e*sinaz)**2 )
      gc(3,2) = dsqrt( (gc32n*cosaz)**2 + (gc32e*sinaz)**2 )
      gc(3,3) = dsqrt( (gc33n*cosaz)**2 + (gc33e*sinaz)**2 )
      phcorr(2,1) = datan2( gc21e*sinaz, gc21n*cosaz ) / rad
      phcorr(2,2) = datan2( gc22e*sinaz, gc22n*cosaz ) / rad
      phcorr(3,1) = datan2( gc31e*sinaz, gc31n*cosaz ) / rad
      phcorr(3,2) = datan2( gc32e*sinaz, gc32n*cosaz ) / rad
      phcorr(3,3) = datan2( gc33e*sinaz, gc33n*cosaz ) / rad
      dfact2 = 1.d0 + k2 - h2
      dfact3 = 1.d0 + k3 - h3
      go to 8
c
c     strain tide with love's number h and l
c
    4 if( ic.eq.5 )  az = 90.d0
      if( ic.eq.6 )  az = 45.d0
      cosaz  = dcos(az*rad)
      sinaz  = dsin(az*rad)
      cosaz2 = cosaz*cosaz
      sinaz2 = sinaz*sinaz
      cosiaz = cosaz*sinaz
      theta = 90.d0*rad - fc
      cth   = dcos(theta)
      sth   = dsin(theta)
      g = 4.124492d+04*rc/ge
      gc21h =  g*2.d0*cth*sth                            * h2
      gc22h =  g*sth*sth                                 * h2
      gc31h =  g*0.72618d0*sth*(1.d0-5.d0*cth*cth)*rc    * h3
      gc32h =  g*2.59808d0*cth*sth*sth*rc                * h3
      gc33h =  g*sth*sth*sth*rc                          * h3
c
      gc21n = -g*8.d0*cth*sth                            * l2
      gc22n =  g*2.d0*(cth*cth-sth*sth)                  * l2
      gc31n =  g*0.72618d0*sth*(34.d0-45.d0*sth*sth)*rc  * l3
      gc32n =  g*2.59808d0*cth*(9.d0*cth*cth-7.d0)*rc    * l3
      gc33n =  g*sth*(6.d0-9.d0*sth*sth)*rc              * l3
c
      gc21e = -g*4.d0*cth*sth                            * l2
      gc22e =  g*(2.d0*cth*cth-4.d0)                     * l2
      gc31e =  g*0.72618d0*sth*(14.d0-15.d0*sth*sth)*rc  * l3
      gc32e =  g*2.59808d0*cth*(3.d0*cth*cth-5.d0)*rc    * l3
      gc33e = -g*sth*(6.d0+3.d0*sth*sth)*rc              * l3
c
      gc21x =  g*4.d0*sth                                * l2
      gc22x = -g*4.d0*cth                                * l2
      gc31x = -g*0.72618d0*20.d0*cth*sth*rc              * l3
      gc32x =  g*2.59808d0*4.d0*(sth*sth-cth*cth)*rc     * l3
      gc33x = -g*12.d0*cth*sth*rc                        * l3
c
      pin21  = ( gc21n + gc21h )*cosaz2 + ( gc21e + gc21h )*sinaz2
      pin22  = ( gc22n + gc22h )*cosaz2 + ( gc22e + gc22h )*sinaz2
      pin31  = ( gc31n + gc31h )*cosaz2 + ( gc31e + gc31h )*sinaz2
      pin32  = ( gc32n + gc32h )*cosaz2 + ( gc32e + gc32h )*sinaz2
      pin33  = ( gc33n + gc33h )*cosaz2 + ( gc33e + gc33h )*sinaz2
c
      pout21 = - gc21x*cosiaz
      pout22 = - gc22x*cosiaz
      pout31 = - gc31x*cosiaz
      pout32 = - gc32x*cosiaz
      pout33 = - gc33x*cosiaz
c
      gc(2,1) = dsqrt( pin21*pin21 + pout21*pout21 )
      gc(2,2) = dsqrt( pin22*pin22 + pout22*pout22 )
      gc(3,1) = dsqrt( pin31*pin31 + pout31*pout31 )
      gc(3,2) = dsqrt( pin32*pin32 + pout32*pout32 )
      gc(3,3) = dsqrt( pin33*pin33 + pout33*pout33 )
c
      phcorr(2,1) = - datan2( pout21, pin21 ) / rad
      phcorr(2,2) = - datan2( pout22, pin22 ) / rad
      phcorr(3,1) = - datan2( pout31, pin31 ) / rad
      phcorr(3,2) = - datan2( pout32, pin32 ) / rad
      phcorr(3,3) = - datan2( pout33, pin33 ) / rad
      go to 8
c
c     potential/gravity/radius   (non-dimensional, for strain tide)
c
   11 g = 4.124492d+04*rc/ge
      gc(2,1) = g*c21
      gc(2,2) = g*c22
      gc(3,1) = g*0.72618d0*c31*rc
      gc(3,2) = g*2.59808d0*c32*rc
      gc(3,3) = g*c33*rc
      dfact2 = 2.d0*h2 -  6.d0*l2
      dfact3 = 2.d0*h3 - 12.d0*l3
      go to 8
c
c     potential height (for ocean tide)
c
   12 g = 26.75824d0*rc
      gc(2,1) = g*c21
      gc(2,2) = g*c22
      gc(3,1) = g*0.72618d0*c31*rc
      gc(3,2) = g*2.59808d0*c32*rc
      gc(3,3) = g*c33*rc
      dfact2 = 1.d0 + k2 - h2
      dfact3 = 1.d0 + k3 - h3
c
    8 continue
      if( ic.le.3 .or. ic.ge.7 )  then
         if( lovenm.eq.1 )  then
            gc(2,1) = gc(2,1)*dfact2
            gc(2,2) = gc(2,2)*dfact2
            gc(3,1) = gc(3,1)*dfact3
            gc(3,2) = gc(3,2)*dfact3
            gc(3,3) = gc(3,3)*dfact3
            write(8,220)  dfact2
  220       format(//' delta factor for P21, P22      :', f9.5 )
            write(8,230)  dfact3
  230       format(  ' delta factor for P31, P32, P33 :', f9.5 )
         else if( lovenm.eq.2 )  then
            dfacta  = dfact3/dfact2
            gc(3,1) = gc(3,1)*dfacta
            gc(3,2) = gc(3,2)*dfacta
            write(8,250)  dfacta
  250       format(//' normalizing factor for P31, P32 :', f9.5 )
         endif
      endif
      return
      end
c===========================================================================
      subroutine sphas1( tj, hd, alon )
      implicit double precision (a-h,o-z)
      dimension t(6)
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /phase0/ phcorr(4,4)
      common /jstut/  timsys
      data   detmut  /51.d0/
      td = tj + timsys/24.d0 + detmut/86400.d0
      fs = td/36525.0d0
      fs2 = fs*fs
      fs3 = fs2*fs
      t(2) = 270.434162d0 + 481267.883142d0*fs - 0.0011333d0*fs2
     &                                         + 0.000001889d0*fs3
      t(3) = 279.696681d0  + 36000.768925d0*fs + 0.0003027d0*fs2
      t(4) = 334.329568d0   + 4069.034034d0*fs - 0.0103249d0*fs2
     &                                         - 0.0000125d0*fs3
      t(5) = 100.843202d0   + 1934.142008d0*fs - 0.002078 d0*fs2
     &                                         - 0.000002 d0*fs3
      t(6) = 281.220868d0      + 1.719175d0*fs + 0.0004527d0*fs2
     &                                         + 0.0000033d0*fs3
c     alon:longitude (east)
      t(1) = t(3) - t(2) + (hd+timsys)*15.d0 + alon
      do i = 1, 377
        r = 0.d0
        do j = 1, 6
          f = idn(i,j)
          r = r + t(j)*f
        enddo
        is = idn(i,1)
        np = ip(i)
        r  = r + phcorr( np, is )
        if( mod(np+is,2).eq.1 )  r = r - 90.d0
        k = r/360.d0
        u = k
        phc(i) = r - 360.d0*u
      enddo
      return
      end
c===========================================================================
      subroutine geogr2( kind, ph, hi, grav, az, lovenm )
      implicit double precision (a-h,o-z)
      double precision  k2, k3, k4
      double precision  l2, l3, l4
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /phase0/ phcorr(4,4)
      data  pi    / 3.14159 26535 89793 d0/
      data  re    / 6378137.d2 /
      data  flat  / 3.35292d-3 /
      data  ge    / 3.98600448d20 /
      data  fmu   / 0.012300034d0 /
      data  sinpi / 3422.448d0 /
      data  k2, k3, k4  / 0.299d0,  0.093d0,  0.042d0  /
      data  h2, h3, h4  / 0.606d0,  0.291d0,  0.178d0  /
ccc   data  l2, l3, l4  / 0.0840d0, 0.0149d0, 0.0050d0 /
      data  l2, l3, l4  / 0.0840d0, 0.0149d0, 0.0100d0 /
c
c
      deg = 180.d0/pi
      rad = pi/180.d0
c
c
      cv = 3.d0 / 4.d0 * fmu * ge * ( sinpi/3600.d0*rad )**3 / re**2
c
      phi = ph
      if( phi.ge. 90.d0 )  phi =  89.9999d0
      if( phi.le.-90.d0 )  phi = -89.9999d0
      if( phi.eq.  0.d0 )  phi =   0.0001d0
      phi = phi * rad
c
      alti = hi * 100.d0
c
c
      cosphi = dcos( phi )
      sinphi = dsin( phi )
      ep = ( flat + flat**2/2.d0 ) * dsin( 2.d0*phi )
     *            - flat**2/2.d0   * dsin( 4.d0*phi )
      e2 = 2.d0*flat - flat**2
      roe = (   1.d0      / dsqrt( 1.d0-e2*sinphi**2 ) + alti/re )
     *      * cosphi
      rop = ( ( 1.d0-e2 ) / dsqrt( 1.d0-e2*sinphi**2 ) + alti/re )
     *      * sinphi
      roe2 = roe**2
      rop2 = rop**2
      rr = re * dsqrt( roe2 + rop2 )
c
      do j = 1, 4
         do i = 1, 4
            gc(i,j) = 0.d0
            phcorr(i,j) = 0.d0
         enddo
      enddo
c
      if( kind.eq.1 )  then
c
c        gravity in micro gal
         cv  =  -1.d6*cv
ccc      gc(2,0) = cv * ( roe*cosphi - 2.d0*rop*sinphi )
         gc(2,1) = 2.d0 * cv * ( rop*cosphi + roe*sinphi )
         gc(2,2) = 2.d0 * cv * roe * cosphi
ccc      gc(3,0) = 3.d0*dsqrt(5.d0)/2.d0 * cv * ( 2.d0*roe*rop
ccc  *          * cosphi + (roe2-2.d0*rop2)*sinphi )
         gc(3,1) = 3.d0*dsqrt(15.d0)/16.d0 * cv * ( (3.d0*roe2
     *          -4.d0*rop2)*cosphi - 8.d0*roe*rop*sinphi )
         gc(3,2) = 3.d0*dsqrt(3.d0)/2.d0 * cv * roe
     *              * ( 2.d0*rop*cosphi + roe*sinphi )
         gc(3,3) = 3.d0 * cv * roe2 * cosphi
ccc      gc(4,0) = 0.5d0 * cv
ccc  *    * (  3.d0*roe*( roe2-4.d0*rop2 )     *cosphi
ccc  *       + 4.d0*rop*( 2.d0*rop2-3.d0*roe2 )*sinphi )
         gc(4,1) = 448.d0 / ( 3.d0+dsqrt(393.d0))
     *             / dsqrt( 390.d0+2.d0*dsqrt(393.d0) ) * cv
     *    * (  rop*( 9.d0*roe2-4.d0*rop2 )*cosphi
     *       + 3.d0*roe*( roe2-4.d0*rop2 )*sinphi )
         gc(4,2) = 28.d0/9.d0 * cv
     *    * (  roe*( roe2-3.d0*rop2 )*cosphi
     *       - 3.d0*roe2*rop         *sinphi )
         gc(4,3) = 16.d0*dsqrt(3.d0)/9.d0 * cv
     *    * ( 3.d0*roe2*rop*cosphi + roe**3*sinphi )
ccc      gc(4,4) = 4.d0 * cv * roe**3 * cosphi
c
         dfact2 = 1.d0 +           h2 -    1.50d0*k2
         dfact3 = 1.d0 + 2.d0/3.d0*h3 - 4.d0/3.d0*k3
         dfact4 = 1.d0 +     0.5d0*h4 -    1.25d0*k4
c
      else if( kind.eq.2 .or. kind.eq.3 )  then
c
c        tilt in milli second of arc
         fact = deg * 3600.d3 / grav
         cv   = cv*fact
ccc      xx20    = -cv * ( 2.d0*rop*cosphi + roe*sinphi )
         xx21    =  2.d0 * cv * ( roe*cosphi - rop*sinphi )
         xx22    = -2.d0 * cv * roe * sinphi
ccc      xx30    = 3.d0*dsqrt(5.d0)/2.d0 * cv * ( (roe2
ccc  *           -2.d0*rop2)*cosphi - 2.d0*roe*rop*sinphi )
         xx31    =  3.d0*dsqrt(15.d0)/16.d0 * cv * ( -8.d0*roe*rop
     *          *cosphi + ( 4.d0*rop2-3.d0*roe2 )*sinphi )
         xx32    =  3.d0*dsqrt(3.d0)/2.d0 * cv
     *          *( roe2*cosphi - 2.d0*roe*rop*sinphi )
         xx33    = -3.d0 * cv * roe2 * sinphi
ccc      xx40    = 0.5d0 * cv
ccc  *    * (  4.d0*rop*( 2.d0*rop2-3.d0*roe2 )*cosphi
ccc  *       + 3.d0*roe*( 4.d0*rop2-roe2 )     *sinphi )
         xx41    = 448.d0 / ( 3.d0+dsqrt(393.d0))
     *             / dsqrt( 390.d0+2.d0*dsqrt(393.d0) ) * cv
     *    * (  3.d0*roe*( roe2-4.d0*rop2 )*cosphi
     *       + rop*( 4.d0*rop2-9.d0*roe2 )*sinphi )
         xx42    = 28.d0/9.d0 * cv
     *    * ( -3.d0*roe2*rop       *cosphi
     *       + roe*(3.d0*rop2-roe2)*sinphi )
         xx43    = 16.d0*dsqrt(3.d0)/9.d0 * cv
     *    * ( roe**3*cosphi - 3.d0*roe2*rop*sinphi )
ccc      xx44    = -4.d0 * cv * roe**3 * sinphi
c
ccc      yy20    = 0.d0
         yy21    = 2.d0 * cv * rop
         yy22    = 2.d0 * cv * roe
ccc      yy30    = 0.d0
         yy31    = 3.d0*dsqrt(15.d0)/16.d0 * cv
     *           * ( roe2 - 4.d0*rop2 )
         yy32    = 3.d0*dsqrt(3.d0) * cv * roe * rop
         yy33    = 3.d0 * cv * roe2
ccc      yy40    = 0.d0
         yy41    = 448.d0 / ( 3.d0+dsqrt(393.d0) )
     *           / dsqrt( 390.d0+2.d0*dsqrt(393.d0) ) * cv
     *           * rop*(3.d0*roe2-4.d0*rop2)
         yy42    = 14.d0/9.d0 * cv
     *           * roe*(roe2-6.d0*rop2)
         yy43    = 16.d0*dsqrt(3.d0)/3.d0 * cv * roe2 * rop
ccc      yy44    = 4.d0 * cv * roe**3
c
         if( kind.eq.3 )  az = 90.d0
         cosaz = dcos( az*rad )
         sinaz = dsin( az*rad )
c
ccc      gc(2,0) = dsqrt( (xx20*cosaz)**2 + (yy20*sinaz)**2 )
         gc(2,1) = dsqrt( (xx21*cosaz)**2 + (yy21*sinaz)**2 )
         gc(2,2) = dsqrt( (xx22*cosaz)**2 + (yy22*sinaz)**2 )
ccc      gc(3,0) = dsqrt( (xx30*cosaz)**2 + (yy30*sinaz)**2 )
         gc(3,1) = dsqrt( (xx31*cosaz)**2 + (yy31*sinaz)**2 )
         gc(3,2) = dsqrt( (xx32*cosaz)**2 + (yy32*sinaz)**2 )
         gc(3,3) = dsqrt( (xx33*cosaz)**2 + (yy33*sinaz)**2 )
ccc      gc(4,0) = dsqrt( (xx40*cosaz)**2 + (yy40*sinaz)**2 )
         gc(4,1) = dsqrt( (xx41*cosaz)**2 + (yy41*sinaz)**2 )
         gc(4,2) = dsqrt( (xx42*cosaz)**2 + (yy42*sinaz)**2 )
         gc(4,3) = dsqrt( (xx43*cosaz)**2 + (yy43*sinaz)**2 )
ccc      gc(4,4) = dsqrt( (xx44*cosaz)**2 + (yy44*sinaz)**2 )
c
ccc      if( cosaz.ne.0.d0 )
ccc  *   phcorr(2,0) = datan2( yy20*sinaz, xx20*cosaz ) * deg
         phcorr(2,1) = datan2( yy21*sinaz, xx21*cosaz ) * deg
         phcorr(2,2) = datan2( yy22*sinaz, xx22*cosaz ) * deg
ccc      if( cosaz.ne.0.d0 )
ccc  *   phcorr(3,0) = datan2( yy30*sinaz, xx30*cosaz ) * deg
         phcorr(3,1) = datan2( yy31*sinaz, xx31*cosaz ) * deg
         phcorr(3,2) = datan2( yy32*sinaz, xx32*cosaz ) * deg
         phcorr(3,3) = datan2( yy33*sinaz, xx33*cosaz ) * deg
ccc      if( cosaz.ne.0.d0 )
ccc  *   phcorr(4,0) = datan2( yy40*sinaz, xx40*cosaz ) * deg
         phcorr(4,1) = datan2( yy41*sinaz, xx41*cosaz ) * deg
         phcorr(4,2) = datan2( yy42*sinaz, xx42*cosaz ) * deg
         phcorr(4,3) = datan2( yy43*sinaz, xx43*cosaz ) * deg
ccc      phcorr(4,4) = datan2( yy44*sinaz, xx44*cosaz ) * deg
c
         dfact2 = 1.d0 + k2 - h2
         dfact3 = 1.d0 + k3 - h3
         dfact4 = 1.d0 + k4 - h4
c
      else if( kind.eq.4 .or. kind.eq.5 .or. kind.eq.6 )  then
c
c        strain tide with love's number h and l
c
         if( kind.eq.5 )  az = 90.d0
         if( kind.eq.6 )  az = 45.d0
         cosaz  = dcos(az*rad)
         sinaz  = dsin(az*rad)
         cosaz2 = cosaz*cosaz
         sinaz2 = sinaz*sinaz
         cosiaz = cosaz*sinaz
c
         psi   = phi - ep
         theta = 90.d0*rad - psi
         cth   = dcos(theta)
         cth2  = cth*cth
         sth   = dsin(theta)
         sth2  = sth*sth
c
         g   = cv * 1.d9/grav/6371023.6d2 * rr**2 / re
         rc  = rr/re
         rc4 = rc*rc
ccc      gc20h =  g*0.5d0*(1.d0-3.d0*cth2)                  * h2
         gc21h =  g*2.d0*cth*sth                            * h2
         gc22h =  g*sth2                                    * h2
ccc      gc30h =  g*1.11803d0*cth*(3.d0-5.d0*cth2)     * rc * h3
         gc31h =  g*0.72618d0*sth*(1.d0-5.d0*cth2)     * rc * h3
         gc32h =  g*2.59808d0*cth*sth2                 * rc * h3
         gc33h =  g*sth2*sth                           * rc * h3
ccc      gc40h =  g*0.12500d0*(3.d0-30.d0*cth2+35.d0*cth2*cth2)
ccc  *                                                 * rc4 * h4
         gc41h =  g*0.47347d0*cth*sth*(6.d0-14.d0*cth2)* rc4 * h4
         gc42h =  g*0.77778d0*(1.d0-8.d0*cth2+7.d0*cth2*cth2)
     *                                                 * rc4 * h4
         gc43h =  g*3.07920d0*cth*sth2*sth             * rc4 * h4
ccc      gc44h =  g*sth2*sth2                          * rc4 * h4
c
ccc      gc20n =  g*3.d0*(cth2-sth2)                        * l2
         gc21n = -g*8.d0*cth*sth                            * l2
         gc22n =  g*2.d0*(cth2-sth2)                        * l2
ccc      gc30n =  g*1.11803d0*cth*(45.d0*cth2-33.d0)   * rc * l3
         gc31n =  g*0.72618d0*sth*(34.d0-45.d0*sth2)   * rc * l3
         gc32n =  g*2.59808d0*cth*(9.d0*cth2-7.d0)     * rc * l3
         gc33n =  g*sth*(6.d0-9.d0*sth2)               * rc * l3
ccc      gc40n = -g*0.12500d0*(60.d0-540.d0*cth2+560.d0*cth2*cth2)
ccc  *                                                 * rc4 * l4
         gc41n =  g*0.47347d0*cth*sth*(224.d0*cth2-108.d0)
     *                                                 * rc4 * l4
         gc42n = -g*0.77778d0*(16.d0-116.d0*cth2+112.d0*cth2*cth2)
     *                                                 * rc4 * l4
         gc43n =  g*3.07920d0*cth*sth*(6.d0-16.d0*sth2)* rc4 * l4
ccc      gc44n =  g*sth2*(12.d0-16.d0*sth2)            * rc4 * l4
c
ccc      gc20e =  g*3.d0*cth2                               * l2
         gc21e = -g*4.d0*cth*sth                            * l2
         gc22e =  g*(2.d0*cth2-4.d0)                        * l2
ccc      gc30e =  g*1.11803d0*3.d0*(5.d0*cth2-1.d0)    * rc * l3
         gc31e =  g*0.72618d0*sth*(14.d0-15.d0*sth2)   * rc * l3
         gc32e =  g*2.59808d0*cth*(3.d0*cth2-5.d0)     * rc * l3
         gc33e = -g*sth*(6.d0+3.d0*sth2)               * rc * l3
ccc      gc40e =  g*0.12500d0*cth2*(60.d0-140.d0*cth2) * rc4 * l4
         gc41e =  g*0.47347d0*cth*sth*(56.d0*cth2-12.d0)*rc4 * l4
         gc42e = -g*0.77778d0*(4.d0-44.d0*cth2+28.d0*cth2*cth2)
     *                                                 * rc4 * l4
         gc43e = -g*3.07920d0*cth*sth*(6.d0+4.d0*sth2) * rc4 * l4
ccc      gc44e = -g*sth2*(12.d0+4.d0*sth2)             * rc4 * l4
c
ccc      gc20x =  0.d0
         gc21x =  g*4.d0*sth                                * l2
         gc22x = -g*4.d0*cth                                * l2
ccc      gc30x =  0.d0
         gc31x = -g*0.72618d0*20.d0*cth*sth            * rc * l3
         gc32x =  g*2.59808d0*4.d0*(sth2-cth2)         * rc * l3
         gc33x = -g*12.d0*cth*sth                      * rc * l3
ccc      gc40x =  0.d0
         gc41x =  g*0.47347d0*sth*(84.d0*sth2-72.d0)   * rc4 * l4
         gc42x =  g*0.77778d0*cth*(84.d0*cth2-60.d0)   * rc4 * l4
         gc43x =  g*3.07920d0*sth*(18.d0*sth2-12.d0)   * rc4 * l4
ccc      gc44x =  g*cth*(24.d0*cth2-24.d0)             * rc4 * l4
c
ccc      pin20  = ( gc20n + gc20h )*cosaz2 + ( gc20e + gc20h )*sinaz2
         pin21  = ( gc21n + gc21h )*cosaz2 + ( gc21e + gc21h )*sinaz2
         pin22  = ( gc22n + gc22h )*cosaz2 + ( gc22e + gc22h )*sinaz2
ccc      pin30  = ( gc30n + gc30h )*cosaz2 + ( gc30e + gc30h )*sinaz2
         pin31  = ( gc31n + gc31h )*cosaz2 + ( gc31e + gc31h )*sinaz2
         pin32  = ( gc32n + gc32h )*cosaz2 + ( gc32e + gc32h )*sinaz2
         pin33  = ( gc33n + gc33h )*cosaz2 + ( gc33e + gc33h )*sinaz2
ccc      pin40  = ( gc40n + gc40h )*cosaz2 + ( gc40e + gc40h )*sinaz2
         pin41  = ( gc41n + gc41h )*cosaz2 + ( gc41e + gc41h )*sinaz2
         pin42  = ( gc42n + gc42h )*cosaz2 + ( gc42e + gc42h )*sinaz2
         pin43  = ( gc43n + gc43h )*cosaz2 + ( gc43e + gc43h )*sinaz2
ccc      pin44  = ( gc44n + gc44h )*cosaz2 + ( gc44e + gc44h )*sinaz2
c
         pout21 = - gc21x*cosiaz
         pout22 = - gc22x*cosiaz
         pout31 = - gc31x*cosiaz
         pout32 = - gc32x*cosiaz
         pout33 = - gc33x*cosiaz
         pout41 = - gc41x*cosiaz
         pout42 = - gc42x*cosiaz
         pout43 = - gc43x*cosiaz
ccc      pout44 = - gc44x*cosiaz
c
ccc      gc(2,0) = dsqrt( pin20*pin20 )
         gc(2,1) = dsqrt( pin21*pin21 + pout21*pout21 )
         gc(2,2) = dsqrt( pin22*pin22 + pout22*pout22 )
ccc      gc(3,0) = dsqrt( pin30*pin30 )
         gc(3,1) = dsqrt( pin31*pin31 + pout31*pout31 )
         gc(3,2) = dsqrt( pin32*pin32 + pout32*pout32 )
         gc(3,3) = dsqrt( pin33*pin33 + pout33*pout33 )
ccc      gc(4,0) = dsqrt( pin40*pin40 )
         gc(4,1) = dsqrt( pin41*pin41 + pout41*pout41 )
         gc(4,2) = dsqrt( pin42*pin42 + pout42*pout42 )
         gc(4,3) = dsqrt( pin43*pin43 + pout43*pout43 )
ccc      gc(4,4) = dsqrt( pin44*pin44 + pout44*pout44 )
c
ccc      phcorr(2,0) = - datan2( 0.0d0,  pin20 ) * deg
         phcorr(2,1) = - datan2( pout21, pin21 ) * deg
         phcorr(2,2) = - datan2( pout22, pin22 ) * deg
ccc      phcorr(3,0) = - datan2( 0.0d0,  pin30 ) * deg
         phcorr(3,1) = - datan2( pout31, pin31 ) * deg
         phcorr(3,2) = - datan2( pout32, pin32 ) * deg
         phcorr(3,3) = - datan2( pout33, pin33 ) * deg
ccc      phcorr(4,0) = - datan2( 0.0d0,  pin40 ) * deg
         phcorr(4,1) = - datan2( pout41, pin41 ) * deg
         phcorr(4,2) = - datan2( pout42, pin42 ) * deg
         phcorr(4,3) = - datan2( pout43, pin43 ) * deg
ccc      phcorr(4,4) = - datan2( pout44, pin44 ) * deg
c
      else if( kind.eq.7 .or. kind.eq.8 )  then
c
c        kind = 7 : potential/grav/radius      10**(-9) strain
c        kind = 8 : potential/grav             ocean tide (cm)
c
ccc      if( kind.eq.7 )  fact = 1.d9/grav/rr
         if( kind.eq.7 )  fact = 1.d9/grav/6371023.6d2
         if( kind.eq.8 )  fact = 1.d0/grav
         cv  = cv*fact
c
         psi = phi - ep
         cospsi = dcos( psi )
         sinpsi = dsin( psi )
          cvr2   = cv * rr**2 / re
ccc      gc(2,0) = cvr2 * ( 1.d0 - 3.d0*sinpsi**2 )/2.d0
         gc(2,1) = cvr2 * dsin( 2.d0*psi )
         gc(2,2) = cvr2 * cospsi**2
          cvr3   = cvr2 * rr/re
ccc      gc(3,0) = dsqrt(5.d0)/2.d0 * cvr3
ccc  *           * sinpsi * ( 3.d0 - 5.d0*sinpsi**2 )
         gc(3,1) = 3.d0*dsqrt(15.d0)/16.d0 * cvr3
     *           * cospsi * ( 1.d0 - 5.d0*sinpsi**2 )
         gc(3,2) = 3.d0*dsqrt(3.d0)/2.d0 * cvr3
     *           * sinpsi * cospsi**2
         gc(3,3) = cvr3 * cospsi**3
          cvr4   = cvr3 * rr/re
ccc      gc(4,0) = 0.125d0 * cvr4
ccc  *           * ( 3.d0 - 30.d0*sinpsi**2 + 35.d0*sinpsi**4 )
         gc(4,1) = 224.d0 / ( 3.d0+dsqrt(393.d0) )
     *           / dsqrt( 390.d0+2.d0*dsqrt(393.d0) ) * cvr4
     *           * dsin( 2.d0*psi )*( 3.d0 - 7.d0*sinpsi**2 )
         gc(4,2) = 7.d0/9.d0 * cvr4
     *           * cospsi**2*( 1.d0 - 7.d0*sinpsi**2 )
         gc(4,3) = 16.d0/3.d0/dsqrt(3.d0) * cvr4
     *           * sinpsi*cospsi**3
ccc      gc(4,4) = cvr4 * cospsi**4
c
         if( kind.eq.7 )  then
            dfact2 = 2.d0*h2 -  6.d0*l2
            dfact3 = 2.d0*h3 - 12.d0*l3
            dfact4 = 2.d0*h4 - 20.d0*l4
         else if( kind.eq.8 )  then
            dfact2 = 1.d0 + k2 - h2
            dfact3 = 1.d0 + k3 - h3
            dfact4 = 1.d0 + k4 - h4
         endif
c
      else
c
         write(8,200)  kind
  200    format(/' invalid kind in geogr2      kind =',i5)
         stop
c
      endif
c
      if( kind.le.3 .or. kind.ge.7 )  then
         if( lovenm.eq.1 )  then
ccc         gc(2,0) = gc(2,0)*dfact2
            gc(2,1) = gc(2,1)*dfact2
            gc(2,2) = gc(2,2)*dfact2
ccc         gc(3,0) = gc(3,0)*dfact3
            gc(3,1) = gc(3,1)*dfact3
            gc(3,2) = gc(3,2)*dfact3
            gc(3,3) = gc(3,3)*dfact3
ccc         gc(4,0) = gc(4,0)*dfact4
            gc(4,1) = gc(4,1)*dfact4
            gc(4,2) = gc(4,2)*dfact4
            gc(4,3) = gc(4,3)*dfact4
ccc         gc(4,4) = gc(4,4)*dfact4
            write(8,220)  dfact2
  220       format(//' delta factor for P20-P22 :', f9.5 )
            write(8,230)  dfact3
  230       format(  ' delta factor for P30-P33 :', f9.5 )
            write(8,240)  dfact4
  240       format(  ' delta factor for P40-P44 :', f9.5 )
         else if( lovenm.eq.2 )  then
            dfacta  = dfact3/dfact2
            dfactb  = dfact4/dfact2
            dfactc  = dfact4/dfact3
ccc         gc(3,0) = gc(3,0)*dfacta
            gc(3,1) = gc(3,1)*dfacta
            gc(3,2) = gc(3,2)*dfacta
ccc         gc(4,0) = gc(4,0)*dfactb
            gc(4,1) = gc(4,1)*dfactb
            gc(4,2) = gc(4,2)*dfactb
            gc(4,3) = gc(4,3)*dfactc
            write(8,250)  dfacta
  250       format(//' normalizing factor for P30, P31, P32 :', f9.5 )
            write(8,260)  dfactb
  260       format(  ' normalizing factor for P40, P41, P42 :', f9.5 )
            write(8,270)  dfactc
  270       format(  ' normalizing factor for P43           :', f9.5 )
         endif
      endif
      return
      end
c===========================================================================
      subroutine sphas2( tj, hd, alon, tc0 )
      implicit double precision (a-h,o-z)
      dimension t(8)
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /phase0/ phcorr(4,4)
      common /jstut/  timsys
      common /dtdmut/ tdmut(130)
      data  pi  / 3.14159 26535 89793 d0 /
      rad = pi/180.d0
      tmid = tc0/36525.d0 - 1.d0
      tu19 = tj + timsys/24.d0
      tu   = tu19/36525.d0 - 1.0d0
      tu2  = tu*tu
c
      mm = ( tmid*100.0d0 + 100.0d0 )
      if( mm.lt.  1 )  mm =   1
      if( mm.gt.130 )  mm = 130
      detmut = tdmut( mm )
ccc   detmut = 51.d0
c
      td19 = tu19 + detmut/86400.d0
      td   = td19/36525.d0 - 1.0d0
      td2  = td*td
c
      el1  =   280.4606184d0 + 36000.7700536d0*tu
     *                           + 0.00038793d0*tu2
     *                           - 0.0000000258d0*tu**3
      t(2) =   218.316656d0 + 481267.881342d0*td - 0.001330d0 *td2
     *         + 0.0040d0*dcos( ( 29.d0+133.d0*tmid)*rad )
      t(1) =    el1 - t(2) + (hd+timsys)*15.d0 + alon
      t(3) =   280.466449d0  + 36000.769822d0*td + 0.0003036d0*td2
     *         + 0.0018d0*dcos( (159.d0+ 19.d0*tmid)*rad )
      t(4) =    83.353243d0   + 4069.013711d0*td - 0.010324d0 *td2
      t(5) =   234.955444d0   + 1934.136185d0*td - 0.002076d0 *td2
      t(6) =   282.937348d0      + 1.719533d0*td + 0.0004597d0*td2
      t(7) =   248.1d0       + 32964.47d0    *td
      t(8) =    81.5d0       + 22518.44d0    *td
c
c
      do i = 1, 909
        r = 0.d0
        do j = 1, 8
          f = idn(i,j)
          r = r + t(j)*f
        enddo
        is = idn(i,1)
        np = ip(i)
        r  = r + phcorr( np, is )
        if( mod(np+is,2).eq.1 )  r = r - 90.d0
        k = r/360.d0
        u = k
        phc(i) = r - 360.d0*u
      enddo
      return
      end
c===========================================================================
      subroutine setcos( ncosgr, comg, comg0, tcos, start, ipoten )
      implicit double precision (a-h,o-z)
      dimension  comg(*), comg0(*), tcos(*)
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /stngrp/ ig1(36),ig2(36),ngroup,imwave(36)
      iwn3 = 377
      if( ipoten.eq.2 )  iwn3 = 909
      write(8,200)
  200 format(//,14x,'  -------Additional sine waves to fit--------',//,
     *          '     i   Freq (cycle/day)       ',
     *          'epoch       omega0(deg)   initial phase',/)
      do i = 1, ncosgr
         avc(i+iwn3) = comg(i)
         hh = ( start - tcos(i) ) * 24.d0
         phc(i+iwn3) = dmod( comg0(i) + hh*comg(i), 360.d0 )
         ig1(i+ngroup) = i + iwn3
         ig2(i+ngroup) = i + iwn3
         write(8,210)  i, comg(i)/15, tcos(i), comg0(i), phc(i+iwn3)
  210    format(i6,f16.10,f17.2,f16.7,f16.7,f16.7)
      enddo
      write(8,220)
  220 format( )
      return
      end
c===========================================================================
      subroutine tide01( n1, n2, t, ct, st, xt, nn )
      implicit double precision (a-h,o-z)
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /savews/ ws(919), ampc(919), difc(919), con(919),
     *                         amps(919), difs(919)
      data    icall / 0 /
      data    inint / 500 /
      data    rad / 0.017453292519943d0 /
      if( icall.eq.0 )  then
         do i = 1, 377
            j = idn(i,1)
            k = ip(i)
            ws(i) = amc(i)*gc(k,j)
         enddo
         do i = 378, 387
            ws(i) = 1.d0
         enddo
         icall = 1
      endif
      ct = 0.d0
      st = 0.d0
      if( mod(nn,inint).eq.1 )  then
c
c initialize
c
         delta = xt*0.5d0*rad
         do i = n1, n2
            tempb = ( avc(i)*t + phc(i) )*rad
            tempc = avc(i)*delta
            ampc(i) = ws(i)*dcos(tempb)
            ct = ct + ampc(i)
            temp = 2.d0*dsin(tempc)
            con(i)  = temp*temp
            difc(i) = ws(i)*temp*dsin(tempc-tempb)
            amps(i) = ws(i)*dsin(tempb)
            st = st + amps(i)
            difs(i) = ws(i)*temp*dcos(tempb-tempc)
         enddo
      else
c
c        recurrence formula          do loop is vectorizable
c        amc2(i) is used as an iap work area
c
         do i = n1, n2
ccc         amc2(i) = ampc(i)*con(i)
ccc         difc(i) = difc(i) - amc2(i)
            difc(i) = difc(i) - ampc(i)*con(i)
            ampc(i) = ampc(i) + difc(i)
            ct = ct + ampc(i)
ccc         amc2(i) = amps(i)*con(i)
ccc         difs(i) = difs(i) - amc2(i)
            difs(i) = difs(i) - amps(i)*con(i)
            amps(i) = amps(i) + difs(i)
            st = st + amps(i)
         enddo
      endif
      return
      end
c===========================================================================
      subroutine tide02( n1, n2, t, ct, st, xt, nn, p4flag, tc0 )
      implicit double precision (a-h,o-z)
      integer  p4flag
      common /ctetbl/ avc(919),amc(919),amc2(919),phc(919),
     *                gc(4,4),idn(919,8),ip(919)
      common /savews/ ws(919), ampc(919), difc(919), con(919),
     *                         amps(919), difs(919)
      data    icall / 0 /
      data    inint / 500 /
      data    rad / 0.017453292519943d0 /
c
      if( icall.eq.0 )  then
         tmid = tc0/36525.d0 - 1.0d0
         do i = 1, 909
            j = idn(i,1)
            k = ip(i)
            ws(i) = ( amc(i) + amc2(i)*tmid )*gc(k,j)
            if( p4flag.eq.0 .and. k.eq.4 )  ws(i) = 0.d0
         enddo
         do i = 910, 919
            ws(i) = 1.d0
         enddo
         icall = 1
      endif
      ct = 0.d0
      st = 0.d0
      if( mod(nn,inint).eq.1 )  then
c
c  initialize
c
         delta = xt*0.5d0*rad
         do i = n1, n2
            tempb = ( avc(i)*t + phc(i) )*rad
            tempc = avc(i)*delta
            ampc(i) = ws(i)*dcos(tempb)
            ct = ct + ampc(i)
            temp = 2.d0*dsin(tempc)
            con(i)  = temp*temp
            difc(i) = ws(i)*temp*dsin(tempc-tempb)
            amps(i) = ws(i)*dsin(tempb)
            st = st + amps(i)
            difs(i) = ws(i)*temp*dcos(tempb-tempc)
         enddo
      else
c
c        recurrence formula          do loop is vectorizable
c        amc2(i) is used as an iap work area
c
         do i = n1, n2
ccc         amc2(i) = ampc(i)*con(i)
ccc         difc(i) = difc(i) - amc2(i)
            difc(i) = difc(i) - ampc(i)*con(i)
            ampc(i) = ampc(i) + difc(i)
            ct = ct + ampc(i)
ccc         amc2(i) = amps(i)*con(i)
ccc         difs(i) = difs(i) - amc2(i)
            difs(i) = difs(i) - amps(i)*con(i)
            amps(i) = amps(i) + difs(i)
            st = st + amps(i)
         enddo
      endif
      return
      end
c===========================================================================
      subroutine rtitle( numtit, numins, ctitle, cstnam,
     *                   cinstr, cunit,  cassoc, iaug   )
c
c     reading titls, station name, instrument name, unit and
c     auxiliary data name
c
      implicit double precision (a-h,o-z)
      character*40  cstnam, cinstr(10), cunit, cassoc(*), blk40
      character*80  ctitle(10), cbuff
      common/backcom/iback
      data  blk40  / '                                        ' /
c
c     skip the first 9999 (backwards compatibility)
c
      if(iback.eq.1) then
   10   read(7,2000)  cbuff(1:4)
        if( cbuff(1:4) .ne. '9999' )  go to 10
 2000   format(a4)
      endif

c
c     titles
c
      numtit = 0
   20 continue
      cbuff( 1:40) = blk40
      cbuff(41:80) = blk40
c   use err= to recover in case of variable record length
      read(7,2010,err=28)  (cbuff(i:i),i=1,80)
 2010 format(80a1)
   28 if(cbuff(1:4) .eq.'9999'.or.cbuff(1:4).eq.'----')  go to 50
      numtit = numtit + 1
      if(numtit.gt.10)  then
         write(8,2020)
 2020    format(/,' Only 10 title lines read in',/)
         go to 50
      endif
      ctitle(numtit) = cbuff
      go to 20
c
c     station name -- one line
c
   50 cstnam = blk40
      read(7,2030,err=58)  (cstnam(i:i),i=1,40)
 2030 format(40a1)
c
c     instrument name
c
   58 numins = 0
   60 cbuff(1:40) = blk40
      read(7,2030,err=68)  (cbuff(i:i),i=1,40)
   68 if(cbuff(1:4).eq.'9999'.or.cbuff(1:4).eq.'----')  go to 90
      numins = numins + 1
      if( numins.gt.10 )  then
         write(8,2040)
 2040    format(/,' Only 10 instrument lines read in',/)
         go to 90
      endif
      cinstr(numins) = cbuff(1:40)
      go to 60
c
c     unit
c
   90 cunit = blk40
      read(7,2030,err=98)  (cunit(i:i),i=1,40)
c
c     auxiliary data name
c
   98 if( iaug.eq.0 )  return
      do ii = 1, iaug
         cassoc(ii) = blk40
         read(7,2030,err=100)  (cassoc(ii)(i:i),i=1,40)
      enddo
 100  return
      end
c===========================================================================
      subroutine calend(ja0,jb0,jc0,hr0,n,delt,ja,jb,jc,hr)
      implicit double precision (a-h,o-z)
      dimension month(12)
      data month /31,28,31,30,31,30,31,31,30,31,30,31/
c
      ill = 0
      jax = mod(ja0,1900)
      if( jax.lt.1 .or. jax.gt.199 ) ill = 1
      if( jb0.lt.1 .or. jb0.gt.12 )  ill = 1
      if( jc0.lt.1 .or. jc0.gt.31 )  ill = 1
      if( hr0.lt.0.d0 .or. hr0.gt.24.d0 ) ill = 1
      if( ill.ne.0 )  then
          write(8,200)  ja0, jb0, jc0, hr0
  200     format(/' invalid date   y,m,d,h =', 3i9, f9.1,
     *            '        stopped at calend'           )
          stop
      endif
      ja = jax
      jb = jb0
      hr = hr0 + (n-1)*delt
      jd = hr/24.d0
      hr = hr - 24.d0*jd
      jc = jc0 + jd
 1    m  = month(jb)
      if( jb .eq. 2 .and. mod(ja,4) .eq. 0 )  m = m + 1
      if( jc .le. m ) return
      jc = jc - m
      jb = jb + 1
      if( jb .le. 12 )  go to 1
      jb = 1
      ja = ja + 1
      go to 1
      end
c===========================================================================
      subroutine htohms(dhr,ih,imin,isec)
      double precision dhr,r
      ih=dhr
      r=60.d0*(dhr-ih)
      imin=r
      r=60.d0*(r-imin)
      isec=r
      return
      end
c===========================================================================
      subroutine subsea(dmin,respc,ithaug,abicm,trend,respns,irreg,
     *    tidal,ftrn,n,istart,rlim,dc,idc,h2,n2,n2max,
     *    data,intest,limit,ishift,err,sqeopt,center,sd0,
     *    maxdc,maxh2)
c
      implicit double precision (a-h,o-z)
c
      double precision  irreg
      integer    span
      dimension  ftrn(*), dc(idc,*), h2(n2max,*), err(*),
     *           trend(*), respns(*), irreg(*),
     *           data(*), tidal(*), respc(*), center(*)
      common /idata/ iord,lagdbl,lagp,njump,span,lag,ncoef,idummy(4)
      common /rdata/ weight,dmin0,maxitr
      data    eps12  / 1.d-12 /
c
c     save area check
c
      isave = 0
      item1 = idc*limit
      item2 = n2max*limit
      if( item1*2.le.maxdc .and. item2*2.le.maxh2 )  isave = 1
      if( maxitr.eq.1 )                              isave = 0
c
      n200   = n2
      njump0 = njump
      istep  = 1
      iflag  = 0
      dmax0  = 1024.d0
      mode   = 0
      ro     = dsqrt(2.0d0)
      abicm  = 1.d25
c
      alndt0 = 0.d0
      if( intest.ne.0 )  then
         dd = dmin0*4.d0
      else
         dd = dmin
      endif
c
c
      do  900  iiii = 1, maxitr
      njump=njump0
      n2=n200
c
c     construction and householder transformation of matrix dc
c
      wt=dd
c
c     calculation of log(det(dc'dc))*0.5
c
c     --------------------
      alndtd=n*dlog(wt)+alndt0
c     --------------------
c
c     construction and householder transformation of matrix dcx
c
      alndn=0.d0
      do  i=1,limit
        dc(1,i)=1.d0
      enddo
      call setx( alndn,dc,idc,h2,n2,n2max,m1,icount,ftrn,n,wt,
     *           n,istart,istep,rlim,
     *           ithaug,alndtd,intest,limit,tidal,
     *           center)
c
c     least squares computation
c
      k=m1+n2-1
      k=mod(k,limit) + 1
      sqe=h2(n2,k)**2
c
c     interpretation of the solution
c
c     ****
c
c     abic computation
c
      an = icount
      do i=1,limit
         tem=dabs(dc(1,i))
         alndn=alndn + dlog(tem)
      enddo
      if( n2.ne.1 .and. weight.gt.0.d0 )  then
         n2m1 = n2 - 1
         ntem = n2m1 - njump
         do i = 1, ntem
            m1i = m1 + i - 1
            m1i = mod(m1i,limit) + 1
            tem = dabs(h2(i,m1i))
            alndn = alndn + dlog(tem)
         enddo
      endif
      sd=0.d0
      if( icount.le.0 )  go to 500
      sqe0=sqe/an
      alsqe=an*dlog(sqe0)
      sd=dsqrt(sqe0)
      abic=alsqe + 2.d0*(alndn-alndtd)
      abic=abic+njump*2.d0
      if(weight .le. 0.d0) abic=abic+2.d0*ncoef
      write(8,1300)  dd, abic, alsqe, alndn, alndtd
 1300 format('     ABIC(',1pd12.4,'  ) = ',0pf10.2,
     * '   alsqe =',1pd14.5,'    alndn =',d13.5,'    alndtd =',d13.5)
c
c     end of basic routine
c
c
c     minimum abic procedure
c
      if( abic.ge.abicm )           go to 500
      if( abicm-abic.lt.0.0001d0 )  go to 500
      abicm = abic
      sqeopt=sqe0
      dmin = dd
c
c     saving
      if( isave.eq.1 )  then
         do k2 = 1, limit
            do k1 = 1, idc
               dc(k1,limit+k2) = dc(k1,k2)
            enddo
         enddo
         do k2 = 1, limit
            do k1 = 1, n2max
               h2(k1,limit+k2) = h2(k1,k2)
            enddo
         enddo
cc       without subscript range check
cc       do 10010 kk = 1, item1
cc       dc(kk,limit+1) = dc(kk,1)
cc10010  continue
cc       do 10020 kk = 1, item2
cc       h2(kk,limit+1) = h2(kk,1)
cc10020  continue
      endif
      n2save = n2
      njsave = njump
c
      sd0 = sd
      dd = ro*dd
      if( iiii.eq.2 )  mode = 1
      go to 700
  500 if( mode.eq.1 )  go to 1000
      mode = 1
      ro = 1.d0/ro
      dd = dd*ro*ro
  700 continue
      if( dd .le. dmax0+eps12 )  go to 800
      if( mode.eq.0 )  then
         mode = 1
         ro = 1.d0/ro
         dd = dd*ro*ro
         go to 700
      else
         dd = dmax0
         iflag = 1
         go to 1000
      endif
  800 continue
      if( dd .lt. dmin0-eps12 )  then
         dd = dmin0
         iflag = -1
         go to 1000
      endif
  900 continue
c
c
 1000 continue
c
c
c     construction and householder transformation of matrix dc
c
      wt=dmin
c
c     calculation of log(det(dc'dc))*0.5
c
c     --------------------
      alndtd=n*dlog(wt)+alndt0
c     --------------------
c
c     construction and householder transformation of matrix dcx
c
      if( isave.eq.1 )  then
         do k2 = 1, limit
            do k1 = 1, idc
               dc(k1,k2) = dc(k1,limit+k2)
            enddo
         enddo
         do k2 = 1, limit
            do k1 = 1, n2max
               h2(k1,k2) = h2(k1,limit+k2)
            enddo
         enddo
cc       without subscript range check
cc       do 10030 kk = 1, item1
cc       dc(kk,1) = dc(kk,limit+1)
cc10030  continue
cc       do 10040 kk = 1, item2
cc       h2(kk,1) = h2(kk,limit+1)
cc10040  continue
         n2    = n2save
         njump = njsave
      else if( maxitr.eq.1 .or. iflag.ne.0 )  then
         n2    = n2save
         njump = njsave
      else
         njump = njump0
         n2    = n200
         alndn = 0.d0
         do i=1,limit
            dc(1,i)=1.d0
         enddo
         call setx( alndn,dc,idc,h2,n2,n2max,m1,icount,ftrn,n,wt,
     *              n,istart,istep,rlim,
     *              ithaug,alndtd,intest,limit,tidal,
     *              center     )
      endif
c
c     least squares computation
c
      nd=span+n2
      if(ishift .eq. 0) nd=n2
      do i=1,nd
         err(i)=0.d0
      enddo
      call solve(dc,idc,h2,n2,n2max,respns,m1,sqe,nd,limit,err)
c
      write(8,1400)  abicm, dmin, sd0
 1400 format(/' minimum ABIC =',f10.2,'   attained at vmin =',
     *         1pd12.4,'    sd =',d12.4)
      if( ishift .eq. 0 )  then
         do j = 1, ncoef
            respc(j) = respns(j)
         enddo
      else
         call decode(trend,respns,irreg,tidal,respc,err,
     *               span,istart,ithaug,intest,data)
      endif
      if( iflag .eq.  1 )  write(8,1500) dmax0
 1500 format(' **** d is hitting the upper bound ',1pd12.4,' -----',
     *       ' try lower values of order')
      if( iflag .eq. -1 )  write(8,1600) dmin0
 1600 format(' **** d is hitting the lower bound ',1pd12.4,' -----',
     *       ' try higher values of order')
      return
      end
c===========================================================================
      subroutine setx( alndn,h1,n1,h2,n2,n2max,m1,icount,ftrn,n,wt,
     *                 ndata,istart,istep,rlim,
     *                 ithaug,alndtd,intest,limit,d,
     *                 center     )
      implicit double precision (a-h,o-z)
ccc   external yreado,yreada
c
      dimension h1(n1,*),h2(n2max,*),h3(500),h4(500),d(*)
      dimension ftrn(*),ti(10),t0(10),djump(300),work(3),err(3)
      dimension center(*)
      common /idata/ id,lagdbl,lagp,njump,ispan,lag,
     *               ncoef,ith,ithp1,lagint,ifcr
      common /rdata/ weight,dmin0,maxitr
      common /lpcnt/ lpout
      common /validd/ numuse, maxjmp
c
      lagpp1=lagp+1
      iiii=istart-istep
      ntem=ith + 2+(ithaug-ith)*lagpp1+njump
      if(ntem .eq. 0) ntem=1
      do i=1,100
         djump(i)=0.d0
      enddo
      do i=1,limit
         do j=1,n2
            h2(j,i)=0.d0
         enddo
      enddo
      lagp1=ncoef+1
      n2m1=n2-1
      j0 = 0
      if( ith.gt.0 )  then
ccc      stabil  = weight*0.001d0
         stabil  = weight*0.01d0
         if( stabil.gt.0.01d0 )  stabil = 0.01d0
         h2(1,1) = stabil
         h2(2,2) = stabil
         j0 = 2
         ngroup = ith/2 - 1 - ifcr
         do k = 1, ngroup
            do j = 1, 2
               j0 = j0 + 1
               h2(j0-2,j0) = -weight*center(k)
               h2(j0,  j0) =  weight*center(k)
            enddo
         enddo
         h2(j0-1,j0+1) = stabil
         h2(j0,  j0+2) = stabil
         if( ifcr.eq.1 )  then
            j0 = j0 + 1
            h2(j0,j0+2) = stabil
            j0 = j0 + 1
            h2(j0,j0+2) = stabil
         endif
      endif
      if( ithp1.le.ithaug )  then
         do k = ithp1, ithaug
            do j = 1, lagpp1
               j0 = j0 + 1
               if( j.lt.lagpp1 )  h2(j0,j0+3) = -weight
               h2(j0,j0+2) = weight
            enddo
         enddo
      endif
      call hushld(h2,ntem,n2,n2max,d)
      if(n2m1 .le. 0)       go to 1300
      if(weight .le. 0.d0)  go to 1300
      do j=1,n2m1
         tem=dabs(h2(j,j))
         if(j .le. ncoef)alndtd=alndtd+dlog(tem)
      enddo
 1300 continue
      call setd(t0,id,wt)
      do i=1,id
         ti(i) = ftrn(i)*wt
      enddo
      call init(ti,id)
      icount=0
      m1=0
      id0=id+1
      ipos=0
      k=0
      jmpchk=0
      jumpnn = 0
      numuse = 0
c
      do 3300 i=1,n
      ipos = ipos + 1
      n3 = ipos
      if(n3 .gt. id0) n3 = id0
      jtem = id0 - n3
      do j=1,n3
         jtem = jtem + 1
         h3(j) = t0(jtem)
      enddo
      do j=1,n2
         h4(j) = 0.d0
      enddo
      if(i .gt. id) go to 1800
      h4(n2)=ti(i)
      if(intest.eq.0) go to 1800
      do j=i,id
         jtem=j-i+1
         ktem=n2+jtem-1-id
         h4(ktem)=t0(jtem)
      enddo
 1800 continue
      call exqrcn(alndn,h1,n1,h2,n2,n2max,h3,n3,h4,m1,ipos,limit)
      iiii=iiii+istep
      yiiii=yreado(iiii)
      n3 = -1
      if(i .gt. ndata) go to 3200
      if(yiiii .gt. rlim .and. rlim .gt. 0.d0) go to 3200
      if(yiiii .ge. -rlim .or. rlim .le. 0.d0) go to 1900
      jmpchk = 1
      jumpnn = jumpnn + 1
      if( jumpnn.le.maxjmp )  go to 3200
         write(8,1890)  maxjmp
 1890    format(/' ERROR     too many steps         maxjmp =',i3)
         stop
 1900 numuse = numuse + 1
c**************************
      n3=-1
      h3(1) = 1.d0
      j0=0
      if(ith .le. 0) go to 2100
      call yreadt(iiii,h4,ith)
      j0=ith
c
 2100 continue
      if(ithp1 .gt. ithaug) go to 2300
      do ll=ithp1,ithaug
        nf0=ll-ith
        l=iiii-lagp*lagint
        if(l .le. 0) go to 3200
        do j=1,lagpp1
          weekll=yreada(nf0,l)
          if(weekll .gt. rlim .and. rlim .gt. 0.d0) go to 3200
          l=l+lagint
          j0=j0+1
          h4(j0)=weekll
        enddo
      enddo
c**************************
 2300 n3=1
      if(jmpchk .eq. 0) go to 2900
      ktem=njump+1-intest
      if(n2.lt.n2max) go to 2500
      call solve(h1,n1,h2,n2,n2max,work,m1,sqe,3,limit,err)
      djump(njump)=work(1)+work(2)*djump(njump)
      njumpm=njump-intest
      if(lpout.ge.2) write(8,3400) njumpm
 3400 format(/' ***** more than',i4,' jumps ****')
      if(lpout.ge.2) write(8,3500) work(1),work(2),djump(njump)
 3500 format('      earliest two jumps',1p2d11.3,' are aggregated',
     *       ' to',d11.3)
      l=n2m1
      lm1=l-1
      do j=1,limit
         h2(l,j)=work(2)*h2(l,j)+work(1)*h2(lm1,j)
         h2(lm1,j)=0.d0
      enddo
      ktem=ktem-3
      go to 2700
 2500 continue
      njump=njump+1
      djump(njump)=1.d0
      length=m1+n2
      length=mod(length,limit)+1
      n2=n2+1
      n2m1=n2m1+1
      l=n2+1
      lm1=n2
      do j=1,n2
         h2(j,length)=0.d0
      enddo
 2700 continue
      do k=1,ktem
         l=l-1
         lm1=lm1-1
         do j=1,limit
            h2(l,j)=h2(lm1,j)
            h2(lm1,j)=0.d0
         enddo
      enddo
 2900 continue
      h4(n2)=yiiii
      if(lagp1 .gt. n2m1) go to 3100
      l=0
      do j=lagp1,n2m1
         l=l+1
         h4(j)=djump(l)
      enddo
 3100 icount=icount+1
      jmpchk=0
 3200 call exqrcn(alndn,h1,n1,h2,n2,n2max,h3,n3,h4,m1,ipos,limit)
 3300 continue
c
      m1=m1-1
      m1=mod(m1,limit) + 1
      return
      end
c===========================================================================
      double precision function yreado(i)
c
c     reads observed tidal data
c
      implicit double precision (a-h,o-z)
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  1250 )
cc    parameter ( lbuff =  4500 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( lbuff = 18000 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
      real       yt(lbuff,2,maxgr2)
      common  /bufota/  yo, yt, ya, incore
      data nblock /0/
c
c see if we are reading off disk
c
      if( incore.ne.1) then
         kl=(i-1)/lbuff
         k1=kl+1
         k2=i-kl*lbuff
   70    continue
         if(k1 .eq. nblock)    go to 100
         if(k1 .eq. nblock-1)  go to 100
         if(k1 .gt. nblock)  go to 50
         rewind 30
         nblock=0
   50    continue
         nblock=nblock+1
         ibuff=mod(nblock,2)+1
         read(30)  ( yo(j,ibuff), j=1,lbuff )
         go to 70
  100    ibuff=mod(k1,2)+1
         yreado=yo(k2,ibuff)
         return
c
c or not
c
      elseif(incore.eq.1) then
         yreado = yo(i,1)
         return
      endif
      end
c===========================================================================
      subroutine yreadt(i,buf,ith)
c
c     reads theoretical tide data
c
      implicit double precision (a-h,o-z)
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  1250 )
cc    parameter ( lbuff =  4500 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( lbuff = 18000 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
c
      dimension  buf(*)
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
      real       yt(lbuff,2,maxgr2)
      save
      common  /bufota/  yo, yt, ya, incore
      data nblock /0/
c
c see if we are reading off disk
c
      if( incore.ne.1)  then
         kl=(i-1)/lbuff
         k1=kl+1
         k2=i-kl*lbuff
   70    continue
         if(k1 .eq. nblock)    go to 100
         if(k1 .eq. nblock-1)  go to 100
         if(k1 .gt. nblock)    go to 50
         rewind 31
         nblock=0
   50    continue
         nblock=nblock+1
         ibuff=mod(nblock,2)+1
         do ktem = 1, ith, 2
            read(31)  ( yt(j,ibuff,ktem),   j=1,lbuff ),
     *             ( yt(j,ibuff,ktem+1), j=1,lbuff )
         enddo
         go to 70
c
  100    ibuff=mod(k1,2)+1
         do k = 1, ith
            buf(k) = yt(k2,ibuff,k)
         enddo
         return
c
c or not
c
      elseif(incore.eq.1) then
         do k = 1, ith
            buf(k) = yt(i,1,k)
         enddo
         return
      endif
      end
c===========================================================================
      double precision function yreada(nf0,i)
c
c     reads auxiliary data
c
      implicit double precision (a-h,o-z)
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
cc    parameter ( lbuff =  1250 )
cc    parameter ( lbuff =  4500 )
cc    parameter ( lbuff = 13000 )
cc    parameter ( lbuff = 18000 )
      parameter ( lbuff = 50000 )
      parameter ( maxaux = 3 )
      dimension  yo(lbuff,2), ya(lbuff,2,maxaux)
      real       yt(lbuff,2,maxgr2)
      common  /bufota/  yo, yt, ya, incore
      dimension  nblock(maxaux)
      data nblock /maxaux*0/
c
c see if we are reading off disk
c
      if(incore.ne.1) then
         kl=(i-1)/lbuff
         k1=kl+1
         k2=i-kl*lbuff
   70    continue
         if(k1 .eq. nblock(nf0))    go to 100
         if(k1 .eq. nblock(nf0)-1)  go to 100
         nfile=nf0+31
         if(k1 .gt. nblock(nf0))  go to 50
         rewind nfile
         nblock(nf0)=0
   50    continue
         nblock(nf0)=nblock(nf0)+1
         ibuff=mod(nblock(nf0),2)+1
         read(nfile) (ya(j,ibuff,nf0),j=1,lbuff)
         go to 70
  100    ibuff=mod(k1,2)+1
         yreada=ya(k2,ibuff,nf0)
         return
c
c or not
c
      elseif(incore.eq.1) then
         yreada = ya(i,1,nf0)
         return
      endif
      end
c===========================================================================
      subroutine  hushld( x,n,k,mj1,d)
c
c
c     this subroutine  transforms matrix x into an upper triangular form
c     by householder transformation.
c
c       inputs:
c          x:     original n*k data matrix
c          mj1:   absolute dimension of x
c          n:  number of rows of x, not greater than mj1
c          k:     number of columns of x. not greater than mj1
c       output:
c          x:     in upper triangular form
c
      implicit double precision (a-h,o-z)
      dimension  x(mj1,*) , d(*)
      tol=1.0d-38
      if( mj1 .gt. 100) stop
      mnk=k
      if(n.le.k) mnk=n-1
      do ii=1,mnk
         h = 0.0d00
         do i=ii,n
            d(i) = x(ii,i)
            absld=dabs(d(i))
            if(absld.le.tol) d(i)=0.0d-00
            h = h + d(i)*d(i)
         enddo
         if( h .gt. tol )  go to 20
         g = 0.0d00
         go to 100
   20    g = dsqrt( h )
         f=x(ii,ii)
         if( f .ge. 0.0d00 )   g = -g
         d(ii) = f-g
         h = h - f*g
c
c        form  (i - d*d'/h) * x, where h = d'd/2
c
         ii1 = ii+1
         do i=ii1,n
            x(ii,i) = 0.d0
         enddo
         if( ii .eq. k )  go to 100
         do j=ii1,k
            s = 0.0d00
            do i=ii,n
               s = s + d(i)*x(j,i)
            enddo
            s = s/h
            do i=ii,n
               x(j,i) = x(j,i) - d(i)*s
            enddo
         enddo
  100    x(ii,ii) = g
      enddo
      return
      end
c===========================================================================
      subroutine setd(w,id,c)
      implicit double precision (a-h,o-z)
      dimension w(*)
      idp1 = id + 1
      w(idp1) = c
      do j=1,id
         w(j) = 0.d0
      enddo
      do j=1,id
         i = idp1 - j - 1
         do k=1,j
           i = i + 1
           w(i) = w(i) - w(i+1)
         enddo
      enddo
      return
      end
c===========================================================================
      subroutine  init(w,id)
      implicit double precision (a-h,o-z)
      dimension  w(*)
      idp1 = id + 1
      w(idp1) = 0.d0
      do j=1,id
         do k=1,id
            w(k) = w(k+1) - w(k)
         enddo
      enddo
      do j=1,id
         w(j) = -w(j)
      enddo
      return
      end
c===========================================================================
      subroutine  exqrcn(alndn,h1,n1,h2,n2,n2max,h3,n3,h4,macc,ipos,
     *                   limit)
c
c     for fortran77 & noiap version
c
      implicit double precision (a-h,o-z)
      dimension  h1(n1,*), h2(n2max,*), h3(*), h4(*)
      data  eps30  /1.d-30/
c
      if( ipos .gt. macc )  then
         macc = ipos
         mtem = ipos - 1
         m1 = mod( mtem, limit ) + 1
         alndn = alndn + dlog( dabs( h1(1,m1) ) )
         do j = 1, n1
            h1(j,m1) = 0.d0
         enddo
         m1n2 = m1 + n2
         if( m1n2 .gt. limit )  m1n2 = m1n2 - limit
         do j = 1, n2
            h2(j,m1n2) = 0.d0
         enddo
      endif
      if( n3 .lt. 0 )  return
c
      m0 = ipos - n3 - 1
      mm = mod(m0,limit) + 1
      do 70 j = 1, n3
         mm = mm + 1
         if( mm .gt. limit )  mm = 1
         if( dabs(h3(j)) .lt. eps30 )  go to 70
         sqd = dsqrt( h1(1,mm)**2 + h3(j)**2 )
         c = h1(1,mm)/sqd
         s = h3(j)/sqd
         h1(1,mm) = sqd
         m = 1
         do 40 k = j+1, n3
            m = m + 1
            if(m .gt. n1)  go to 50
            h1m = h1(m,mm)
            h1(m,mm) = c*h1m + s*h3(k)
            h3(k)    = c*h3(k) - s*h1m
   40    continue
   50    continue
         do 60 k = 1, n2
            h2k = h2(k,mm)
            h2(k,mm) = c*h2k + s*h4(k)
            h4(k)    = c*h4(k) - s*h2k
   60    continue
   70 continue
c
      mm = m1
      do 90 j = 1, n2
         mm = mm + 1
         if(mm .gt. limit)  mm = 1
         if( dabs(h4(j)) .lt. eps30 )  go to 90
         sqd = dsqrt( h2(j,mm)**2 + h4(j)**2 )
         c = h2(j,mm)/sqd
         s = h4(j)/sqd
         h2(j,mm) = sqd
         do 80 k = j+1, n2
            h2k = h2(k,mm)
            h2(k,mm) = c*h2k + s*h4(k)
            h4(k)    = c*h4(k) - s*h2k
   80    continue
   90 continue
c
      return
      end
c===========================================================================
      subroutine solve(h1,n1,h2,n2,n2max,a,m1,sqe,nans,limit,err)
      implicit double precision (a-h,o-z)
      dimension  h1(n1,*), h2(n2max,*), a(*), err(*)
c
      do 100 ler = 1, nans
         k = m1 + n2 - 1
         k = mod(k,limit) + 1
         ka = nans
         jj = nans - 1
         if( ler.ne.nans )  then
            sqe = 0.d0
            kam1 = ka - 1
            do kka = 1, kam1
               a(kka) = 0.d0
            enddo
            a(ler) = 1.d0
         else
            sqe = h2(n2,k)**2
            kka = ka
            kk  = k
            do j = 1, jj
               kk = kk - 1
               if( kk.eq.0 )  kk = limit
               kka = kka - 1
               a(kka) = h2(n2,kk)
            enddo
         endif
c
         kcopy = k
         do 80 j = 1, jj
            ka = ka - 1
            if( a(ka).eq.0.d0 )  go to 80
            k = kcopy - j
            if( k.le.0 )  k = k + limit*( (-k)/limit + 1 )
c
            if( j.ge.n2 )  then
               if( ler.ne.nans )  go to 100
               a(ka) = a(ka)/h1(1,k)
               if( ler.lt.nans )  err(ka) = err(ka) + a(ka)**2
               ltem = k
               l = ka
               do 30 i = 2, n1
                  l = l - 1
                  ltem = ltem - 1
                  if( ltem.eq.0 )  ltem = limit
                  if( l.le.0 )  go to 80
                  a(l) = a(l) - a(ka)*h1(i,ltem)
   30          continue
            else
               a(ka) = a(ka)/h2(n2-j,k)
               if( ler.lt.nans )  err(ka) = err(ka) + a(ka)**2
               kam1 = ka - 1
               if( kam1.le.0 )  go to 80
               ltem = k
               katem = ka
               aka = a(ka)
               n2mj = n2-j
               if( ltem .gt. kam1 )  then
                  loffs = ltem - kam1 - 1
                  do 40 l = 1, kam1
                  a(l) = a(l) - aka*h2(n2mj,l+loffs)
   40             continue
               else
                  do l = 1, kam1
                     katem = katem - 1
                     ltem = ltem - 1
                     if( ltem.eq.0 )  ltem = limit
                     a(katem) = a(katem) - aka*h2(n2mj,ltem)
                  enddo
               endif
            endif
   80    continue
  100 continue
      return
      end
c===========================================================================
      subroutine decode(trend,respns,irreg,tidal,w,err,
     *                  nn,istart,ithaug,intest,ys)
c
c
c   this subroutine computes
c       trend
c       seas0
c       respns=y - seas0
c
      implicit double precision (a-h,o-z)
      parameter ( maxgrp = 31,  maxgr2 = maxgrp*2 )
      double precision  irreg
      dimension buf(maxgr2)
      dimension trend(*),respns(*),irreg(*),
     *          err(*),ys(*),w(*),tidal(*)
      common /idata/ iorder,lagdbl,lagp,njump,ispan,lag,
     *               ncoef,ith,ithp1,lagint,ifcr
c
      jp=njump+1
      ajump=0.d0
      rlim=1.d25
      lagpp1=lagp+1
      n=nn
c
      ntem = n+1
      n7 = ncoef + njump
      call copy(w,respns,n7,ntem)
      call copy(err,err,n7,ntem)
      do i=1,n
         trend(i)=respns(i)
      enddo
      ii=istart-1
      do 80 i=1,n
      ii=ii+1
      if(i .gt. nn) go to 20
      ys(i)=yreado(ii)
      if(jp .le. intest) go to 20
      if(ys(i) .gt. -1.d25) go to 20
      jp=jp-1
      ajump=ajump+w(ncoef+jp)
c
   20 continue
      sum=0.d0
      j0=0
      if( ith.ne.0 )  then
         call yreadt(ii,buf,ith)
         do 30 k=1,ith
         sum=sum+w(k)*buf(k)
   30    continue
         j0=ith
      endif
c
      tidal(i)=sum
      sum=0.d0
      if(ithp1 .gt. ithaug) go to 70
      do 62 k=ithp1,ithaug
        nf0 = k - ith
        jj=ii-lagp*lagint
        if(jj .le. 0) go to 64
        do 60 j=1,lagpp1
          weekkj=yreada(nf0,jj)
          if(dabs(weekkj) .ge. rlim)  go to 64
          jj=jj+lagint
          j0=j0+1
          sum=sum+w(j0)*weekkj
   60   continue
   62 continue
      go to 70
   64 sum=1.d30
c
   70 continue
      respns(i)=sum
c**************************
      irreg(i) = ys(i) - respns(i) - tidal(i) - ajump
      if(dabs(ys(i)).gt.rlim.or.dabs(respns(i)).gt.rlim) irreg(i)=1.d30
      irreg(i)=irreg(i)-trend(i)
   80 continue
      return
      end
c===========================================================================
      subroutine copy(x,y,ny,iy)
c
c     this subroutine copies y into x.
c     inputs:
c       x:     mx*nx matrix
c       y:     my*ny matrix
c
      implicit double precision (a-h,o-z)
      dimension x(*), y(*)
      iym1 = iy - 1
      do i=1,ny
         x(i)=y(i+iym1)
      enddo
      return
      end
c===========================================================================
      subroutine frqrsp( rat, respc, err, lagint, lagpp1,
     *                   iaug, deg0, paglen, rsperr )
c
      implicit double precision (a-h,o-z)
c
      dimension  respc(lagpp1,*), fy(7), sxx(181,2), fresp(181,2)
      dimension  amym(2), dmym(2), fmym(2), rat(*)
      dimension  err(lagpp1,*), erra(181), errp(181)
      integer    h1, h1end, paglen, rsperr
      character*62  cc
      data  pi /3.14159265358979323d0/
      h1    = 61
      h1end = h1
      if( paglen.eq.60 )  h1end = h1end - 5
      coef = pi*lagint/(h1-1)
      deg  = 180.d0/deg0/dble(h1-1)
      cpd  = deg/15
      fnyq = 180.d0 / ( deg0*dble(lagint) )
      do 90 iaugt=1,iaug
         write(8,2000) iaugt
 2000    format(/'      Frequency response of auxiliary data',
     *        '  to',i3,'-th aux. input' /)
c
      do i=1,h1
         ar=respc(lagpp1,iaugt)
         ai=0.d0
         arerr = err(lagpp1,iaugt)**2
         aierr = 0.d0
         if(lagpp1 .le. 1) go to 20
         c=dble(i-1)*coef
         do j=2,lagpp1
            arg=c*dble(j-1)
            jr = lagpp1+1-j
            ar=ar+respc(jr,iaugt)*dcos(arg)
            ai=ai-respc(jr,iaugt)*dsin(arg)
            arerr = arerr + (err(jr,iaugt)*dcos(arg))**2
            aierr = aierr + (err(jr,iaugt)*dsin(arg))**2
         enddo
   20    ar = ar * rat(iaugt+1)
         ai = ai * rat(iaugt+1)
         arerr = dsqrt(arerr) * rat(iaugt+1)
         aierr = dsqrt(aierr) * rat(iaugt+1)
         fresp(i,1)=dsqrt(ar**2 + ai**2)
         sxx(i,1)=dlog10(fresp(i,1))*2.d0
         fresp(i,2)=datan2(ai,ar)*180.d0/pi
         sxx(i,2)=fresp(i,2)
         erra(i) = dsqrt( (ar*arerr)**2 + (ai*aierr)**2 ) / fresp(i,1)
         errp(i) = dsqrt( (ar*aierr)**2 + (ai*arerr)**2 )
     *             / fresp(i,1)**2 * 180.d0/pi
      enddo
      if(iback.eq.0) then
         write(8,1030)
 1030    format('   cycle/day    amplitude',23x,'phase',/)
         do i = 1, h1end
            dim1=cpd*(i-1)
           if(rsperr.eq.0) write(8,1666) dim1,fresp(i,1),
     1                                        fresp(i,2)
 1666       format('>R',f8.4,2x,g15.4,15x,f13.2)
            if(rsperr.eq.1) write(8,1070) dim1,fresp(i,1),erra(i),
     1                                         fresp(i,2),errp(i)
 1070       format(f6.1,2x,g15.4,f15.2,f13.2,f15.2)
         enddo
      endif
      if(iback.eq.1) then
         dmym(1)=10.d0
         call dsp3( sxx(1,1), h1, r8min )
         amym(1)=r8min*10.d0
         do i = 1, h1
            sxx(i,1)=sxx(i,1)*10.d0
         enddo
         amym(2)=-180.d0
         dmym(2)=60.d0
         fmym(1)=1.d0
         fmym(2)=60.d0/360.d0
         do kkk=1,2
            if(kkk.eq.2)  write(8,2010)
 2010       format(' ')
            fy(1)=amym(kkk)
            do i=2,7
               fy(i)=fy(i-1)+dmym(kkk)
            enddo
            write(8,2020) (fy(i),i=1,7)
 2020       format(25x,6(f6.1,4x),f6.1)
            if(kkk.eq.1) write(8,2030)
            if(kkk.eq.2) write(8,2040)
 2030       format(' deg/h    amplitude factor   ',6('+---------'),'+')
 2040       format(' deg/h  phase shift in deg   ',6('+---------'),'+')
            do j = 1, 62
               cc(j:j) = ' '
            enddo
            do i = 1, h1end
              dim1=deg*(i-1)
              it=(sxx(i,kkk)-amym(kkk))*fmym(kkk)+1.0
              if( it.lt. 1 )  it =  1
              if( it.gt.62 )  it = 62
              cc(1:1)   = '!'
              cc(it:it) = '*'
              if( rsperr.eq.0 )  then
                if(kkk.eq.1)  write(8,2060) dim1, fresp(i,1), cc
 2060           format(f6.1,2x,1pd15.4,6x,a62,1pd17.4)
                if(kkk.eq.2)  write(8,2070) dim1, fresp(i,2), cc
 2070           format(f6.1,2x,f13.2,  8x,a62,f15.2)
              else
                if(kkk.eq.1)  
     1               write(8,2060) dim1, fresp(i,1), cc, erra(i)
                if(kkk.eq.2)
     1               write(8,2070) dim1, fresp(i,2), cc, errp(i)
              endif
              cc(it:it) = ' '
            enddo
c        for normal version
c        for long period version
c2060    format(f7.3,1x,1pd15.4,6x,a62,1pd17.4)
c2070    format(f7.3,1x,f13.2,  8x,a62,f15.2)
         enddo
      endif
      if(lagpp1.le.1)  write(8,2080)
 2080 format('  (lags negative)')
      if(lagpp1.ge.2.and.iback.eq.1)  write(8,2090)  fnyq
 2090 format('  (lags negative, Nyquist freq ',f7.2,' deg/hr)')
      if(lagpp1.ge.2.and.iback.eq.0)  write(8,2092)  fnyq/15.
 2092 format('  (lags negative, Nyquist freq ',f7.4,' cycle/day)')
c
   90 continue
      return
      end
c===========================================================================
      subroutine dsp3( y, lagh1, ymin )
c
c     search for minimum of y
c
      implicit double precision (a-h,o-z)
      dimension  y(lagh1)
      ymin = y(1)
      do i = 2, lagh1
         if( y(i).lt.ymin )  ymin = y(i)
      enddo
      if( ymin.ge.0.d0 )  then
         imin = ymin
      else
         ymin =  ymin - 1.d0
         imin = -ymin
         imin = -imin
      endif
      ymin = imin
      return
      end
c===========================================================================
      subroutine otlchk(data,n,idif,list,l,w,lmax)
      implicit double precision (a-h,o-z)
      dimension data(*), list(*)
      dimension w(*)
      l=0
      nmd=n-idif
      s=0.d0
      s2=s
      count=s
      do i=1,nmd
         if(idif .eq. 0) w(i)=data(i)
         if(idif .ne. 0) w(i)=data(i+1)-data(i)
         if(dabs(w(i)) .gt. 1.d25) go to 1
         s=s+w(i)
         s2=s2+w(i)**2
         count=count+1.d0
    1    continue
      enddo
      if(count .lt. 0.5d0) return
      s=s/count
      s2=s2/count - s**2
      sd4=dsqrt(s2)*4.d0
      do i=1,nmd
         div=w(i)-s
         div=dabs(div)
         if(div .gt. 1.d25) go to 2
         if(div .le. sd4) go to 2
         if(l .ge. lmax) go to 2
         l=l+1
         list(l)=i
    2    continue
      enddo
      return
      end
c===========================================================================
      subroutine sautco(x,cxx,n,lagh1,lpout)
c
c     the outputs are autocovariances (cxx(i); i=0,lagh) and
c     auto correlations (normalized covariances).
c
      implicit double precision (a-h,o-z)
      dimension  x(n), cxx(lagh1), cn(361)
      character  f(21)
c
c     initial condition print out
      lagh=lagh1-1
c     mean deletion
      call smeadl(x,n,xmean)
c     auto covariance computation
      call crosco(x,x,n,cxx,lagh1)
c     normalization
      cx0=cxx(1)
      call cornom(cxx,cn,lagh1,cx0,cx0)
c     auto covariance print out
      if(lpout .lt. 2) return
      write(8,100) n,lagh,xmean
  100 format(/' autocovariance     cxx(i)     n=',i5,5x,'lagh=',i5,
     *        '     mean=',1pd15.4)
      write(8,102)
  102 format(40x,'-1',9x,'0',9x,'1')
      write(8,104)
  104 format(5x,'i     cxx(i)',8x,'normalized',6x,4('+----'),'+')
      do i=1,lagh1
         im1=i-1
         do j = 1, 21
           f(j)  = ' '
         enddo
         f(11) = '!'
         cst0=0.0d-00
         cst10=10.0d-00
         cst05=0.5d-00
         if(cn(i).lt.cst0) go to 300
         nfc=cst10*cn(i)+cst05
         go to 310
  300    nfc=cst10*cn(i)-cst05
  310    anfc=nfc
         jj=anfc+11.d0
         f(jj) = '*'
         write(8,110) im1,cxx(i),cn(i),(f(j),j=1,21)
  110    format(i6,2x,1p2d14.4,5x,21a1)
      enddo
      return
      end
c===========================================================================
      subroutine smeadl(x,n,xmean)
c
c  remove the mean of a series x
c
      implicit double precision (a-h,o-z)
      dimension x(n)
      an=n
      xmean=sumf(x,n)/an
      do i=1,n
         x(i)=x(i)-xmean
      enddo
      return
      end
      double precision function sumf( x, n )
c
c  return the mean of a series x
c
      implicit double precision (a-h,o-z)
      dimension  x(n)
      sumf = 0.d0
      do i = 1, n
         sumf = sumf + x(i)
      enddo
      return
      end
c===========================================================================
      subroutine crosco(x,y,n,c,lagh1)
c
c     compute c(l)=covariance(x(s+l),y(s))
c     (l=0,1,...,lagh1-1).
c
      implicit double precision (a-h,o-z)
      dimension x(n),y(n),c(lagh1)
      an=n
      bn1=1.0d-00
      bn=bn1/an
      ct0=0.0d-00
      do ii=1,lagh1
         i=ii-1
         t=ct0
         il=n-i
         do j=1,il
            j1=j+i
            t=t+x(j1)*y(j)
         enddo
         c(ii)=t*bn
      enddo
      return
      end
c===========================================================================
      subroutine cornom(c,cn,lagh1,cx0,cy0)
c
c     normalize covariance
c
      implicit double precision (a-h,o-z)
      dimension c(lagh1),cn(lagh1)
      cst1=1.0d-00
      ds=cst1/dsqrt(cx0*cy0)
      do i=1,lagh1
         cn(i)=c(i)*ds
      enddo
      return
      end
c===========================================================================
      subroutine sicp2(cyy,l1,n,coef,mo,osd,oaic)
c
c     fit autoregressive models of successively
c     increasing order up to l(=l1-1).
c     input:
c     cyy(i),i=0,l1; autocovariance sequence
c     l1: l1=l+1, l is the upper limit of the model order
c     n; length of original data
c     out put:
c     coef; ar-coefficients
c     mo: order of ar
c     osd: innovation variance
c     oaic: value of aic
c
      implicit double precision (a-h,o-z)
      dimension  cyy(l1), coef(l1)
      dimension  a(101), b(101)
      character  ffff, f(41), ames(41)
      common /lpcnt/ lpout
      data  f / 41*' ' /,  ames / 41*' ' /
c
      cst0=0.0d-00
      cst1=1.0d-00
      cst2=2.0d-00
      cst20=20.0d-00
      cst05=0.05d-00
      cst01=0.00001d-00
      l=l1-1
      sd=cyy(1)
      an=n
      oaic=an*dlog(sd)
      osd=sd
      mo=0
c
c     initial condition print out
c
      ran=cst1/dsqrt(an)
      scalh=cst20
      jj0=scalh+cst1
      jjl=scalh*cst2+cst1
      ames(1)      = '+'
      ames(11)     = '+'
      ames(jj0)    = '+'
      ames(jj0+10) = '+'
      ames(jjl)    = '+'
      ian=scalh*(ran+cst05)
      ian1=ian+jj0
      ian2=2*ian+jj0
      lan1=-ian+jj0
      lan2=-2*ian+jj0
      if(lpout.ge.2) write(8,26101)
      if(lpout.ge.2) write(8,261)
      if(lpout.ge.2) write(8,26102)
      if(lpout.ge.2) write(8,262)
      if(lpout.ge.2) write(8,264) (ames(j),j=1,jjl)
cc    if(lpout.ge.2) write(8,859) mo,osd,oaic
      f(jj0)  = '!'
      f(ian1) = '!'
      f(ian2) = '!'
      f(lan1) = '!'
      f(lan2) = '!'
cc    if(lpout.ge.2)  write(8,861)  (f(j),j=1,jjl)
      if(lpout.ge.2)  write(8,862)  mo,osd,oaic, (f(j),j=1,jjl)
      se=cyy(2)
c     iteration start
      do 400 m=1,l
      sdr=sd/cyy(1)
      if(sdr.ge.cst01) go to 399
      if(lpout.ge.2) write(8,2600)
      go to 402
  399 mp1=m+1
      d=se/sd
      a(m)=d
      d2=d*d
      sd=(cst1-d2)*sd
      am=m
      aic=an*dlog(sd)+cst2*am
      if(m.eq.1) go to 410
c     a(i) computation
      lm=m-1
      do 420 i=1,lm
      a(i)=a(i)-d*b(i)
  420 continue
  410 continue
      do 421 i=1,m
      im=mp1-i
      b(i)=a(im)
  421 continue
c     m,sd,aic  print out
      if(a(m).lt.cst0) go to 300
      nfc=scalh*(a(m)+cst05)
      go to 310
  300 nfc=scalh*(a(m)-cst05)
  310 anfc=nfc
      jj=anfc+scalh+cst1
      ffff  = f(jj)
      f(jj) = '*'
      if(lpout.ge.2) write(8,860) m,sd,aic,a(m),(f(j),j=1,jjl)
      f(jj) = ffff
c
c
c     ----- 5/15/80 -----
c
      if(oaic.lt.aic) go to 440
      oaic=aic
      osd=sd
      mo=m
      go to 440
c     do 430 i=1,m
c     coef(i)=-a(i)
c 430 continue
  440 if(m.eq.l) go to 400
      se=cyy(m+2)
      do 441 i=1,m
      se=se-b(i)*cyy(i+1)
  441 continue
  400 continue
  402 continue
      if(lpout.ge.2) write(8,870) oaic,mo
c     ----- 5/15/80 -----
      oaic=aic
      osd=sd
      mo=l
      do 5100 i=1,l
      coef(i)=-a(i)
 5100 continue
c
      f(jj0)  = ' '
      f(ian1) = ' '
      f(ian2) = ' '
      f(lan1) = ' '
      f(lan2) = ' '
      ames(jj0)    = '-'
      ames(jj0+10) = '-'
      ames(jjl)    = '-'
      return
26101 format(/////4x,'m',11x,'innovation',10x,'aic(m)=    ',8x,
     1      'partial auto-')
  261 format(20x,'variance         n*dlog(sd(m))+2*m',
     2      '  correlation    ',
     3      'partial correlation (lines show +sd and +2sd)')
cc26102 format('+',102x,'_',7x,'_')
26102 format(103x,'-       -')
  262 format(70x,'-1',19x,'0',19x,'1')
  264 format(71x,41a1)
cc859 format(i6,2x,2d20.5)
  860 format(i6,2x,3d20.5,3x,41a1)
cc861 format('+',70x,41a1)
  862 format(i6,2x,2d20.5,23x,41a1)
  870 format(/' minimum AIC(m)=',1pd12.4,'  attained at m=',i5)
 2600 format(/' accuracy of computation lost')
      end
c===========================================================================
      subroutine snrasp(a,b,sxx,sgme2,l,k,h1,deg0,paglen)
c
c     compute power spectrum of an ARMA process defined by
c     x(n)=a(1)x(n-1)+...+a(l)x(n-l)+e(n)+b(1)e(n-1)+...+b(k)e(n-k),
c     where e(n) is a white noise with zero mean and variance equal to
c     sgme2.  outputs pxx(i) are given at frequencies i/(2*h)
c     i=0,1,...,h.
c     required inputs are:
c     l,k,h,sgme2,(a(i),i=1,l), and (b(i),i=1,k).
c     0 is allowable as l and/or k.
c
      implicit double precision (a-h,o-z)
c
      character*72  cc
      integer    h1, h1end, paglen
      dimension  a(101),b(101)
      dimension  g(361),gr1(361),gi1(361),gr2(361),gi2(361)
      dimension  pxx(361),sxx(361),fy(10)
c
      cst0=0.0d-00
      cst1=1.0d-00
      deg=180.d0/deg0/(h1-1.d0)
      cpd=deg/15.
      if(l.le.0) go to 320
      do i=1,l
         a(i)=-a(i)
      enddo
  320 l1=l+1
      k1=k+1
      g(1)=cst1
      if(l.le.0) go to 400
      do i=1,l
         i1=i+1
         g(i1)=-a(i)
      enddo
c
  400 call fouger(g,l1,gr1,gi1,h1)
      g(1)=cst1
      if(k.le.0) go to 410
      do i=1,k
         i1=i+1
         g(i1)=b(i)
      enddo
c
  410 call fouger(g,k1,gr2,gi2,h1)
      do i=1,h1
         pxx(i)=(gr2(i)**2+gi2(i)**2)/(gr1(i)**2+gi1(i)**2)*sgme2
      enddo
      if(l.le.0) go to 500
      do i=1,l
         a(i)=-a(i)
      enddo
  500 if(k.le.0) go to 510
      write(8,63)
   63 format(/'      ma(i)')
c
      call subvcp(b,k)
  510 t0=cst0
      do i=1,h1
         t=pxx(i)
         if(t.lt.t0) t=-t
         sxx(i)=dlog10(t)
      enddo
c     search  for the minimum of (sxx(i),i=0,lagh)
      call dsp3( sxx, h1, r8min )
      if(iback.eq.0) then
        write(8,1935)
 1935   format(' cycle/day  rational spectrum  (dB) ',/)
        do i = 1,h1
           dim1=cpd*(i-1)
           write(8,2666)  dim1, 10*sxx(i)
 2666      format('>S',f8.4,2x,f14.1)
        enddo
      endif
      if(iback.eq.1) then
        write(8,266)
  266   format(48x,'(density in dB)')
        fy(1)=r8min*10.d0
        do i=2,7
           fy(i)=fy(i-1)+10.d0
        enddo
        write(8,2033) (fy(i),i=1,7)
 2033   format(25x,6(f6.1,4x),f6.1)
        write(8,2035)
 2035   format(' deg/h  rational spectrum    ',6('+---------'),'+')
        do j = 1, 72
           cc(j:j) = ' '
        enddo
        h1end = h1
        if( paglen.eq.60 )  h1end = h1end - 5
        do i = 1, h1end
           it=(sxx(i)-r8min)*10.d0+1.d0
           if( it.lt. 1 )  it =  1
           if( it.gt.72 )  it = 72
           im1=i-1
           dim1=deg*(i-1)
           cc(1:1)   = '!'
           cc(it:it) = '*'
           write(8,2060)  dim1, pxx(i),cc
 2060      format(f6.1,2x,g14.4,7x,a72)
           cc(it:it) = ' '
        enddo
      endif
c
c     for normal version
c2060 format(f6.1,2x,1pd14.4,7x,72a1)
c     for long period version
c2060 format(f7.3,1x,1pd14.4,7x,a72)
      return
      end
c===========================================================================
      subroutine fouger(g,lgp1,fc,fs,lf1)
c
c     fourier transform (goertzel method)
c     this subroutine computes fourier transform of g(i),i=0,1,...,lg at
c     frequencies k/(2*lf),k=0,1,...,lf and returns cosin transform in
c     fc(k) and sin transform in fs(k).
c
      implicit double precision (a-h,o-z)
      dimension g(lgp1),fc(lf1),fs(lf1)
      lg=lgp1-1
      lf=lf1-1
      cst0=0.0d-00
c     reversal of g(i),i=1,...,lgp1 into g(lg3-i)   lg3=lgp1+1
      if(lgp1.le.1) go to 110
      lg3=lgp1+1
      lg4=lgp1/2
      do i=1,lg4
         i2=lg3-i
         t=g(i)
         g(i)=g(i2)
         g(i2)=t
      enddo
  110 pi = 3.141592653589793d0
      alf=lf
      t=pi/alf
      do k=1,lf1
         ak=k-1
         tk=t*ak
         ck=dcos(tk)
         sk=dsin(tk)
         ck2=ck+ck
         um2=cst0
         um1=cst0
         if(lg.eq.0) go to 12
         do i=1,lg
            um0=ck2*um1-um2+g(i)
            um2=um1
            um1=um0
         enddo
   12    fc(k)=ck*um1-um2+g(lgp1)
         fs(k)=sk*um1
      enddo
      return
      end
c===========================================================================
      subroutine subvcp(hh,lc)
c
c     prints out vector (hh(i),i=1,lc).
c
      implicit double precision (a-h,o-z)
      dimension hh(lc)
      write(8,100) lc
 100  format(/' vector     lc=',i5)
      write(8,102)
 102  format(/16x,'1',11x,'2',11x,'3',11x,'4',11x,'5',11x,'6',11x,
     *       '7',11x,'8',11x,'9',10x,'10')
      j1=0
      j2=0
      i=1
      jc=0
 3    j1=j2+1
      j2=j1+9
      if(j2.le.lc) go to 5
      j2=lc
 5    jc=jc+1
      write(8,104) i,(hh(j),j=j1,j2)
 104  format(i6,4x,1p10d12.4)
      if(j2.ge.lc) return
      i=i+10
      go to 3
      end
c===========================================================================
      subroutine graph3( x, y, z, rs, td, n, prepro,
     *                   rlim, jy, jm, jd, hr, delt )
c
c     this subroutine prints out the graph of time series x.
c     data with values greater than or equal to rlim
c     are ignored.
c     inputs:
c       x :   n-vector  ( original * factor )
c       y :      "      ( trend )
c       z :      "      ( irreguler part )
c       rs:      "      ( response part )
c       td:      "      ( tidal component )
c       rlim:   range of the value of x
c
      implicit double precision (a-h,o-z)
c
      dimension         x(*), y(*), z(*), rs(*), td(*), axis(11)
      integer           prepro
      character         c101, ctem
      character*11      cz
      character*23      lform
      character*101     cc, c0, c1
      common  /prstep/  step00
      data lform  / '(19x, 1pd10.3, 10d10.3)' /
      xmax = -1.d25
      zmax =  xmax
      xmin =  1.d25
      zmin =  xmin
      do i = 1, n
        if(rlim .le. 0.d0)        go to  5
        if(dabs(x(i)) .ge. rlim)  go to 10
        if(dabs(z(i)) .ge. rlim)  go to  5
        if(z(i) .gt. zmax)  zmax = z(i)
        if(z(i) .lt. zmin)  zmin = z(i)
    5   xtem = x(i)
        if( xtem .gt. xmax )  xmax = xtem
        if( xtem .lt. xmin )  xmin = xtem
   10   continue
      enddo
      zd   = (zmax-zmin)*0.1d0
      zmin = zmin - 1.5d0*zd
      xdif = xmax - xmin
      ix   = idint( dlog10(xdif) )
      power = dble( 10**ix )
      xdifn = xdif/power
      u = 0.2d0
      if(xdifn .ge. 1.5d0)  u = 0.25d0
      if(xdifn .ge. 2.0d0)  u = 0.5d0
      if(xdifn .ge. 4.0d0)  u = 1.d0
      if(xdifn .ge. 9.0d0)  u = 2.d0
      unit = u * power
      num  = idint( xdif/unit ) + 2
      lp   = 100/num
      mesh  = lp*num
      lpmax = mesh + 1
      ixmin = idint( xmin/unit )
      if(xmin .le. 0.d0)  ixmin = ixmin - 1
      xmin = dble(ixmin)*unit
      xmax = xmin + dble(num)*unit
      xd   = (xmax-xmin)/dble(mesh)
      xd2  = xd*0.5d0
      xd10 = xd*dble(lp)
      nump1 = num + 1
      rel   = dabs( xmax + xmin )*0.5d0/( xmax - xmin )
      xbase = xmin
      if(rel .gt. 50.d0)  then
        write(8,1600)  xmin
 1600   format(100x,'( +',1pd13.5,' )')
        xbase = 0.d0
      endif
      do i = 1, nump1
        axis(i) = xbase + xd10*dble(i-1)
        if(dabs(axis(i)) .lt. xd10*1.d-4)  axis(i) = 0.d0
      enddo
      write(8,500)
  500 format(/' *    :   data'/
     *        ' xxxx :   connecting line'/
     *        ' ++++ :   trend+step'/' i    :   irregular'/)
      write(lform(19:20),'(i2)')  lp
      write(8,lform)  (axis(i),i=1,nump1)
      do j = 1, 101
        cc(j:j) = ' '
        if( mod(j,lp) .eq. 1 )  then
          c1(j:j) = '!'
          c0(j:j) = '!'
        else
          c1(j:j) = '-'
          c0(j:j) = ' '
        endif
      enddo
      xmin2 = xmin - xd2
c
c
c     for long period version
c     jmlast = 0
c     if( jd.ne.1 )  jmlast = jm
c
      do 100  i = 1, n
        iobs = 0
c       for normal version
        if( hr.ge.0.001d0 )  then
cc       for long period version
cc       if( jm.eq.jmlast  )  then
          cc(1:lpmax) = c0(1:lpmax)
        else
          cc(1:lpmax) = c1(1:lpmax)
        endif
ccc     item = idint( (x(i)-xmin2)/xd ) + 1
        xposit = (x(i)-xmin2)/xd + 1.0000001d0
        if( xposit.gt.1.d4 )  then
           item = 10000
           else if( xposit.lt.0.d0 )  then
           item = 0
           else
           item = idint( xposit )
        endif
        item0 = item
        item1 = item
ccc     if(i .gt. 1)  item0 = idint( (x(i-1) - xmin2)/xd ) + 1
        if(i .gt. 1)  then
           xposi0 = (x(i-1) - xmin2)/xd + 1.0000001d0
           if( dabs(xposi0).gt.1.d3 )  then
              item0 = item
              else
              item0 = idint( xposi0 )
           endif
        endif
ccc     if(i .lt. n)  item1 = idint( (x(i+1) - xmin2)/xd ) + 1
        if(i .lt. n)  then
           xposi1 = (x(i+1) - xmin2)/xd + 1.0000001d0
           if( dabs(xposi1).gt.1.d3 )  then
              item1 = item
              else
              item1 = idint( xposi1 )
           endif
        endif
        if(item .gt. lpmax)  go to 90
        if(item .lt. 1)      go to 90
c
        if(item0 .lt. item)   item0 = item - (item-item0-1)/2
        if(item0 .gt. item)   item0 = item + (item0-item-1)/2
        if(item1 .lt. item)   item1 = item - (item-item1-1)/2
        if(item1 .gt. item)   item1 = item + (item1-item-1)/2
        if(item1 .gt. lpmax)  item1 = item
        if(item1 .lt. 1)      item1 = item
        if(item0 .gt. lpmax)  item0 = item
        if(item0 .lt. 1)      item0 = item
        jtem0 = item0
        if(jtem0 .gt. item)   jtem0 = item
        if(jtem0 .gt. item1)  jtem0 = item1
        jtem1 = item0
        if(jtem1 .lt. item)   jtem1 = item
        if(jtem1 .lt. item1)  jtem1 = item1
        do j = jtem0, jtem1
           cc(j:j) = 'x'
        enddo
        cc(item:item) = '*'
        iobs = 1
c
   90   item = idint( (y(i)-xmin2)/xd ) + 1
        if(item .gt. lpmax)  go to 91
        if(item .lt. 1)      go to 91
        ctem = '+'
        if(cc(item:item) .eq. '*')  ctem = 'c'
        cc(item:item) = ctem
   91   continue
        cz = '           '
        if( z(i).lt.1.d25 )  then
           ktem = idint( (z(i)-zmin)/zd )
           if( ktem.ge.1 .and. ktem.le.11 )  cz(ktem:ktem) = 'i'
        endif
        if( prepro.ge.1 )  then
          call kando( coef, jy, jm, jd, hr, 0 )
          if( rs(i).lt.1.d25 )  then
             pred = ( y(i) + rs(i) + td(i) - step00 ) / coef
          else
             pred = ( y(i)         + td(i) - step00 ) / coef
          endif
          c101 = cc(101:101)
          if( iobs.eq.0 )  cc(101:101) = '*'
ccc          write(8,601)  jy,jm,jd,hr, cz, cc, pred
ccc          write(8,602)  jy,jm,jd,hr, cz, cc, pred
ccc          write(8,603)  jy,jm,jd,hr, cz, cc, pred
ccc          write(8,604)  jy,jm,jd,hr, cz, cc
          if( prepro.eq.1 )  then
             write(8,601)  mod(jy,100),jm,jd,hr, cz, cc, pred
  601        format(i3.2,2i2,f4.1,1x,a11,1x,a101,f8.1)
          else if( prepro.eq.2 )  then
             write(8,602)  mod(jy,100),jm,jd,hr, cz, cc, pred
  602        format(i3.2,2i2,f4.1,1x,a11,1x,a101,f8.2)
          else
             write(8,603)  mod(jy,100),jm,jd,hr, cz, cc, pred
  603        format(i3.2,2i2,f4.1,1x,a11,1x,a101,f8.3)
          endif
          cc(101:101) = c101
        else
          write(8,604)  mod(jy,100),jm,jd,hr, cz, cc
  604     format(i3.2,2i2,f4.1,1x,a11,1x,a101)
        endif
c
c       for long period version
c       jmlast = jm
c
        call update(jy,jm,jd,hr,delt)
c
  100 continue
c
      write(8,lform)  (axis(i),i=1,nump1)
      return
      end
c===========================================================================
      subroutine kando( coef, iy, im, id, hr, ireset )
      implicit double precision (a-h,o-z)
      parameter ( maxclb = 100 )
      common /inform/ iformt, netalt, etalt(maxclb), tjet(maxclb)
      data    kstart / 1 /
ccc   external tjul
      if( iformt.eq.1 )  then
         coef = 1.d0
      else
         if( ireset.eq.1 )  kstart = 1
         t = tjul( iy, im, id, hr )
         do 10 k = kstart, netalt-1
            if( t.ge.tjet(k) .and. t.lt.tjet(k+1) )  go to 20
   10    continue
         write(8,1000)  netalt, iy, im, id, hr
 1000    format(/' ERROR at kando            netalt =', i4,
     *           '       iy,im,id,hr =', 3i4, f6.1)
         stop
c
   20    kstart = k
         coef   = etalt(k) + ( etalt(k+1) - etalt(k) )
     *           * ( t - tjet(k) ) / ( tjet(k+1) - tjet(k) )
      endif
      return
      end
c===========================================================================
      subroutine verstr
c
c     program name, version name, and source
c
      character*5   version
      character*8   pgname
      character*60  who
      common /vernam/ pgname, version, who
      pgname = 'Baytap08'
      version = '1.9.2'
      who =
     1  'NAO Mizusawa (mod by IGPP/Scripps/UC San Diego)            '
c        0        1         2         3         4         5         6
c        123456789012345678901234567890123456789012345678901234567890
      return
      end
c===========================================================================
      blockdata dtmutt
c
c  table of TD-UT from 1901.5 to 2030.5
c  last updated May 2008 by D. C. Agnew;
c  last measured value is 64.66 for 2008.5
c
      double precision tdmut
      common/dtdmut/tdmut(130)
      data tdmut/    1.7d0,   2.9d0,   4.0d0,   5.2d0,   6.3d0,
     2    7.5d0,   8.6d0,   9.7d0,  10.9d0,  12.1d0,  13.4d0,  14.6d0,
     3   15.7d0,  16.8d0,  17.8d0,  18.7d0,  19.6d0,  20.4d0,  21.1d0,
     4   21.7d0,  22.2d0,  23.0d0,  22.9d0,  23.4d0,  23.7d0,  23.9d0,
     5   23.9d0,  23.5d0,  23.7d0,  24.0d0,  24.1d0,  24.4d0,  24.2d0,
     6   24.4d0,  24.3d0,  24.2d0,  24.2d0,  24.6d0,  24.4d0,  24.6d0,
     7   25.5d0,  25.5d0,  26.4d0,  26.7d0,  26.9d0,  27.4d0,  28.2d0,
     8   28.5d0,  29.2d0,  29.9d0,  30.0d0,  30.6d0,  31.0d0,  31.3d0,
     9  31.23d0, 31.50d0, 31.92d0, 32.43d0, 32.91d0, 33.37d0, 33.78d0,
     1 34.246d0,34.735d0,35.403d0,36.151d0,37.000d0,37.887d0,38.756d0,
     2 39.708d0,40.710d0,41.689d0,42.825d0,43.961d0,44.998d0,45.986d0,
     3 47.000d0,48.038d0,49.105d0,50.105d0,50.981d0,51.817d0,52.578d0,
     4 53.438d0,54.090d0,54.640d0,55.117d0,55.585d0,56.098d0,56.574d0,
     5 57.227d0,57.962d0,58.545d0,59.590d0,60.406d0,61.250d0,61.980d0,
     6 62.638d0,63.285d0,63.660d0,63.660d0,63.660d0,63.660d0,63.660d0,
     7 63.660d0,63.660d0,64.660d0,64.660d0,64.660d0,65.000d0,65.000d0,
     8 66.500d0,67.000d0,67.500d0,68.000d0,68.500d0,69.000d0,69.500d0,
     9 70.000d0,70.500d0,71.000d0,71.500d0,72.000d0,72.500d0,73.000d0,
     1 73.500d0,74.000d0,74.500d0,75.000d0,75.500d0,76.000d0/
      end
c===========================================================================
      blockdata gr31
      character*8 ksymbol
      parameter (maxgrp = 31)
      common/group31/kg2(maxgrp,8),ksymbol(maxgrp,8)
      data ((kg2(i,j),j=1,8),i=1,maxgrp)/205,113, 65, 65, 65, 65, 65,
     1  14,360,205, 91, 91, 91, 91, 91, 24,377,296,113,113,113,113,113,
     2  35,  0,360,146,123,123,116,116, 55,  0,377,168,146,126,123,123,
     3  65,  0,  0,205,168,146,126,126, 81,  0,  0,246,205,168,137,137,
     4  91,  0,  0,270,246,205,139,139,106,  0,  0,296,270,246,146,146,
     5 113,  0,  0,310,296,270,168,168,116,  0,  0,360,310,296,205,205,
     6 123,  0,  0,377,319,310,246,246,126,  0,  0,  0,360,319,270,270,
     7 137,  0,  0,  0,377,360,296,278,139,  0,  0,  0,  0,377,300,288,
     8 146,  0,  0,  0,  0,  0,310,296,154,  0,  0,  0,  0,  0,315,300,
     9 168,  0,  0,  0,  0,  0,319,310,176,  0,  0,  0,  0,  0,360,315,
     1 186,  0,  0,  0,  0,  0,377,319,205,  0,  0,  0,  0,  0,  0,360,
     2 226,  0,  0,  0,  0,  0,  0,377,236,  0,  0,  0,  0,  0,  0,  0,
     3 246,  0,  0,  0,  0,  0,  0,  0,259,  0,  0,  0,  0,  0,  0,  0,
     4 270,  0,  0,  0,  0,  0,  0,  0,296,  0,  0,  0,  0,  0,  0,  0,
     5 310,  0,  0,  0,  0,  0,  0,  0,315,  0,  0,  0,  0,  0,  0,  0,
     6 319,  0,  0,  0,  0,  0,  0,  0,360,  0,  0,  0,  0,  0,  0,  0,
     7 377/
      data ((ksymbol(i,j),j=1,8),i=1,maxgrp)/"Diurnal ","O1 Group",
     1 "Q1      ","Q1      ","Q1      ","Q1      ","Q1      ",
     2 "W1      ","Semi D. ","K1 Group","O1      ","O1      ",
     3 "O1      ","O1      ","O1      ","2Q1     ","Ter D.  ",
     4 "M2 Group","M1      ","M1      ","M1      ","M1      ",
     5 "M1      ","Sigma1  ","        ","S2 Group","P1S1K1  ",
     6 "P1      ","P1      ","Pi1     ","Pi1     ","Q1      ",
     7 "        ","M3 Group","J1      ","S1K1    ","S1      ",
     8 "P1      ","P1      ","Rho1    ","        ","        ",
     9 "OO1     ","J1      ","K1      ","S1      ","S1      ",
     1 "O1      ","        ","        ","2N2     ","OO1     ",
     2 "J1      ","K1      ","K1      ","Tau1    ","        ",
     3 "        ","N2      ","2N2     ","OO1     ","Psi1    ",
     4 "Psi1    ","M1      ","        ","        ","M2      ",
     5 "N2      ","2N2     ","Phi1    ","Phi1    ","Chi1    ",
     6 "        ","        ","L2      ","M2      ","N2      ",
     7 "J1      ","J1      ","Pi1     ","        ","        ",
     8 "S2K2    ","L2      ","M2      ","OO1     ","OO1     ",
     9 "P1      ","        ","        ","M3      ","S2      ",
     1 "L2      ","2N2     ","2N2     ","S1      ","        ",
     2 "        ","        ","K2      ","S2      ","N2      ",
     3 "N2      ","K1      ","        ","        ","        ",
     4 "M3      ","K2      ","M2      ","Alpha2  ","Psi1    ",
     5 "        ","        ","        ","        ","M3      ",
     6 "Lambda2 ","M2      ","Phi1    ","        ","        ",
     7 "        ","        ","        ","L2      ","Beta2   ",
     8 "Theta1  ","        ","        ","        ","        ",
     9 "        ","T2      ","Lambda2 ","J1      ","        ",
     1 "        ","        ","        ","        ","S2      ",
     2 "L2      ","SO1     ","        ","        ","        ",
     3 "        ","        ","K2      ","T2      ","OO1     ",
     4 "        ","        ","        ","        ","        ",
     5 "M3      ","S2      ","V1      ","        ","        ",
     6 "        ","        ","        ","        ","K2      ",
     7 "Epsilon2","        ","        ","        ","        ",
     8 "        ","        ","M3      ","2N2     ","        ",
     9 "        ","        ","        ","        ","        ",
     1 "        ","Mu2     ","        ","        ","        ",
     2 "        ","        ","        ","        ","N2      ",
     3 "        ","        ","        ","        ","        ",
     4 "        ","        ","Nu2     ","        ","        ",
     5 "        ","        ","        ","        ","        ",
     6 "M2      ","        ","        ","        ","        ",
     7 "        ","        ","        ","L2      ","        ",
     8 "        ","        ","        ","        ","        ",
     9 "        ","T2      ","        ","        ","        ",
     1 "        ","        ","        ","        ","S2      ",
     2 "        ","        ","        ","        ","        ",
     3 "        ","        ","K2      ","        ","        ",
     4 "        ","        ","        ","        ","        ",
     5 "M3      "/
      end
c===========================================================================
      blockdata gr32
      character*8 ksymbol
      parameter (maxgrp = 31)
      common/group32/kg2(maxgrp,8),ksymbol(maxgrp,8)
      data ((kg2(i,j),j=1,8),i=1,maxgrp)/205,113, 65, 65, 65, 65, 65,
     1  35,360,205, 91, 91, 91, 91, 91, 50,377,296,113,113,113,113,113,
     2  65,  0,360,146,123,123,116,116, 91,  0,377,168,146,126,123,123,
     3 113,  0,  0,205,168,146,126,126,116,  0,  0,246,205,168,137,137,
     4 123,  0,  0,270,246,205,139,139,126,  0,  0,296,270,246,146,146,
     5 137,  0,  0,313,296,270,168,168,139,  0,  0,360,313,296,205,205,
     6 146,  0,  0,377,322,313,246,246,168,  0,  0,  0,360,322,270,270,
     7 205,  0,  0,  0,377,360,296,278,226,  0,  0,  0,  0,377,301,288,
     8 236,  0,  0,  0,  0,  0,313,296,246,  0,  0,  0,  0,  0,315,301,
     9 259,  0,  0,  0,  0,  0,322,313,270,  0,  0,  0,  0,  0,360,315,
     1 296,  0,  0,  0,  0,  0,377,322,313,  0,  0,  0,  0,  0,  0,360,
     2 315,  0,  0,  0,  0,  0,  0,377,322,  0,  0,  0,  0,  0,  0,  0,
     3 360,  0,  0,  0,  0,  0,  0,  0,377,  0,  0,  0,  0,  0,  0,  0,
     4   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     5   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     6   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     7   0/
      data ((ksymbol(i,j),j=1,8),i=1,maxgrp)/"Diurnal ","O1 Group",
     1 "Q1      ","Q1      ","Q1      ","Q1      ","Q1      ",
     2 "Sigma1  ","Semi D. ","K1 Group","O1      ","O1      ",
     3 "O1      ","O1      ","O1      ","Q1      ","Ter D.  ",
     4 "M2 Group","M1      ","M1      ","M1      ","M1      ",
     5 "M1      ","Rho1    ","        ","S2 Group","P1S1K1  ",
     6 "P1      ","P1      ","Pi1     ","Pi1     ","O1      ",
     7 "        ","M3 Group","J1      ","S1K1    ","S1      ",
     8 "P1      ","P1      ","M1      ","        ","        ",
     9 "OO1     ","J1      ","K1      ","S1      ","S1      ",
     1 "Pi1     ","        ","        ","2N2     ","OO1     ",
     2 "J1      ","K1      ","K1      ","P1      ","        ",
     3 "        ","N2      ","2N2     ","OO1     ","Psi1    ",
     4 "Psi1    ","S1      ","        ","        ","M2      ",
     5 "N2      ","2N2     ","Phi1    ","Phi1    ","K1      ",
     6 "        ","        ","L2      ","M2      ","N2      ",
     7 "J1      ","J1      ","Psi1    ","        ","        ",
     8 "S2K2    ","L2      ","M2      ","OO1     ","OO1     ",
     9 "Phi1    ","        ","        ","M3      ","S2      ",
     1 "L2      ","2N2     ","2N2     ","J1      ","        ",
     2 "        ","        ","K2      ","S2      ","N2      ",
     3 "N2      ","OO1     ","        ","        ","        ",
     4 "M3      ","K2      ","M2      ","Alpha2  ","Epsilon2",
     5 "        ","        ","        ","        ","M3      ",
     6 "Lambda2 ","M2      ","2N2     ","        ","        ",
     7 "        ","        ","        ","L2      ","Beta2   ",
     8 "Mu2     ","        ","        ","        ","        ",
     9 "        ","T2      ","Lambda2 ","N2      ","        ",
     1 "        ","        ","        ","        ","S2      ",
     2 "L2      ","Nu2     ","        ","        ","        ",
     3 "        ","        ","K2      ","T2      ","M2      ",
     4 "        ","        ","        ","        ","        ",
     5 "M3      ","S2      ","L2      ","        ","        ",
     6 "        ","        ","        ","        ","K2      ",
     7 "T2      ","        ","        ","        ","        ",
     8 "        ","        ","M3      ","S2      ","        ",
     9 "        ","        ","        ","        ","        ",
     1 "        ","K2      ","        ","        ","        ",
     2 "        ","        ","        ","        ","M3      ",
     3 "        ","        ","        ","        ","        ",
     4 "        ","        ","        ","        ","        ",
     5 "        ","        ","        ","        ","        ",
     6 "        ","        ","        ","        ","        ",
     7 "        ","        ","        ","        ","        ",
     8 "        ","        ","        ","        ","        ",
     9 "        ","        ","        ","        ","        ",
     1 "        ","        ","        ","        ","        ",
     2 "        ","        ","        ","        ","        ",
     3 "        ","        ","        ","        ","        ",
     4 "        ","        ","        ","        ","        ",
     5 "        "/
      end
c===========================================================================
      blockdata gr41
      character*8 ksymbol
      parameter (maxgrp = 31)
      common/group41/kg2(maxgrp,8),ksymbol(maxgrp,8)
      data ((kg2(i,j),j=1,8),i=1,maxgrp)/450,249,143,143,143,143,143,
     1  49,827,450,201,201,201,201,201, 72,909,655,249,249,249,249,249,
     2  92,  0,827,305,266,266,256,256,125,  0,909,345,305,270,266,266,
     3 143,  0,  0,450,345,305,270,270,175,  0,  0,549,450,345,288,288,
     4 201,  0,  0,599,549,450,292,292,231,  0,  0,655,599,549,305,305,
     5 249,  0,  0,681,655,599,345,345,256,  0,  0,827,681,655,450,450,
     6 266,  0,  0,909,710,681,549,549,270,  0,  0,  0,827,710,599,599,
     7 288,  0,  0,  0,909,827,655,612,292,  0,  0,  0,  0,909,663,631,
     8 305,  0,  0,  0,  0,  0,681,655,325,  0,  0,  0,  0,  0,701,663,
     9 345,  0,  0,  0,  0,  0,710,681,365,  0,  0,  0,  0,  0,827,701,
     1 383,  0,  0,  0,  0,  0,909,710,450,  0,  0,  0,  0,  0,  0,827,
     2 505,  0,  0,  0,  0,  0,  0,909,528,  0,  0,  0,  0,  0,  0,  0,
     3 549,  0,  0,  0,  0,  0,  0,  0,574,  0,  0,  0,  0,  0,  0,  0,
     4 599,  0,  0,  0,  0,  0,  0,  0,655,  0,  0,  0,  0,  0,  0,  0,
     5 681,  0,  0,  0,  0,  0,  0,  0,701,  0,  0,  0,  0,  0,  0,  0,
     6 710,  0,  0,  0,  0,  0,  0,  0,827,  0,  0,  0,  0,  0,  0,  0,
     7 909/
      data ((ksymbol(i,j),j=1,8),i=1,maxgrp)/"Diurnal ","O1 Group",
     1 "Q1      ","Q1      ","Q1      ","Q1      ","Q1      ",
     2 "W1      ","Semi D. ","K1 Group","O1      ","O1      ",
     3 "O1      ","O1      ","O1      ","2Q1     ","Ter D.  ",
     4 "M2 Group","M1      ","M1      ","M1      ","M1      ",
     5 "M1      ","Sigma1  ","        ","S2 Group","P1S1K1  ",
     6 "P1      ","P1      ","Pi1     ","Pi1     ","Q1      ",
     7 "        ","M3 Group","J1      ","S1K1    ","S1      ",
     8 "P1      ","P1      ","Rho1    ","        ","        ",
     9 "OO1     ","J1      ","K1      ","S1      ","S1      ",
     1 "O1      ","        ","        ","2N2     ","OO1     ",
     2 "J1      ","K1      ","K1      ","Tau1    ","        ",
     3 "        ","N2      ","2N2     ","OO1     ","Psi1    ",
     4 "Psi1    ","M1      ","        ","        ","M2      ",
     5 "N2      ","2N2     ","Phi1    ","Phi1    ","Chi1    ",
     6 "        ","        ","L2      ","M2      ","N2      ",
     7 "J1      ","J1      ","Pi1     ","        ","        ",
     8 "S2K2    ","L2      ","M2      ","OO1     ","OO1     ",
     9 "P1      ","        ","        ","M3      ","S2      ",
     1 "L2      ","2N2     ","2N2     ","S1      ","        ",
     2 "        ","        ","K2      ","S2      ","N2      ",
     3 "N2      ","K1      ","        ","        ","        ",
     4 "M3      ","K2      ","M2      ","Alpha2  ","Psi1    ",
     5 "        ","        ","        ","        ","M3      ",
     6 "Lambda2 ","M2      ","Phi1    ","        ","        ",
     7 "        ","        ","        ","L2      ","Beta2   ",
     8 "Theta1  ","        ","        ","        ","        ",
     9 "        ","T2      ","Lambda2 ","J1      ","        ",
     1 "        ","        ","        ","        ","S2      ",
     2 "L2      ","SO1     ","        ","        ","        ",
     3 "        ","        ","K2      ","T2      ","OO1     ",
     4 "        ","        ","        ","        ","        ",
     5 "M3      ","S2      ","V1      ","        ","        ",
     6 "        ","        ","        ","        ","K2      ",
     7 "Epsilon2","        ","        ","        ","        ",
     8 "        ","        ","M3      ","2N2     ","        ",
     9 "        ","        ","        ","        ","        ",
     1 "        ","Mu2     ","        ","        ","        ",
     2 "        ","        ","        ","        ","N2      ",
     3 "        ","        ","        ","        ","        ",
     4 "        ","        ","Nu2     ","        ","        ",
     5 "        ","        ","        ","        ","        ",
     6 "M2      ","        ","        ","        ","        ",
     7 "        ","        ","        ","L2      ","        ",
     8 "        ","        ","        ","        ","        ",
     9 "        ","T2      ","        ","        ","        ",
     1 "        ","        ","        ","        ","S2      ",
     2 "        ","        ","        ","        ","        ",
     3 "        ","        ","K2      ","        ","        ",
     4 "        ","        ","        ","        ","        ",
     5 "M3      "/
      end
c===========================================================================
      blockdata gr42
      character*8 ksymbol
      parameter (maxgrp = 31)
      common/group42/kg2(maxgrp,8),ksymbol(maxgrp,8)
      data ((kg2(i,j),j=1,8),i=1,maxgrp)/450,249,143,143,143,143,143,
     1  92,827,450,201,201,201,201,201,116,909,655,249,249,249,249,249,
     2 143,  0,827,305,266,266,256,256,201,  0,909,345,305,270,266,266,
     3 249,  0,  0,450,345,305,270,270,256,  0,  0,549,450,345,288,288,
     4 266,  0,  0,599,549,450,292,292,270,  0,  0,655,599,549,305,305,
     5 288,  0,  0,694,655,599,345,345,292,  0,  0,827,694,655,450,450,
     6 305,  0,  0,909,715,694,549,549,345,  0,  0,  0,827,715,599,599,
     7 450,  0,  0,  0,909,827,655,612,505,  0,  0,  0,  0,909,668,631,
     8 528,  0,  0,  0,  0,  0,694,655,549,  0,  0,  0,  0,  0,701,668,
     9 574,  0,  0,  0,  0,  0,715,694,599,  0,  0,  0,  0,  0,827,701,
     1 612,  0,  0,  0,  0,  0,909,715,631,  0,  0,  0,  0,  0,  0,827,
     2 655,  0,  0,  0,  0,  0,  0,909,668,  0,  0,  0,  0,  0,  0,  0,
     3 694,  0,  0,  0,  0,  0,  0,  0,701,  0,  0,  0,  0,  0,  0,  0,
     4 715,  0,  0,  0,  0,  0,  0,  0,827,  0,  0,  0,  0,  0,  0,  0,
     5 909,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     6   0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,  0,
     7   0/
      data ((ksymbol(i,j),j=1,8),i=1,maxgrp)/"Diurnal ","O1 Group",
     1 "Q1      ","Q1      ","Q1      ","Q1      ","Q1      ",
     2 "Sigma1  ","Semi D. ","K1 Group","O1      ","O1      ",
     3 "O1      ","O1      ","O1      ","Q1      ","Ter D.  ",
     4 "M2 Group","M1      ","M1      ","M1      ","M1      ",
     5 "M1      ","Rho1    ","        ","S2 Group","P1S1K1  ",
     6 "P1      ","P1      ","Pi1     ","Pi1     ","O1      ",
     7 "        ","M3 Group","J1      ","S1K1    ","S1      ",
     8 "P1      ","P1      ","M1      ","        ","        ",
     9 "OO1     ","J1      ","K1      ","S1      ","S1      ",
     1 "Pi1     ","        ","        ","2N2     ","OO1     ",
     2 "J1      ","K1      ","K1      ","P1      ","        ",
     3 "        ","N2      ","2N2     ","OO1     ","Psi1    ",
     4 "Psi1    ","S1      ","        ","        ","M2      ",
     5 "N2      ","2N2     ","Phi1    ","Phi1    ","K1      ",
     6 "        ","        ","L2      ","M2      ","N2      ",
     7 "J1      ","J1      ","Psi1    ","        ","        ",
     8 "S2K2    ","L2      ","M2      ","OO1     ","OO1     ",
     9 "Phi1    ","        ","        ","M3      ","S2      ",
     1 "L2      ","2N2     ","2N2     ","J1      ","        ",
     2 "        ","        ","K2      ","S2      ","N2      ",
     3 "N2      ","OO1     ","        ","        ","        ",
     4 "M3      ","K2      ","M2      ","Alpha2  ","Epsilon2",
     5 "        ","        ","        ","        ","M3      ",
     6 "Lambda2 ","M2      ","2N2     ","        ","        ",
     7 "        ","        ","        ","L2      ","Beta2   ",
     8 "Mu2     ","        ","        ","        ","        ",
     9 "        ","T2      ","Lambda2 ","N2      ","        ",
     1 "        ","        ","        ","        ","S2      ",
     2 "L2      ","Nu2     ","        ","        ","        ",
     3 "        ","        ","K2      ","T2      ","Alpha2  ",
     4 "        ","        ","        ","        ","        ",
     5 "M3      ","S2      ","M2      ","        ","        ",
     6 "        ","        ","        ","        ","K2      ",
     7 "Beta2   ","        ","        ","        ","        ",
     8 "        ","        ","M3      ","Lambda2 ","        ",
     9 "        ","        ","        ","        ","        ",
     1 "        ","L2      ","        ","        ","        ",
     2 "        ","        ","        ","        ","T2      ",
     3 "        ","        ","        ","        ","        ",
     4 "        ","        ","S2      ","        ","        ",
     5 "        ","        ","        ","        ","        ",
     6 "K2      ","        ","        ","        ","        ",
     7 "        ","        ","        ","M3      ","        ",
     8 "        ","        ","        ","        ","        ",
     9 "        ","        ","        ","        ","        ",
     1 "        ","        ","        ","        ","        ",
     2 "        ","        ","        ","        ","        ",
     3 "        ","        ","        ","        ","        ",
     4 "        ","        ","        ","        ","        ",
     5 "        "/
      end
c===========================================================================
      blockdata tab3
      double precision avc,amc
      common/hart3/avc(377),amc(377),ip(377),idn(377,6)
      data ip/2,2,2,3,2,2,2,3,2,2,2,2,2,2,2,2,3,3,2,2,2,2,2,2,3,2,2,2,
     12,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,2,2,2,2,3,2,2,2,2,2,2,2,2,2,3,
     22,2,2,2,2,2,2,2,2,2,2,2,3,2,2,2,3,3,3,2,2,2,2,2,2,3,2,2,2,2,2,
     32,2,2,2,2,2,2,2,2,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,
     42,2,2,2,2,2,3,3,2,3,2,2,2,2,3,3,2,2,2,2,2,2,2,2,2,2,2,3,2,2,2,
     52,2,2,2,2,3,2,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,3,2,2,2,2,3,3,2,2,
     62,2,2,2,2,2,2,3,2,2,2,2,2,2,2,3,3,2,2,2,2,2,2,2,2,3,2,2,2,2,3,
     72,2,2,2,3,3,2,2,2,2,2,2,2,2,2,3,3,2,2,2,2,2,3,3,2,2,2,2,2,2,2,
     82,2,2,2,2,2,3,3,3,2,2,2,2,3,2,2,2,2,2,2,3,2,2,2,2,2,2,3,2,2,2,
     92,2,3,3,2,2,2,3,3,3,2,2,2,2,2,3,2,2,2,2,2,2,2,2,2,2,2,3,3,3,2,
     12,2,2,2,2,2,2,2,2,2,3,2,2,2,2,3,3,2,2,2,2,2,2,2,2,2,2,3,2,2,2,
     22,2,2,2,3,3,3,2,2,2,2,2,2,2,3,2,2,2,2,2,2,2,3,3,3,3,3,3,3,3,3,
     33,3,3,3,3,3,3,3/
      data ((idn(i,j),j=1,6),i=1,377)/ 1,-5, 0, 4, 0, 0, 1,-5, 2, 2,
     2 0, 0, 1,-5, 4, 0, 0, 0, 1,-4, 0, 2, 0, 0, 1,-4, 0, 3,-1, 0, 1,
     3-4, 0, 3, 0, 0, 1,-4, 1, 1, 0, 1, 1,-4, 2, 0, 0, 0, 1,-4, 2, 1,
     4-1, 0, 1,-4, 2, 1, 0, 0, 1,-4, 3, 1, 0,-1, 1,-4, 4,-1,-1, 0, 1,
     5-4, 4,-1, 0, 0, 1,-4, 5,-1, 0,-1, 1,-3,-1, 2, 0, 1, 1,-3, 0, 0,
     6-2, 0, 1,-3, 0, 1,-1, 0, 1,-3, 0, 1, 0, 0, 1,-3, 0, 2,-2, 0, 1,
     7-3, 0, 2,-1, 0, 1,-3, 0, 2, 0, 0, 1,-3, 1, 0, 0, 1, 1,-3, 1, 1,
     8 0, 0, 1,-3, 1, 2, 0,-1, 1,-3, 2,-1, 0, 0, 1,-3, 2, 0,-2, 0, 1,
     9-3, 2, 0,-1, 0, 1,-3, 2, 0, 0, 0, 1,-3, 2, 2, 0, 0, 1,-3, 3, 0,
     1-1,-1, 1,-3, 3, 0, 0,-1, 1,-3, 4,-2,-1, 0, 1,-3, 4,-2, 0, 0, 1,
     2-3, 4, 0, 0, 0, 1,-3, 4, 0, 1, 0, 1,-2,-2, 1,-2, 0, 1,-2,-2, 3,
     3 0, 0, 1,-2,-1, 1,-1, 1, 1,-2,-1, 1, 0, 1, 1,-2, 0,-1,-3, 0, 1,
     4-2, 0,-1,-2, 0, 1,-2, 0, 0,-2, 0, 1,-2, 0, 0,-1, 0, 1,-2, 0, 0,
     5 0, 0, 1,-2, 0, 0, 0, 1, 1,-2, 0, 1,-2, 0, 1,-2, 0, 1,-1, 0, 1,
     6-2, 0, 1, 0, 0, 1,-2, 0, 2, 0, 0, 1,-2, 0, 3, 0, 0, 1,-2, 1,-1,
     7 0, 1, 1,-2, 1, 0,-1, 0, 1,-2, 1, 0, 0, 0, 1,-2, 1, 1,-1,-1, 1,
     8-2, 1, 1, 0,-1, 1,-2, 2,-1,-2, 0, 1,-2, 2,-1,-1, 0, 1,-2, 2,-1,
     9 0, 0, 1,-2, 2, 0, 0, 0, 1,-2, 2, 1, 0, 0, 1,-2, 2, 1, 1, 0, 1,
     1-2, 3,-1,-1,-1, 1,-2, 3,-1, 0,-1, 1,-2, 3, 1, 0,-1, 1,-2, 4,-1,
     2 0, 0, 1,-1,-2, 0,-2, 0, 1,-1,-2, 2,-1, 0, 1,-1,-2, 2, 0, 0, 1,
     3-1,-1, 0,-1, 1, 1,-1,-1, 0, 0, 1, 1,-1,-1, 1, 0, 0, 1,-1, 0,-1,
     4 0, 0, 1,-1, 0, 0,-2, 0, 1,-1, 0, 0,-1, 0, 1,-1, 0, 0, 0, 0, 1,
     5-1, 0, 1,-1, 0, 1,-1, 0, 1, 0, 0, 1,-1, 0, 1, 1, 0, 1,-1, 0, 2,
     6-1, 0, 1,-1, 0, 2, 0, 0, 1,-1, 0, 2, 1, 0, 1,-1, 1, 0,-1,-1, 1,
     7-1, 1, 0, 0,-1, 1,-1, 2,-2, 0, 0, 1,-1, 2,-1, 0, 0, 1,-1, 2, 0,
     8-1, 0, 1,-1, 2, 0, 0, 0, 1,-1, 2, 0, 1, 0, 1,-1, 2, 0, 2, 0, 1,
     9-1, 3, 0, 0,-1, 1,-1, 4,-2, 0, 0, 1, 0,-3, 1, 0, 1, 1, 0,-2, 1,
     1-1, 0, 1, 0,-2, 1, 0, 0, 1, 0,-1, 0, 0, 0, 1, 0,-1, 1, 0, 1, 1,
     2 0, 0,-1,-2, 0, 1, 0, 0,-1,-1, 0, 1, 0, 0,-1, 0, 0, 1, 0, 0, 0,
     3-1, 0, 1, 0, 0, 0, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 0, 1,-1, 0, 1,
     4 0, 0, 1, 0, 0, 1, 0, 0, 1, 1, 0, 1, 0, 0, 1, 2, 0, 1, 0, 1, 0,
     5 0, 0, 1, 0, 1, 1, 0,-1, 1, 0, 2,-1,-1, 0, 1, 0, 2,-1, 0, 0, 1,
     6 0, 2,-1, 1, 0, 1, 0, 3,-1, 0,-1, 1, 0, 3,-1, 1,-1, 1, 1,-4, 0,
     7 0, 2, 1, 1,-3, 0,-1, 1, 1, 1,-3, 0, 0, 1, 1, 1,-2, 0,-2, 0, 1,
     8 1,-2, 0,-1, 0, 1, 1,-2, 0, 0, 0, 1, 1,-2, 0, 0, 2, 1, 1,-2, 1,
     9 0, 0, 1, 1,-2, 2, 0, 0, 1, 1,-2, 2, 1, 0, 1, 1,-1, 0, 0,-1, 1,
     1 1,-1, 0, 0, 1, 1, 1,-1, 0, 1, 1, 1, 1, 0,-2,-1, 0, 1, 1, 0,-1,
     2-1, 0, 1, 1, 0,-1, 0, 0, 1, 1, 0, 0,-2, 0, 1, 1, 0,-1, 1, 0, 1,
     3 1, 0, 0,-1, 0, 1, 1, 0, 0, 0, 0, 1, 1, 0, 0, 1, 0, 1, 1, 0, 0,
     4 2, 0, 1, 1, 0, 1, 0, 0, 1, 1, 0, 1, 1, 0, 1, 1, 1, 0, 0,-1, 1,
     5 1, 1, 0, 1,-1, 1, 1, 2,-2, 0, 0, 1, 1, 2,-2, 1, 0, 1, 1, 2, 0,
     6 0,-2, 1, 1, 2, 0, 0, 0, 1, 1, 2, 0, 1, 0, 1, 1, 2, 0, 2, 0, 1,
     7 1, 3, 0, 0,-1, 1, 2,-3, 1, 0, 1, 1, 2,-2,-1,-1, 0, 1, 2,-2, 0,
     8 0, 0, 1, 2,-2, 1,-1, 0, 1, 2,-2, 1, 0, 0, 1, 2,-2, 1, 1, 0, 1,
     9 2,-1,-1, 0, 1, 1, 2,-1, 0, 0, 0, 1, 2, 0,-1,-1, 0, 1, 2, 0,-1,
     1 0, 0, 1, 2, 0,-1, 1, 0, 1, 2, 0, 0,-1, 0, 1, 2, 0,-1, 2, 0, 1,
     2 2, 0, 0, 0, 0, 1, 2, 0, 0, 1, 0, 1, 2, 0, 0, 2, 0, 1, 2, 0, 1,
     3 0, 0, 1, 2, 0, 1, 1, 0, 1, 2, 0, 1, 2, 0, 1, 2, 1,-1, 0,-1, 1,
     4 2, 2,-1, 0, 0, 1, 2, 2,-1, 1, 0, 1, 3,-4, 2, 0, 0, 1, 3,-3, 0,
     5 0, 1, 1, 3,-3, 0, 1, 1, 1, 3,-2, 0,-1, 0, 1, 3,-2, 0, 0, 0, 1,
     6 3,-2, 0, 1, 0, 1, 3,-2, 1, 0, 0, 1, 3,-1, 0, 0,-1, 1, 3, 0,-2,
     7-1, 0, 1, 3, 0,-2, 0, 0, 1, 3, 0,-2, 1, 0, 1, 3, 0,-1, 0, 0, 1,
     8 3, 0,-1, 1, 0, 1, 3, 0, 0, 0, 0, 1, 3, 0, 0, 1, 0, 1, 3, 0, 0,
     9 2, 0, 1, 3, 0, 0, 3, 0, 1, 3, 1, 0, 0,-1, 1, 4,-4, 1, 0, 0, 1,
     1 4,-3,-1, 0, 1, 1, 4,-2,-1, 0, 0, 1, 4,-2,-1, 1, 0, 1, 4,-2, 0,
     2 0, 0, 1, 4,-2, 1, 0, 0, 1, 4,-2, 1, 1, 0, 1, 4,-2, 1, 2, 0, 1,
     3 4, 0,-3, 0, 0, 1, 4, 0,-1, 0, 0, 1, 4, 0,-1, 1, 0, 1, 4, 0,-1,
     4 2, 0, 1, 4, 0, 0, 0, 0, 1, 4, 0, 0, 1, 0, 1, 5,-2, 0, 0, 0, 1,
     5 5,-2, 0, 1, 0, 1, 5, 0,-2, 0, 0, 1, 5, 0,-2, 1, 0, 1, 6,-2,-1,
     6 0, 0, 2,-5, 2, 3, 0, 0, 2,-5, 4, 1, 0, 0, 2,-4, 0, 4, 0, 0, 2,
     7-4, 2, 1, 0, 0, 2,-4, 2, 2, 0, 0, 2,-4, 3, 2, 0,-1, 2,-4, 4, 0,
     8 0, 0, 2,-4, 5, 0, 0,-1, 2,-3, 0, 2, 0, 0, 2,-3, 0, 3,-1, 0, 2,
     9-3, 0, 3, 0, 0, 2,-3, 1, 1, 0, 1, 2,-3, 1, 3, 0,-1, 2,-3, 2, 0,
     1-1, 0, 2,-3, 2, 0, 0, 0, 2,-3, 2, 1,-1, 0, 2,-3, 2, 1, 0, 0, 2,
     2-3, 3, 1, 0,-1, 2,-3, 4,-1,-1, 0, 2,-3, 4,-1, 0, 0, 2,-3, 5,-1,
     3 0,-1, 2,-2,-2, 4, 0, 0, 2,-2,-1, 2, 0, 1, 2,-2, 0, 0,-2, 0, 2,
     4-2, 0, 1,-1, 0, 2,-2, 0, 1, 0, 0, 2,-2, 0, 2,-1, 0, 2,-2, 0, 2,
     5 0, 0, 2,-2, 1, 0, 0, 1, 2,-2, 1, 1, 0, 0, 2,-2, 1, 2, 0,-1, 2,
     6-2, 2,-1,-1, 0, 2,-2, 2,-1, 0, 0, 2,-2, 2, 0,-1, 0, 2,-2, 2, 0,
     7 0, 0, 2,-2, 3,-1, 0, 0, 2,-2, 3, 0,-1,-1, 2,-2, 3, 0, 0,-1, 2,
     8-2, 4,-2, 0, 0, 2,-2, 4, 0, 0,-2, 2,-2, 5,-2, 0,-1, 2,-1,-2, 1,
     9-2, 0, 2,-1,-2, 3, 0, 0, 2,-1,-1, 1,-1, 1, 2,-1,-1, 1, 0, 1, 2,
     1-1, 0,-1,-2, 0, 2,-1, 0, 0,-2, 0, 2,-1, 0, 0,-1, 0, 2,-1, 0, 0,
     2 0, 0, 2,-1, 0, 0, 0, 1, 2,-1, 0, 1,-2, 0, 2,-1, 0, 1,-1, 0, 2,
     3-1, 0, 1, 0, 0, 2,-1, 0, 2, 0, 0, 2,-1, 1,-1, 0, 1, 2,-1, 1, 0,
     4 0, 0, 2,-1, 1, 1,-1,-1, 2,-1, 1, 1, 0,-1, 2,-1, 2,-1,-1, 0, 2,
     5-1, 2,-1, 0, 0, 2,-1, 2, 0, 0, 0, 2,-1, 2, 1, 0, 0, 2,-1, 2, 1,
     6 1, 0, 2,-1, 3,-1,-1,-1, 2,-1, 3,-1, 0,-1, 2, 0,-3, 2, 0, 1, 2,
     7 0,-2, 0,-2, 0, 2, 0,-2, 1, 0, 0, 2, 0,-2, 2,-1, 0, 2, 0,-2, 2,
     8 0, 0, 2, 0,-1, 0,-1, 1, 2, 0,-1, 0, 0, 1, 2, 0,-1, 1, 0, 0, 2,
     9 0, 0,-1,-1, 0, 2, 0, 0,-1, 0, 0, 2, 0, 0, 0,-2, 0, 2, 0, 0, 0,
     1-1, 0, 2, 0, 0, 0, 0, 0, 2, 0, 0, 1,-1, 0, 2, 0, 0, 1, 0, 0, 2,
     2 0, 0, 1, 1, 0, 2, 0, 0, 2, 0, 0, 2, 0, 0, 2, 1, 0, 2, 0, 1, 0,
     3-1,-1, 2, 0, 1, 0, 0,-1, 2, 0, 2,-2, 0, 0, 2, 0, 2,-1, 0, 0, 2,
     4 0, 2, 0, 0, 0, 2, 0, 2, 0, 1, 0, 2, 0, 2, 0, 2, 0, 2, 0, 3, 0,
     5 0,-1, 2, 1,-3, 1, 0, 1, 2, 1,-2, 1,-1, 0, 2, 1,-2, 1, 0, 0, 2,
     6 1,-1,-1, 0, 1, 2, 1,-1, 0, 0, 0, 2, 1, 0,-1,-1, 0, 2, 1, 0,-1,
     7 0, 0, 2, 1, 0, 0,-1, 0, 2, 1, 0, 0, 0, 0, 2, 1, 0, 0, 1, 0, 2,
     8 1, 0, 1,-1, 0, 2, 1, 0, 1, 0, 0, 2, 1, 0, 1, 1, 0, 2, 1, 0, 1,
     9 2, 0, 2, 1, 2,-1, 0, 0, 2, 1, 2,-1, 1, 0, 2, 1, 2,-1, 2, 0, 2,
     1 2,-4, 0, 0, 2, 2, 2,-3, 0, 0, 1, 2, 2,-2, 0,-1, 0, 2, 2,-2, 0,
     2 0, 0, 2, 2,-2, 1, 0, 0, 2, 2,-2, 2, 0, 0, 2, 2,-1, 0, 0,-1, 2,
     3 2,-1, 0, 0, 1, 2, 2,-1, 0, 1, 1, 2, 2, 0,-1, 0, 0, 2, 2, 0,-1,
     4 1, 0, 2, 2, 0, 0,-1, 0, 2, 2, 0, 0, 0, 0, 2, 2, 0, 0, 1, 0, 2,
     5 2, 0, 0, 2, 0, 2, 2, 1, 0, 0,-1, 2, 2, 2,-2, 0, 0, 2, 2, 2, 0,
     6 0, 0, 2, 3,-3, 1, 0, 1, 2, 3,-2,-1,-1, 0, 2, 3,-2,-1, 0, 0, 2,
     7 3,-2, 0, 0, 0, 2, 3,-2, 1, 0, 0, 2, 3,-2, 1, 1, 0, 2, 3,-2, 1,
     8 2, 0, 2, 3, 0,-1,-1, 0, 2, 3, 0,-1, 0, 0, 2, 3, 0,-1, 1, 0, 2,
     9 3, 0,-1, 2, 0, 2, 3, 0, 0, 0, 0, 2, 3, 0, 0, 1, 0, 2, 3, 0, 0,
     1 2, 0, 2, 3, 0, 1, 0, 0, 2, 4,-3, 0, 0, 1, 2, 4,-2, 0, 0, 0, 2,
     2 4,-2, 0, 1, 0, 2, 4,-2, 0, 2, 0, 2, 4, 0,-2, 0, 0, 2, 4, 0,-2,
     3 1, 0, 2, 4, 0,-1, 0, 0, 2, 4, 0, 0, 0, 0, 2, 4, 0, 0, 1, 0, 2,
     4 4, 0, 0, 2, 0, 2, 4, 0, 0, 3, 0, 2, 5,-2,-1, 0, 0, 2, 5, 0,-1,
     5 0, 0, 2, 5, 0,-1, 1, 0, 3,-3, 2, 1, 0, 0, 3,-2, 0, 2, 0, 0, 3,
     6-2, 2, 0, 0, 0, 3,-1, 0, 1,-1, 0, 3,-1, 0, 1, 0, 0, 3,-1, 2,-1,
     7 0, 0, 3, 0,-2, 2, 0, 0, 3, 0, 0, 0,-1, 0, 3, 0, 0, 0, 0, 0, 3,
     8 1,-2, 1, 0, 0, 3, 1, 0,-1, 0, 0, 3, 1, 0, 1, 0, 0, 3, 1, 0, 1,
     9 1, 0, 3, 2, 0, 0,-1, 0, 3, 2, 0, 0, 0, 0, 3, 2, 0, 0, 1, 0, 3,
     1 2, 0, 0, 2, 0/
      data avc/ 11.76553681, 11.83839044, 11.91124407, 12.30526966,
     2 12.30770509, 12.30991150, 12.34169843, 12.37812327, 12.38055869,
     3 12.38276510, 12.42383178, 12.45341229, 12.45561871, 12.49668539,
     4 12.81321951, 12.84058969, 12.84743794, 12.84964436, 12.84987337,
     5 12.85207978, 12.85428619, 12.88607312, 12.89071299, 12.89535287,
     6 12.92249796, 12.92272697, 12.92493338, 12.92713980, 12.93642347,
     7 12.96600006, 12.96820647, 12.99778699, 12.99999340, 13.00927707,
     8 13.01148349, 13.31211078, 13.32580728, 13.35538779, 13.35759421,
     9 13.38275797, 13.38496439, 13.38960622, 13.39181264, 13.39401905,
     1 13.39402101, 13.39424806, 13.39645447, 13.39866089, 13.40330272,
     2 13.40794456, 13.43044781, 13.43288127, 13.43508769, 13.43752115,
     3 13.43972756, 13.46710166, 13.46930808, 13.47151449, 13.47615633,
     4 13.48079816, 13.48300458, 13.51037475, 13.51258117, 13.52186484,
     5 13.55365177, 13.85648547, 13.86797556, 13.87018197, 13.89976249,
     6 13.90196890, 13.90660878, 13.93839374, 13.93862275, 13.94082917,
     7 13.94303558, 13.94547100, 13.94767742, 13.94988383, 13.95011284,
     8 13.95231925, 13.95452567, 13.98189584, 13.98410226, 14.01588918,
     9 14.02053102, 14.02296644, 14.02517286, 14.02737927, 14.02958568,
     1 14.06623953, 14.09802646, 14.37348999, 14.41235025, 14.41455667,
     2 14.45098347, 14.45562727, 14.48299745, 14.48520386, 14.48741027,
     3 14.48984570, 14.49205211, 14.49425852, 14.49448753, 14.49669395,
     4 14.49890036, 14.50110677, 14.53312075, 14.53776062, 14.56734114,
     5 14.56954755, 14.57175396, 14.61061423, 14.61282064, 14.87679800,
     6 14.91565827, 14.91786468, 14.95451853, 14.95672495, 14.95893136,
     7 14.95893528, 14.96357320, 14.96821503, 14.97042145, 14.99999804,
     8 15.00000196, 15.00220837, 15.02957855, 15.03422039, 15.03642680,
     9 15.03665581, 15.03863321, 15.03886223, 15.04106864, 15.04327505,
     1 15.04548146, 15.04571048, 15.04791689, 15.08213532, 15.08434173,
     2 15.11392224, 15.11612866, 15.12320199, 15.12320592, 15.12541233,
     3 15.12761874, 15.16427259, 15.47152305, 15.50109964, 15.50794789,
     4 15.51038331, 15.51258973, 15.51479614, 15.54437665, 15.54901653,
     5 15.58323692, 15.58544333, 15.58764974, 15.58787876, 15.58985616,
     6 15.59008517, 15.59229158, 15.59449799, 15.59472701, 15.59693342,
     7 15.59913983, 15.62651001, 15.66758061, 15.66978702, 15.98411082,
     8 16.01589774, 16.01810416, 16.05475801, 16.05696442, 16.05917083,
     9 16.06160626, 16.09803110, 16.12761161, 16.12981802, 16.13202444,
     1 16.13445986, 16.13666627, 16.13910170, 16.14130811, 16.14351452,
     2 16.14572094, 16.18016838, 16.52848551, 16.56027244, 16.60133911,
     3 16.60354553, 16.60598095, 16.61062279, 16.61282920, 16.61503561,
     4 16.67419272, 16.68347639, 16.68568280, 16.68788922, 16.68811823,
     5 16.69032464, 17.15499744, 17.15720385, 17.22785108, 17.23005749,
     6 17.69937214, 26.33508438, 26.40793802, 26.80660545, 26.87481721,
     7 26.87945905, 26.92052573, 26.95231265, 26.99337933, 27.34633830,
     8 27.34877373, 27.35098014, 27.38276706, 27.39204682, 27.41698549,
     9 27.41919191, 27.42162733, 27.42383374, 27.46490042, 27.49448093,
     1 27.49668735, 27.53775402, 27.82250123, 27.85428815, 27.88165833,
     2 27.88850658, 27.89071299, 27.89314842, 27.89535483, 27.92714176,
     3 27.93178163, 27.93642151, 27.96136019, 27.96356660, 27.96600202,
     4 27.96820844, 28.00463524, 28.00706870, 28.00927511, 28.04106204,
     5 28.05034179, 28.08212872, 28.35317942, 28.36687592, 28.39645643,
     6 28.39866285, 28.42603302, 28.43067486, 28.43288127, 28.43508769,
     7 28.43508965, 28.43531670, 28.43752311, 28.43972952, 28.44437136,
     8 28.47151645, 28.47615633, 28.47858979, 28.48079620, 28.51037672,
     9 28.51258313, 28.51722497, 28.52186680, 28.52407322, 28.55144339,
     1 28.55364981, 28.87018394, 28.89755411, 28.90660878, 28.90904420,
     2 28.91125061, 28.94083113, 28.94303754, 28.94767742, 28.97725597,
     3 28.97946238, 28.97969139, 28.98189780, 28.98410422, 28.98653964,
     4 28.98874605, 28.99095247, 28.99338789, 28.99559430, 29.02296448,
     5 29.02517090, 29.05695782, 29.06159966, 29.06624150, 29.06844791,
     6 29.07065432, 29.10730817, 29.41455863, 29.45341889, 29.45562531,
     7 29.48741223, 29.49205211, 29.52627250, 29.52847891, 29.53091433,
     8 29.53312075, 29.53532716, 29.53555617, 29.53776258, 29.53996900,
     9 29.54217541, 29.61061619, 29.61282260, 29.61502901, 29.91786664,
     1 29.95893332, 29.99779359, 30.00000000, 30.00464184, 30.00928367,
     2 30.04106668, 30.04107060, 30.04327701, 30.07749544, 30.07970185,
     3 30.07993086, 30.08213728, 30.08434369, 30.08655010, 30.12320396,
     4 30.15499088, 30.16427456, 30.51259169, 30.54216828, 30.54437469,
     5 30.54901653, 30.55365837, 30.55586478, 30.55807119, 30.62430556,
     6 30.62651197, 30.62871838, 30.63092480, 30.63115381, 30.63336022,
     7 30.63556663, 30.63579564, 31.05696638, 31.09803306, 31.10023947,
     8 31.10244589, 31.17088666, 31.17309308, 31.17552850, 31.18017034,
     9 31.18237675, 31.18458316, 31.18678958, 31.64240774, 31.72454502,
     1 31.72675143, 41.91588590, 42.38740694, 42.46026054, 42.92957522,
     2 42.93178163, 43.00463524, 43.40330272, 43.47394991, 43.47615633,
     3 43.94767742, 44.02053102, 44.02981469, 44.03202111, 44.57198297,
     4 44.57418939, 44.57639580, 44.57860221/
      data amc/    0.00011,    0.00046,    0.00028,   -0.00010,
     2    0.00020,    0.00107,   -0.00005,   -0.00010,    0.00053,
     3    0.00278,    0.00021,    0.00010,    0.00054,    0.00006,
     4   -0.00013,   -0.00006,   -0.00023,   -0.00058,   -0.00006,
     5    0.00180,    0.00955,   -0.00016,   -0.00010,    0.00015,
     6   -0.00011,   -0.00007,    0.00217,    0.01152,   -0.00010,
     7    0.00014,    0.00078,    0.00007,    0.00035,   -0.00011,
     8    0.00005,   -0.00006,   -0.00023,   -0.00010,   -0.00061,
     9   -0.00005,   -0.00028,   -0.00007,   -0.00083,   -0.00211,
     1    0.00006,   -0.00041,    0.01360,    0.07217,   -0.00013,
     2   -0.00020,   -0.00014,   -0.00007,   -0.00039,    0.00011,
     3    0.00066,   -0.00008,    0.00258,    0.01371,   -0.00018,
     4   -0.00079,    0.00024,    0.00012,    0.00063,   -0.00006,
     5   -0.00017,   -0.00016,   -0.00020,   -0.00113,   -0.00015,
     6   -0.00130,    0.00006,    0.00012,   -0.00218,    0.07106,
     7    0.37694,    0.00016,   -0.00108,    0.00014,    0.00007,
     8   -0.00243,   -0.00039,    0.00012,    0.00109,   -0.00022,
     9   -0.00021,    0.00014,   -0.00493,    0.00107,    0.00007,
     1   -0.00033,   -0.00009,   -0.00013,   -0.00063,   -0.00278,
     2    0.00006,    0.00015,    0.00017,   -0.00197,   -0.01066,
     3    0.00098,   -0.00660,    0.00086,    0.00086,   -0.02964,
     4   -0.00594,    0.00016,    0.00017,   -0.00018,    0.00016,
     5   -0.00567,   -0.00124,   -0.00024,   -0.00006,    0.00042,
     6   -0.00008,    0.01028,    0.00014,   -0.00197,    0.17543,
     7   -0.00007,   -0.00007,   -0.00026,   -0.00005,   -0.00147,
     8   -0.00416,    0.00011,   -0.00010,    0.00005,   -0.00036,
     9   -0.00006,    0.00005,    0.01051,   -0.53011,   -0.07186,
     1    0.00155,   -0.00013,   -0.00005,   -0.00422,   -0.00008,
     2   -0.00026,   -0.00008,   -0.00010,   -0.00755,    0.00029,
     3    0.00014,   -0.00044,   -0.00024,   -0.00017,   -0.00008,
     4    0.00018,   -0.00567,   -0.00113,   -0.00018,    0.00016,
     5    0.00087,   -0.02964,   -0.00587,    0.00008,    0.00014,
     6   -0.00242,   -0.00098,   -0.00008,    0.00045,    0.00029,
     7    0.00017,    0.00015,    0.00012,    0.00009,   -0.00009,
     8   -0.00032,   -0.00006,   -0.00016,   -0.00492,   -0.00096,
     9   -0.00008,    0.00010,    0.00006,   -0.00243,   -0.00048,
     1   -0.00039,   -0.00016,   -0.01624,   -0.01039,   -0.00218,
     2   -0.00014,    0.00006,   -0.00015,   -0.00006,   -0.00078,
     3   -0.00015,   -0.00007,   -0.00059,   -0.00038,   -0.00008,
     4   -0.00019,   -0.00311,   -0.00199,   -0.00041,   -0.00009,
     5   -0.00008,   -0.00050,   -0.00032,   -0.00041,   -0.00027,
     6   -0.00012,    0.00015,    0.00018,    0.00027,   -0.00008,
     7    0.00111,    0.00009,    0.00069,    0.00009,   -0.00027,
     8   -0.00010,    0.00259,   -0.00013,    0.00006,   -0.00005,
     9   -0.00027,   -0.00025,    0.00671,    0.00051,   -0.00005,
     1    0.00130,    0.00015,   -0.00009,   -0.00031,   -0.00014,
     2   -0.00027,   -0.00156,   -0.00086,    0.02301,   -0.00039,
     3   -0.00025,    0.00036,   -0.00005,   -0.00029,   -0.00104,
     4    0.02776,   -0.00007,   -0.00007,    0.00188,    0.00085,
     5    0.00007,    0.00008,   -0.00015,   -0.00056,    0.00005,
     6   -0.00147,   -0.00067,    0.00005,   -0.00097,   -0.00569,
     7    0.00014,    0.00009,   -0.00649,    0.17386,    0.00010,
     8   -0.00032,   -0.00094,   -0.00005,    0.00163,   -0.00123,
     9    0.03302,    0.00014,    0.00014,   -0.00012,   -0.00006,
     1    0.00153,   -0.00011,   -0.00039,    0.00008,    0.00009,
     2   -0.00273,    0.00007,   -0.00313,    0.00014,    0.00005,
     3    0.00032,    0.00047,   -0.03390,    0.90809,   -0.00005,
     4    0.00086,    0.00016,    0.00053,    0.00019,   -0.00006,
     5    0.00277,   -0.00052,    0.00017,    0.00104,   -0.00051,
     6    0.00017,    0.00007,   -0.00032,    0.00030,   -0.00670,
     7   -0.00010,    0.00016,    0.00094,   -0.02567,   -0.00031,
     8    0.00525,    0.00099,   -0.00012,    0.00643,    0.00283,
     9    0.00040,    0.00123,    0.00059,    0.00007,    0.00101,
     1    0.02476,    0.00095,    0.42248,    0.00005,    0.00006,
     2   -0.00355,    0.00090,   -0.00005,    0.00028,    0.00005,
     3   -0.00147,    0.11498,    0.03426,    0.00372,    0.00091,
     4    0.00005,    0.00076,    0.00005,    0.00008,    0.00006,
     5    0.00006,    0.00123,    0.00054,    0.00006,   -0.00012,
     6    0.00643,    0.00280,    0.00030,    0.00048,    0.00031,
     7    0.00006,   -0.00005,    0.00007,    0.00107,    0.00046,
     8    0.00005,    0.00053,    0.00023,    0.00008,    0.00169,
     9    0.00146,    0.00047,    0.00007,    0.00017,    0.00032,
     1    0.00028,   -0.00017,   -0.00057,   -0.00057,    0.00018,
     2   -0.00326,   -0.00061,    0.00007,    0.00067,   -0.01188,
     3    0.00017,    0.00067,   -0.00025,   -0.00011,    0.00006,
     4   -0.00155,   -0.00068,   -0.00007/
      end
c===========================================================================
      blockdata tab4
      double precision avc,amc,amc2
      common/hart4/avc(919),amc(919),amc2(919),ip(919),idn(919,8)
      data ip/2,2,2,2,2,2,2,2,3,2,2,2,3,3,2,2,2,2,2,2,2,2,2,3,3,2,2,2,
     22,2,2,2,3,3,2,2,2,2,2,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,4,4,3,3,
     33,2,2,2,3,2,2,2,2,3,2,2,2,2,3,3,2,2,2,3,2,2,2,2,2,2,2,3,2,2,2,
     42,2,2,2,3,2,2,3,2,2,2,2,2,3,3,3,2,2,2,2,4,3,3,3,2,2,2,2,2,3,2,
     52,2,2,2,2,2,2,4,3,3,2,2,2,2,2,3,2,2,2,2,2,2,2,2,2,2,3,3,2,2,2,
     62,2,3,2,2,3,3,2,3,2,2,4,2,4,2,4,3,3,3,2,2,2,2,2,2,2,2,2,3,2,2,
     72,2,3,3,3,2,2,2,2,2,2,3,2,2,2,2,2,2,2,2,2,3,2,2,2,2,2,2,2,3,2,
     82,2,2,2,3,3,2,3,2,3,2,3,2,4,2,2,3,2,2,3,2,2,2,2,3,2,2,2,2,3,3,
     92,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,3,2,2,2,2,2,2,2,2,2,3,3,2,3,
     12,4,2,4,2,2,4,2,3,3,2,2,2,2,2,2,2,2,3,3,2,2,2,2,2,2,2,2,2,2,2,
     22,2,2,2,2,2,3,3,3,2,2,2,2,2,2,2,2,2,3,2,2,4,2,3,2,2,3,3,3,2,2,
     32,2,2,2,2,2,2,2,2,2,2,2,2,2,3,2,2,2,2,3,3,2,2,2,2,2,2,2,2,2,3,
     43,3,3,2,4,2,4,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,3,2,2,2,2,2,
     52,2,2,2,2,3,3,2,2,2,3,2,3,3,2,2,2,2,2,2,2,2,2,2,2,2,3,2,2,2,2,
     62,2,2,3,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,2,3,2,2,3,2,2,2,3,
     72,2,2,3,3,2,2,2,2,2,3,2,2,2,2,2,2,2,4,4,3,3,2,2,2,2,2,2,3,3,2,
     82,2,3,2,2,2,3,2,2,2,2,2,2,3,2,3,2,2,2,4,4,3,3,3,2,2,2,3,2,3,2,
     93,2,2,2,2,3,3,2,2,2,3,2,2,2,3,2,2,2,2,2,3,2,2,2,2,2,2,2,3,2,2,
     13,2,2,2,2,2,2,3,3,3,2,2,2,2,4,3,3,2,2,2,2,2,3,2,2,2,3,2,2,2,3,
     23,2,2,2,2,2,2,2,3,2,2,2,2,2,2,2,2,2,3,3,2,2,2,2,2,2,2,3,3,2,2,
     34,2,4,2,4,3,2,3,3,2,3,2,2,2,2,2,2,2,2,2,3,2,2,2,3,3,3,2,2,2,2,
     42,2,3,2,2,2,2,2,2,2,2,3,2,2,2,2,3,2,2,2,2,2,2,3,2,3,3,2,3,2,4,
     52,2,2,3,2,2,2,2,3,2,2,2,2,2,2,2,2,2,2,2,3,2,2,2,2,2,2,3,3,2,2,
     62,2,2,2,2,2,2,3,3,3,2,2,4,2,4,2,3,3,2,2,2,2,2,2,2,2,2,2,2,2,2,
     72,2,2,2,3,3,2,2,2,2,2,2,2,2,2,3,2,2,4,2,3,2,3,3,3,2,2,2,2,2,2,
     82,2,2,2,2,2,2,3,2,2,2,2,3,3,2,2,2,2,3,3,3,2,2,2,2,2,2,2,2,2,3,
     93,2,2,2,2,2,3,2,2,2,3,2,3,2,2,2,2,2,2,2,2,2,2,2,3,3,3,4,3,4,3,
     13,3,3,3,4,4,3,3,3,3,4,3,3,3,3,3,3,3,4,4,3,3,3,3,3,3,3,3,3,3,3,
     23,4,3,3,3,4,3,3,3,3,3,3,3,3,3,3,4,4,4,3,3,3,3,3,3,3,3,3,3,3,3,
     33,3,3,3,4,4,3,3,3,3,3,3,3,4,4,4,4,4,4,4,4,4,4/
      data ((idn(i,j),j=1,8),i=1,919)/ 1,-7, 4, 2, 0, 0, 0, 0, 1,-6,
     2 0, 5, 0, 0, 0, 0, 1,-6, 2, 3,-1, 0, 0, 0, 1,-6, 2, 3, 0, 0, 0,
     3 0, 1,-6, 4, 1,-1, 0, 0, 0, 1,-6, 4, 1, 0, 0, 0, 0, 1,-6, 5, 1,
     4 0,-1, 0, 0, 1,-6, 6,-1, 0, 0, 0, 0, 1,-5, 0, 3, 0, 0, 0, 0, 1,
     5-5, 0, 4,-1, 0, 0, 0, 1,-5, 0, 4, 0, 0, 0, 0, 1,-5, 1, 2, 0, 1,
     6 0, 0, 1,-5, 2, 1,-1, 0, 0, 0, 1,-5, 2, 1, 0, 0, 0, 0, 1,-5, 2,
     7 2,-1, 0, 0, 0, 1,-5, 2, 2, 0, 0, 0, 0, 1,-5, 3, 2, 0,-1, 0, 0,
     8 1,-5, 4, 0,-1, 0, 0, 0, 1,-5, 4, 0, 0, 0, 0, 0, 1,-5, 5, 0, 0,
     9-1, 0, 0, 1,-5, 6,-2, 0, 0, 0, 0, 1,-4,-1, 3, 0, 1, 0, 0, 1,-4,
     1 0, 1,-2, 0, 0, 0, 1,-4, 0, 2,-1, 0, 0, 0, 1,-4, 0, 2, 0, 0, 0,
     2 0, 1,-4, 0, 3,-1, 0, 0, 0, 1,-4, 0, 3, 0, 0, 0, 0, 1,-4, 1, 1,
     3-1, 1, 0, 0, 1,-4, 1, 1, 0, 1, 0, 0, 1,-4, 1, 2, 0, 0, 0, 0, 1,
     4-4, 1, 3, 0,-1, 0, 0, 1,-4, 2,-1,-2, 0, 0, 0, 1,-4, 2, 0,-1, 0,
     5 0, 0, 1,-4, 2, 0, 0, 0, 0, 0, 1,-4, 2, 1,-2, 0, 0, 0, 1,-4, 2,
     6 1,-1, 0, 0, 0, 1,-4, 2, 1, 0, 0, 0, 0, 1,-4, 2, 3, 0, 0, 0, 0,
     7 1,-4, 3,-1, 0, 1, 0, 0, 1,-4, 3, 0, 0,-1, 0, 0, 1,-4, 3, 0, 0,
     8 0, 0, 0, 1,-4, 3, 1,-1,-1, 0, 0, 1,-4, 3, 1, 0,-1, 0, 0, 1,-4,
     9 4,-1,-1, 0, 0, 0, 1,-4, 4,-1, 0, 0, 0, 0, 1,-4, 4, 1, 0, 0, 0,
     1 0, 1,-4, 4, 1, 1, 0, 0, 0, 1,-4, 5,-1,-1,-1, 0, 0, 1,-4, 5,-1,
     2 0,-1, 0, 0, 1,-3,-2, 2,-2, 0, 0, 0, 1,-3,-2, 4, 0, 0, 0, 0, 1,
     3-3,-1, 2,-1, 1, 0, 0, 1,-3,-1, 2, 0, 1, 0, 0, 1,-3, 0, 0,-3, 0,
     4 0, 0, 1,-3, 0, 0,-2, 0, 0, 0, 1,-3, 0, 0,-1, 0, 0, 0, 1,-3, 0,
     5 0, 0, 0, 0, 0, 1,-3, 0, 1,-2, 0, 0, 0, 1,-3, 0, 1,-1, 0, 0, 0,
     6 1,-3, 0, 1, 0, 0, 0, 0, 1,-3, 0, 2,-2, 0, 0, 0, 1,-3, 0, 2,-1,
     7 0, 0, 0, 1,-3, 0, 2, 0, 0, 0, 0, 1,-3, 0, 3, 0, 0, 0, 0, 1,-3,
     8 0, 4, 0, 0, 0, 0, 1,-3, 1, 0,-1, 1, 0, 0, 1,-3, 1, 0, 0, 1, 0,
     9 0, 1,-3, 1, 1,-1, 0, 0, 0, 1,-3, 1, 1, 0,-1, 0, 0, 1,-3, 1, 1,
     1 0, 0, 0, 0, 1,-3, 1, 2,-1,-1, 0, 0, 1,-3, 1, 2, 0,-1, 0, 0, 1,
     2-3, 2,-2,-2, 0, 0, 0, 1,-3, 2,-1,-1, 0, 0, 0, 1,-3, 2,-1, 0, 0,
     3 0, 0, 1,-3, 2, 0,-2, 0, 0, 0, 1,-3, 2, 0,-1, 0, 0, 0, 1,-3, 2,
     4 0, 0, 0, 0, 0, 1,-3, 2, 1, 0, 0, 0, 0, 1,-3, 2, 2, 0, 0, 0, 0,
     5 1,-3, 2, 2, 1, 0, 0, 0, 1,-3, 3,-1, 0, 0, 0, 0, 1,-3, 3, 0,-1,
     6-1, 0, 0, 1,-3, 3, 0, 0,-1, 0, 0, 1,-3, 4,-2,-1, 0, 0, 0, 1,-3,
     7 4,-2, 0, 0, 0, 0, 1,-3, 4,-1, 0, 0, 0, 0, 1,-3, 4, 0, 0,-2, 0,
     8 0, 1,-3, 4, 0, 0, 0, 0, 0, 1,-3, 4, 0, 1, 0, 0, 0, 1,-3, 5,-2,
     9 0,-1, 0, 0, 1,-3, 5, 0, 0,-1, 0, 0, 1,-2,-2, 1,-3, 0, 0, 0, 1,
     1-2,-2, 1,-2, 0, 0, 0, 1,-2,-2, 2, 0, 0, 0, 0, 1,-2,-2, 3,-1, 0,
     2 0, 0, 1,-2,-2, 3, 0, 0, 0, 0, 1,-2,-1, 0, 0, 1, 0, 0, 1,-2,-1,
     3 1,-1, 1, 0, 0, 1,-2,-1, 1, 0, 1, 0, 0, 1,-2,-1, 2, 0, 0, 0, 0,
     4 1,-2, 0,-1,-3, 0, 0, 0, 1,-2, 0,-1,-2, 0, 0, 0, 1,-2, 0, 0,-2,
     5 0, 0, 0, 1,-2, 0, 0,-1, 0, 0, 0, 1,-2, 0, 0, 0, 0, 0, 0, 1,-2,
     6 0, 0, 0, 1, 0, 0, 1,-2, 0, 1,-2, 0, 0, 0, 1,-2, 0, 1,-1, 0, 0,
     7 0, 1,-2, 0, 1, 0, 0, 0, 0, 1,-2, 0, 1, 0, 0, 0, 0, 1,-2, 0, 2,
     8-1, 0, 0, 0, 1,-2, 0, 2, 0, 0, 0, 0, 1,-2, 0, 2, 1, 0, 0, 0, 1,
     9-2, 0, 3, 0, 0, 0, 0, 1,-2, 0, 3, 1, 0, 0, 0, 1,-2, 1,-1,-1, 1,
     1 0, 0, 1,-2, 1,-1, 0, 1, 0, 0, 1,-2, 1, 0,-1, 0, 0, 0, 1,-2, 1,
     2 0, 0,-1, 0, 0, 1,-2, 1, 0, 0, 0, 0, 0, 1,-2, 1, 1,-1,-1, 0, 0,
     3 1,-2, 1, 1, 0,-1, 0, 0, 1,-2, 1, 1, 0, 1, 0, 0, 1,-2, 1, 1, 1,
     4 1, 0, 0, 1,-2, 2,-1,-2, 0, 0, 0, 1,-2, 2,-1,-1, 0, 0, 0, 1,-2,
     5 2,-1, 0, 0, 0, 0, 1,-2, 2,-1, 0, 0, 0, 0, 1,-2, 2, 0,-1, 0, 0,
     6 0, 1,-2, 2, 0, 0, 0, 0, 0, 1,-2, 2, 1,-1, 0, 0, 0, 1,-2, 2, 1,
     7 0, 0, 0, 0, 1,-2, 2, 1, 1, 0, 0, 0, 1,-2, 3,-1,-1,-1, 0, 0, 1,
     8-2, 3,-1, 0,-1, 0, 0, 1,-2, 3, 0, 0,-1, 0, 0, 1,-2, 3, 1, 0,-1,
     9 0, 0, 1,-2, 3, 1, 1,-1, 0, 0, 1,-2, 4,-1, 0,-2, 0, 0, 1,-2, 4,
     1-1, 0, 0, 0, 0, 1,-2, 4,-1, 1, 0, 0, 0, 1,-2, 5,-1, 0,-1, 0, 0,
     2 1,-1,-3, 2, 0, 1, 0, 0, 1,-1,-2, 0,-3, 0, 0, 0, 1,-1,-2, 0,-2,
     3 0, 0, 0, 1,-1,-2, 0, 0, 2, 0, 0, 1,-1,-2, 1,-1, 0, 0, 0, 1,-1,
     4-2, 1, 0, 0, 0, 0, 1,-1,-2, 2,-1, 0, 0, 0, 1,-1,-2, 2, 0, 0, 0,
     5 0, 1,-1,-1, 0,-1, 1, 0, 0, 1,-1,-1, 0, 0, 1, 0, 0, 1,-1,-1, 1,
     6 0, 0, 0, 0, 1,-1,-1, 1, 0, 1, 0, 0, 1,-1,-1, 2, 0, 1, 0, 0, 1,
     7-1, 0,-2,-2, 0, 0, 0, 1,-1, 0,-1,-2, 0, 0, 0, 1,-1, 0,-1,-1, 0,
     8 0, 0, 1,-1, 0, 0,-3, 0, 0, 0, 1,-1, 0,-1, 0, 0, 0, 0, 1,-1, 0,
     9 0,-2, 0, 0, 0, 1,-1, 0, 0,-1, 0, 0, 0, 1,-1, 0, 0,-1, 0, 0, 0,
     1 1,-1, 0, 0, 0, 0, 0, 0, 1,-1, 0, 0, 0, 0, 0, 0, 1,-1, 0, 0, 1,
     2 0, 0, 0, 1,-1, 0, 0, 1, 0, 0, 0, 1,-1, 0, 1,-1, 0, 0, 0, 1,-1,
     3 0, 1, 0, 0, 0, 0, 1,-1, 0, 1, 1, 0, 0, 0, 1,-1, 0, 2,-1, 0, 0,
     4 0, 1,-1, 0, 2, 0, 0, 0, 0, 1,-1, 0, 2, 1, 0, 0, 0, 1,-1, 0, 2,
     5 2, 0, 0, 0, 1,-1, 1,-1, 0, 0, 0, 0, 1,-1, 1, 0,-1,-1, 0, 0, 1,
     6-1, 1, 0, 0,-1, 0, 0, 1,-1, 1, 0, 0, 1, 0, 0, 1,-1, 1, 0, 1, 1,
     7 0, 0, 1,-1, 1, 1, 0,-1, 0, 0, 1,-1, 1, 1, 0, 0, 0, 0, 1,-1, 1,
     8 2, 0,-1, 0, 0, 1,-1, 2,-2,-1, 0, 0, 0, 1,-1, 2,-2, 0, 0, 0, 0,
     9 1,-1, 2,-1,-1, 0, 0, 0, 1,-1, 2,-1, 0, 0, 0, 0, 1,-1, 2,-1, 1,
     1 0, 0, 0, 1,-1, 2, 0,-1, 0, 0, 0, 1,-1, 2, 0, 0,-2, 0, 0, 1,-1,
     2 2, 0, 0, 0, 0, 0, 1,-1, 2, 0, 1, 0, 0, 0, 1,-1, 2, 0, 2, 0, 0,
     3 0, 1,-1, 3,-2, 0,-1, 0, 0, 1,-1, 3,-1, 0,-1, 0, 0, 1,-1, 3, 0,
     4-1,-1, 0, 0, 1,-1, 3, 0, 0,-1, 0, 0, 1,-1, 3, 0, 1,-1, 0, 0, 1,
     5-1, 4,-2, 0, 0, 0, 0, 1,-1, 4,-2, 1, 0, 0, 0, 1,-1, 4, 0, 0,-2,
     6 0, 0, 1, 0,-3, 1,-1, 1, 0, 0, 1, 0,-3, 1, 0, 1, 0, 0, 1, 0,-2,
     7-1,-2, 0, 0, 0, 1, 0,-2, 0,-1, 0, 0, 0, 1, 0,-2, 1,-2, 0, 0, 0,
     8 1, 0,-2, 1,-1, 0, 0, 0, 1, 0,-2, 1, 0, 0, 0, 0, 1, 0,-1,-1,-1,
     9 1, 0, 0, 1, 0,-1,-1, 0, 1, 0, 0, 1, 0,-1, 0,-1, 0, 0, 0, 1, 0,
     1-1, 0, 0, 0, 0, 0, 1, 0,-1, 0, 0, 1, 0, 0, 1, 0,-1, 1, 0, 1, 0,
     2 0, 1, 0,-1, 1, 1, 1, 0, 0, 1, 0, 0,-1,-2, 0, 0, 0, 1, 0, 0,-1,
     3-1, 0, 0, 0, 1, 0, 0,-1, 0, 0, 0, 0, 1, 0, 0, 0,-2, 0, 0, 0, 1,
     4 0, 0, 0,-1, 0, 0, 0, 1, 0, 0, 0, 0,-1, 0, 0, 1, 0, 0, 0, 0, 0,
     5 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0,
     6 1,-1, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0,
     7 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1, 1, 0, 0, 0, 1, 0, 0, 1, 2,
     8 0, 0, 0, 1, 0, 0, 2, 0, 0, 0, 0, 1, 0, 1,-1, 0,-1, 0, 0, 1, 0,
     9 1,-1, 0, 1, 0, 0, 1, 0, 1, 0, 0,-1, 0, 0, 1, 0, 1, 0, 0, 0, 0,
     1 0, 1, 0, 1, 0, 1, 0, 0, 0, 1, 0, 1, 1, 0,-1, 0, 0, 1, 0, 1, 1,
     2 1,-1, 0, 0, 1, 0, 2,-2, 0, 0, 0, 0, 1, 0, 2,-1,-1, 0, 0, 0, 1,
     3 0, 2,-1, 0, 0, 0, 0, 1, 0, 2,-1, 1, 0, 0, 0, 1, 0, 2,-1, 2, 0,
     4 0, 0, 1, 0, 2, 0, 0, 0, 0, 0, 1, 0, 2, 0, 1, 0, 0, 0, 1, 0, 2,
     5 1, 1, 0, 0, 0, 1, 0, 2, 1, 2, 0, 0, 0, 1, 0, 3,-1, 0,-1, 0, 0,
     6 1, 0, 3,-1, 1,-1, 0, 0, 1, 1,-5, 0, 0, 3, 0, 0, 1, 1,-4, 0, 0,
     7 2, 0, 0, 1, 1,-2, 0, 0, 0, 0,-2, 1, 1,-3, 0,-1, 1, 0, 0, 1, 1,
     8-3, 0, 0, 1, 0, 0, 1, 1,-2, 0, 0, 0,-1, 0, 1, 1,-3, 2, 0, 1, 0,
     9 0, 1, 1,-2, 0,-2, 0, 0, 0, 1, 1,-2, 0,-1, 0, 0, 0, 1, 1,-2, 0,
     1 0, 0, 0, 0, 1, 1,-2, 0, 0, 2, 0, 0, 1, 1,-2, 1,-1, 0, 0, 0, 1,
     2 1,-2, 1, 0, 0, 0, 0, 1, 1,-2, 1, 1, 0, 0, 0, 1, 1,-2, 2,-1, 0,
     3 0, 0, 1, 1,-2, 2, 0, 0, 0, 0, 1, 1,-2, 2, 1, 0, 0, 0, 1, 1,-1,
     4 0,-1,-1, 0, 0, 1, 1,-1, 0, 0,-1, 0, 0, 1, 1,-1, 0, 0, 1, 0, 0,
     5 1, 1,-1, 0, 1, 1, 0, 0, 1, 1, 0,-2,-2, 0, 0, 0, 1, 1, 0,-2,-1,
     6 0, 0, 0, 1, 1, 0,-1,-1, 0, 0, 0, 1, 1, 0,-1, 0, 0, 0, 0, 1, 1,
     7 0, 0,-2, 0, 0, 0, 1, 1, 0,-1, 1, 0, 0, 0, 1, 1, 0, 0,-1, 0, 0,
     8 0, 1, 1, 0, 0,-1, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0,
     9 0, 0, 0, 0, 1, 1, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 1, 0, 0, 0, 1,
     1 1, 0, 0, 1, 0, 0, 0, 1, 1, 0, 0, 2, 0, 0, 0, 1, 1, 0, 1, 0, 0,
     2 0, 0, 1, 1, 0, 1, 1, 0, 0, 0, 1, 1, 0, 2, 1, 0, 0, 0, 1, 1, 0,
     3 2, 2, 0, 0, 0, 1, 1, 1, 0,-1,-1, 0, 0, 1, 1, 1, 0, 0,-1, 0, 0,
     4 1, 1, 1, 0, 0, 1, 0, 0, 1, 1, 1, 0, 1,-1, 0, 0, 1, 1, 2,-2, 0,
     5 0, 0, 0, 1, 1, 2,-2, 1, 0, 0, 0, 1, 1, 2,-1, 0, 0, 0, 0, 1, 1,
     6 2,-1, 1, 0, 0, 0, 1, 1, 2, 0, 0,-2, 0, 0, 1, 1, 2, 0, 0, 0, 0,
     7 0, 1, 1, 2, 0, 1, 0, 0, 0, 1, 1, 2, 0, 2, 0, 0, 0, 1, 1, 2, 0,
     8 3, 0, 0, 0, 1, 1, 3,-2, 0,-1, 0, 0, 1, 1, 3, 0, 0,-1, 0, 0, 1,
     9 1, 3, 0, 1,-1, 0, 0, 1, 1, 4, 0, 0,-2, 0, 0, 1, 2,-4, 1,-1, 0,
     1 0, 0, 1, 2,-4, 1, 0, 2, 0, 0, 1, 2,-3, 0, 0, 0, 0, 0, 1, 2,-3,
     2 1, 0, 1, 0, 0, 1, 2,-3, 1, 1, 1, 0, 0, 1, 2,-2,-1,-2, 0, 0, 0,
     3 1, 2,-2,-1,-1, 0, 0, 0, 1, 2,-2,-1, 0, 0, 0, 0, 1, 2,-2, 0,-1,
     4 0, 0, 0, 1, 2,-2, 0, 0, 0, 0, 0, 1, 2,-2, 0, 1, 0, 0, 0, 1, 2,
     5-2, 1,-1, 0, 0, 0, 1, 2,-2, 1, 0, 0, 0, 0, 1, 2,-2, 1, 1, 0, 0,
     6 0, 1, 2,-2, 1, 2, 0, 0, 0, 1, 2,-1,-1, 0, 1, 0, 0, 1, 2,-1,-1,
     7 1, 1, 0, 0, 1, 2,-1, 0, 0, 0, 0, 0, 1, 2,-1, 0, 1, 0, 0, 0, 1,
     8 2,-1, 1, 0,-1, 0, 0, 1, 2, 0,-2, 0, 0, 0, 0, 1, 2, 0,-1,-1, 0,
     9 0, 0, 1, 2, 0,-1, 0, 0, 0, 0, 1, 2, 0,-1, 0, 0, 0, 0, 1, 2, 0,
     1-1, 1, 0, 0, 0, 1, 2, 0, 0,-1, 0, 0, 0, 1, 2, 0,-1, 2, 0, 0, 0,
     2 1, 2, 0, 0, 0,-1, 0, 0, 1, 2, 0, 0, 0, 0, 0, 0, 1, 2, 0, 0, 1,
     3 0, 0, 0, 1, 2, 0, 0, 2, 0, 0, 0, 1, 2, 0, 1, 0, 0, 0, 0, 1, 2,
     4 0, 1, 1, 0, 0, 0, 1, 2, 0, 1, 2, 0, 0, 0, 1, 2, 0, 1, 3, 0, 0,
     5 0, 1, 2, 1,-1, 0,-1, 0, 0, 1, 2, 1,-1, 1,-1, 0, 0, 1, 2, 2,-1,
     6 0, 0, 0, 0, 1, 2, 2,-1, 1, 0, 0, 0, 1, 2, 2,-1, 2, 0, 0, 0, 1,
     7 3,-4, 0,-1, 0, 0, 0, 1, 3,-4, 0, 0, 2, 0, 0, 1, 3,-4, 2, 0, 0,
     8 0, 0, 1, 3,-4, 2, 1, 0, 0, 0, 1, 3,-3, 0, 0, 1, 0, 0, 1, 3,-3,
     9 0, 1, 1, 0, 0, 1, 3,-2,-2,-1, 0, 0, 0, 1, 3,-2,-1, 0, 0, 0, 0,
     1 1, 3,-2, 0,-1, 0, 0, 0, 1, 3,-2, 0, 0, 0, 0, 0, 1, 3,-2, 0, 1,
     2 0, 0, 0, 1, 3,-2, 0, 2, 0, 0, 0, 1, 3,-2, 1, 0, 0, 0, 0, 1, 3,
     3-2, 1, 1, 0, 0, 0, 1, 3,-2, 2, 0, 0, 0, 0, 1, 3,-1,-2, 0, 1, 0,
     4 0, 1, 3,-1,-1, 0, 0, 0, 0, 1, 3,-1, 0, 0,-1, 0, 0, 1, 3,-1, 0,
     5 0, 1, 0, 0, 1, 3,-1, 0, 1, 1, 0, 0, 1, 3, 0,-2,-1, 0, 0, 0, 1,
     6 3, 0,-2, 0, 0, 0, 0, 1, 3, 0,-2, 1, 0, 0, 0, 1, 3, 0,-1,-1, 0,
     7 0, 0, 1, 3, 0,-1, 0, 0, 0, 0, 1, 3, 0,-1, 1, 0, 0, 0, 1, 3, 0,
     8-1, 2, 0, 0, 0, 1, 3, 0, 0, 0, 0, 0, 0, 1, 3, 0, 0, 0, 0, 0, 0,
     9 1, 3, 0, 0, 1, 0, 0, 0, 1, 3, 0, 0, 1, 0, 0, 0, 1, 3, 0, 0, 2,
     1 0, 0, 0, 1, 3, 0, 0, 3, 0, 0, 0, 1, 3, 1,-2, 0,-1, 0, 0, 1, 3,
     2 1, 0, 0,-1, 0, 0, 1, 3, 1, 0, 1,-1, 0, 0, 1, 3, 2,-2, 0, 0, 0,
     3 0, 1, 3, 2,-2, 1, 0, 0, 0, 1, 4,-5, 1, 0, 1, 0, 0, 1, 4,-4, 1,
     4 0, 0, 0, 0, 1, 4,-4, 1, 1, 0, 0, 0, 1, 4,-3,-1, 0, 1, 0, 0, 1,
     5 4,-3,-1, 1, 1, 0, 0, 1, 4,-3, 1, 0, 1, 0, 0, 1, 4,-3, 1, 1, 1,
     6 0, 0, 1, 4,-2,-1,-1, 0, 0, 0, 1, 4,-2,-1, 0, 0, 0, 0, 1, 4,-2,
     7-1, 1, 0, 0, 0, 1, 4,-2, 0, 0, 0, 0, 0, 1, 4,-2, 0, 1, 0, 0, 0,
     8 1, 4,-2, 1, 0, 0, 0, 0, 1, 4,-2, 1, 1, 0, 0, 0, 1, 4,-2, 1, 2,
     9 0, 0, 0, 1, 4,-1,-1, 0,-1, 0, 0, 1, 4,-1,-1, 0, 1, 0, 0, 1, 4,
     1-1,-1, 1, 1, 0, 0, 1, 4,-1, 0, 0, 0, 0, 0, 1, 4,-1, 0, 1, 0, 0,
     2 0, 1, 4, 0,-3, 0, 0, 0, 0, 1, 4, 0,-3, 1, 0, 0, 0, 1, 4, 0,-2,
     3 0, 0, 0, 0, 1, 4, 0,-2, 1, 0, 0, 0, 1, 4, 0,-1, 0, 0, 0, 0, 1,
     4 4, 0,-1, 1, 0, 0, 0, 1, 4, 0,-1, 2, 0, 0, 0, 1, 4, 0, 0, 0, 0,
     5 0, 0, 1, 4, 0,-1, 3, 0, 0, 0, 1, 4, 0, 0, 1, 0, 0, 0, 1, 4, 0,
     6 0, 2, 0, 0, 0, 1, 4, 0, 1, 2, 0, 0, 0, 1, 4, 1,-1, 0,-1, 0, 0,
     7 1, 4, 1,-1, 1,-1, 0, 0, 1, 4, 2,-3, 0, 0, 0, 0, 1, 5,-5, 0, 0,
     8 1, 0, 0, 1, 5,-4, 0, 0, 0, 0, 0, 1, 5,-4, 0, 1, 0, 0, 0, 1, 5,
     9-4, 2, 0, 0, 0, 0, 1, 5,-3, 0, 0, 1, 0, 0, 1, 5,-3, 0, 1, 1, 0,
     1 0, 1, 5,-2,-2, 0, 0, 0, 0, 1, 5,-2,-2, 1, 0, 0, 0, 1, 5,-2,-1,
     2 0, 0, 0, 0, 1, 5,-2, 0, 0, 0, 0, 0, 1, 5,-2, 0, 1, 0, 0, 0, 1,
     3 5,-2, 0, 2, 0, 0, 0, 1, 5, 0,-4, 0, 0, 0, 0, 1, 5, 0,-2, 0, 0,
     4 0, 0, 1, 5, 0,-2, 1, 0, 0, 0, 1, 5, 0,-2, 2, 0, 0, 0, 1, 5, 0,
     5-1, 0, 0, 0, 0, 1, 5, 0,-1, 1, 0, 0, 0, 1, 5, 0,-1, 2, 0, 0, 0,
     6 1, 6,-4,-1, 0, 0, 0, 0, 1, 6,-4, 1, 0, 0, 0, 0, 1, 6,-4, 1, 1,
     7 0, 0, 0, 1, 6,-3,-1, 0, 1, 0, 0, 1, 6,-2,-3, 0, 0, 0, 0, 1, 6,
     8-2,-1, 0, 0, 0, 0, 1, 6,-2,-1, 1, 0, 0, 0, 1, 6,-2,-1, 2, 0, 0,
     9 0, 1, 6, 0,-3, 0, 0, 0, 0, 1, 6, 0,-3, 1, 0, 0, 0, 1, 7,-4, 0,
     1 0, 0, 0, 0, 1, 7,-2,-2, 0, 0, 0, 0, 1, 7,-2,-2, 1, 0, 0, 0, 2,
     2-6, 2, 4, 0, 0, 0, 0, 2,-6, 4, 2, 0, 0, 0, 0, 2,-6, 6, 0, 0, 0,
     3 0, 0, 2,-5, 0, 5, 0, 0, 0, 0, 2,-5, 2, 2, 0, 0, 0, 0, 2,-5, 2,
     4 3, 0, 0, 0, 0, 2,-5, 3, 3, 0,-1, 0, 0, 2,-5, 4, 0, 0, 0, 0, 0,
     5 2,-5, 4, 1, 0, 0, 0, 0, 2,-5, 5, 1, 0,-1, 0, 0, 2,-5, 6,-1, 0,
     6 0, 0, 0, 2,-4, 0, 3, 0, 0, 0, 0, 2,-4, 0, 4,-1, 0, 0, 0, 2,-4,
     7 0, 4, 0, 0, 0, 0, 2,-4, 1, 2, 0, 1, 0, 0, 2,-4, 2, 1,-1, 0, 0,
     8 0, 2,-4, 2, 1, 0, 0, 0, 0, 2,-4, 2, 2,-1, 0, 0, 0, 2,-4, 2, 2,
     9 0, 0, 0, 0, 2,-4, 3, 0, 0, 1, 0, 0, 2,-4, 3, 1, 0, 0, 0, 0, 2,
     1-4, 3, 2, 0,-1, 0, 0, 2,-4, 4,-1, 0, 0, 0, 0, 2,-4, 4, 0,-1, 0,
     2 0, 0, 2,-4, 4, 0, 0, 0, 0, 0, 2,-4, 5, 0, 0,-1, 0, 0, 2,-4, 6,
     3-2, 0, 0, 0, 0, 2,-3,-2, 5, 0, 0, 0, 0, 2,-3,-1, 3, 0, 1, 0, 0,
     4 2,-3, 0, 1,-2, 0, 0, 0, 2,-3, 0, 1,-1, 0, 0, 0, 2,-3, 0, 1, 0,
     5 0, 0, 0, 2,-3, 0, 2,-1, 0, 0, 0, 2,-3, 0, 2, 0, 0, 0, 0, 2,-3,
     6 0, 3,-1, 0, 0, 0, 2,-3, 0, 3, 0, 0, 0, 0, 2,-3, 1, 1, 0, 1, 0,
     7 0, 2,-3, 1, 2, 0, 0, 0, 0, 2,-3, 1, 3, 0,-1, 0, 0, 2,-3, 2,-1,
     8-2, 0, 0, 0, 2,-3, 2, 0,-1, 0, 0, 0, 2,-3, 2, 0, 0, 0, 0, 0, 2,
     9-3, 2, 1,-1, 0, 0, 0, 2,-3, 2, 1, 0, 0, 0, 0, 2,-3, 3,-1, 0, 1,
     1 0, 0, 2,-3, 3, 0, 0,-1, 0, 0, 2,-3, 3, 0, 0, 0, 0, 0, 2,-3, 3,
     2 1,-1,-1, 0, 0, 2,-3, 3, 1, 0,-1, 0, 0, 2,-3, 4,-2, 0, 0, 0, 0,
     3 2,-3, 4,-1,-1, 0, 0, 0, 2,-3, 4,-1, 0, 0, 0, 0, 2,-3, 4, 1, 0,
     4-2, 0, 0, 2,-3, 5,-1, 0,-1, 0, 0, 2,-3, 6,-3, 0, 0, 0, 0, 2,-2,
     5-2, 2,-2, 0, 0, 0, 2,-2,-2, 3, 0, 0, 0, 0, 2,-2,-2, 4, 0, 0, 0,
     6 0, 2,-2,-1, 1, 0, 1, 0, 0, 2,-2,-1, 2,-1, 1, 0, 0, 2,-2,-1, 2,
     7 0, 1, 0, 0, 2,-2, 0, 0,-2, 0, 0, 0, 2,-2, 0, 0,-1, 0, 0, 0, 2,
     8-2, 0, 0, 0, 0, 0, 0, 2,-2, 0, 1,-2, 0, 0, 0, 2,-2, 0, 1,-1, 0,
     9 0, 0, 2,-2, 0, 1, 0, 0, 0, 0, 2,-2, 0, 1, 0, 1, 0, 0, 2,-2, 0,
     1 2,-1, 0, 0, 0, 2,-2, 0, 2, 0, 0, 0, 0, 2,-2, 0, 3, 0, 0, 0, 0,
     2 2,-2, 1, 0,-1, 1, 0, 0, 2,-2, 1, 0, 0, 0, 0, 0, 2,-2, 1, 0, 0,
     3 1, 0, 0, 2,-2, 1, 1, 0,-1, 0, 0, 2,-2, 1, 1, 0, 0, 0, 0, 2,-2,
     4 1, 2,-1,-1, 0, 0, 2,-2, 1, 2, 0,-1, 0, 0, 2,-2, 2,-2,-2, 0, 0,
     5 0, 2,-2, 2,-1,-1, 0, 0, 0, 2,-2, 2,-1, 0, 0, 0, 0, 2,-2, 2, 0,
     6-2, 0, 0, 0, 2,-2, 2, 0,-1, 0, 0, 0, 2,-2, 2, 0, 0, 0, 0, 0, 2,
     7-2, 2, 1, 0, 0, 0, 0, 2,-2, 2, 2, 0, 0, 0, 0, 2,-2, 2, 2, 1, 0,
     8 0, 0, 2,-2, 3,-2, 0, 1, 0, 0, 2,-2, 3,-1, 0,-1, 0, 0, 2,-2, 3,
     9-1, 0, 0, 0, 0, 2,-2, 3, 0,-1,-1, 0, 0, 2,-2, 3, 0, 0,-1, 0, 0,
     1 2,-2, 4,-2,-1, 0, 0, 0, 2,-2, 4,-2, 0, 0, 0, 0, 2,-2, 4,-1, 0,
     2 0, 0, 0, 2,-2, 4, 0, 0,-2, 0, 0, 2,-2, 4, 0, 0, 0, 0, 0, 2,-2,
     3 4, 0, 1, 0, 0, 0, 2,-2, 5,-2, 0,-1, 0, 0, 2,-1,-3, 3, 0, 1, 0,
     4 0, 2,-1,-2, 1,-2, 0, 0, 0, 2,-1,-2, 1, 0, 2, 0, 0, 2,-1,-2, 2,
     5 0, 0, 0, 0, 2,-1,-2, 3,-1, 0, 0, 0, 2,-1,-2, 3, 0, 0, 0, 0, 2,
     6-1,-1, 0, 0, 1, 0, 0, 2,-1,-1, 1,-1, 1, 0, 0, 2,-1,-1, 1, 0, 1,
     7 0, 0, 2,-1,-1, 2, 0, 0, 0, 0, 2,-1, 0,-1,-3, 0, 0, 0, 2,-1, 0,
     8-1,-2, 0, 0, 0, 2,-1, 0,-1, 0, 2, 0, 0, 2,-1, 0, 0,-2, 0, 0, 0,
     9 2,-1, 0, 0,-1, 0, 0, 0, 2,-1, 0, 0, 0, 0, 0, 0, 2,-1, 0, 0, 0,
     1 1, 0, 0, 2,-1, 0, 1,-2, 0, 0, 0, 2,-1, 0, 1,-1, 0, 0, 0, 2,-1,
     2 0, 1, 0, 0, 0, 0, 2,-1, 0, 1, 0, 0, 0, 0, 2,-1, 0, 2, 0, 0, 0,
     3 0, 2,-1, 0, 2, 1, 0, 0, 0, 2,-1, 0, 3, 0, 0, 0, 0, 2,-1, 0, 3,
     4 1, 0, 0, 0, 2,-1, 1,-1,-1, 1, 0, 0, 2,-1, 1,-1, 0, 1, 0, 0, 2,
     5-1, 1, 0,-1, 0, 0, 0, 2,-1, 1, 0, 0,-1, 0, 0, 2,-1, 1, 0, 0, 0,
     6 0, 0, 2,-1, 1, 1,-1,-1, 0, 0, 2,-1, 1, 1, 0,-1, 0, 0, 2,-1, 2,
     7-2, 0, 0, 0, 0, 2,-1, 2,-1,-2, 0, 0, 0, 2,-1, 2,-1,-1, 0, 0, 0,
     8 2,-1, 2,-1, 0, 0, 0, 0, 2,-1, 2, 0,-1, 0, 0, 0, 2,-1, 2, 0, 0,
     9 0, 0, 0, 2,-1, 2, 1, 0,-2, 0, 0, 2,-1, 2, 1, 0, 0, 0, 0, 2,-1,
     1 2, 1, 1, 0, 0, 0, 2,-1, 2, 1, 2, 0, 0, 0, 2,-1, 3,-2, 0, 0, 0,
     2 0, 2,-1, 3,-1,-1,-1, 0, 0, 2,-1, 3,-1, 0,-1, 0, 0, 2,-1, 3, 0,
     3 0,-1, 0, 0, 2,-1, 3, 1, 0,-1, 0, 0, 2,-1, 4,-1, 0,-2, 0, 0, 2,
     4-1, 4,-1, 0, 0, 0, 0, 2,-1, 4,-1, 1, 0, 0, 0, 2, 0,-3, 0,-2, 1,
     5 0, 0, 2, 0,-3, 2, 0, 1, 0, 0, 2, 0,-2, 0,-3, 0, 0, 0, 2, 0,-2,
     6 0,-2, 0, 0, 0, 2, 0,-2, 0, 0, 2, 0, 0, 2, 0,-2, 1,-1, 0, 0, 0,
     7 2, 0,-2, 1, 0, 0, 0, 0, 2, 0,-2, 2,-1, 0, 0, 0, 2, 0,-2, 2, 0,
     8 0, 0, 0, 2, 0,-1, 0,-1, 1, 0, 0, 2, 0,-1, 0, 0, 1, 0, 0, 2, 0,
     9-1, 1, 0, 0, 0, 0, 2, 0,-1, 2, 0,-1, 0, 0, 2, 0, 0,-2,-2, 0, 0,
     1 0, 2, 0, 0,-1,-1, 0, 0, 0, 2, 0, 0,-1, 0, 0, 0, 0, 2, 0, 0, 0,
     2-2, 0, 0, 0, 2, 0, 0, 0,-1, 0, 0, 0, 2, 0, 0, 0,-1, 0, 0, 0, 2,
     3 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 2, 0, 0, 0, 1, 0,
     4 0, 0, 2, 0, 0, 0, 1, 0, 0, 0, 2, 0, 0, 1,-1, 0, 0, 0, 2, 0, 0,
     5 1, 0,-1, 0, 0, 2, 0, 0, 1, 0, 0, 0, 0, 2, 0, 0, 1, 1, 0, 0, 0,
     6 2, 0, 0, 2,-1, 0, 0, 0, 2, 0, 0, 1, 2, 0, 0, 0, 2, 0, 0, 2, 0,
     7 0, 0, 0, 2, 0, 0, 2, 1, 0, 0, 0, 2, 0, 0, 2, 2, 0, 0, 0, 2, 0,
     8 1,-2, 0, 1, 0, 0, 2, 0, 1,-1, 0, 0, 0, 0, 2, 0, 1, 0,-1,-1, 0,
     9 0, 2, 0, 1, 0, 0,-1, 0, 0, 2, 0, 1, 0, 0, 1, 0, 0, 2, 0, 1, 0,
     1 1, 1, 0, 0, 2, 0, 1, 1, 0,-1, 0, 0, 2, 0, 1, 1, 0, 0, 0, 0, 2,
     2 0, 2,-2,-1, 0, 0, 0, 2, 0, 2,-2, 0, 0, 0, 0, 2, 0, 2,-1,-1, 0,
     3 0, 0, 2, 0, 2,-1, 0, 0, 0, 0, 2, 0, 2,-1, 1, 0, 0, 0, 2, 0, 2,
     4 0,-1, 0, 0, 0, 2, 0, 2, 0, 0,-2, 0, 0, 2, 0, 2, 0, 0, 0, 0, 0,
     5 2, 0, 2, 0, 1, 0, 0, 0, 2, 0, 2, 0, 2, 0, 0, 0, 2, 0, 3,-2, 0,
     6-1, 0, 0, 2, 0, 3,-1, 0,-1, 0, 0, 2, 0, 3, 0, 0,-1, 0, 0, 2, 0,
     7 3, 0, 1,-1, 0, 0, 2, 0, 4,-2, 0, 0, 0, 0, 2, 0, 4,-2, 1, 0, 0,
     8 0, 2, 1,-4, 1, 0, 2, 0, 0, 2, 1,-3, 1,-1, 1, 0, 0, 2, 1,-3, 1,
     9 0, 1, 0, 0, 2, 1,-2,-1,-2, 0, 0, 0, 2, 1,-2, 0,-1, 0, 0, 0, 2,
     1 1,-2, 1,-1, 0, 0, 0, 2, 1,-2, 1, 0, 0, 0, 0, 2, 1,-1,-1, 0, 1,
     2 0, 0, 2, 1,-1, 0, 0, 0, 0, 0, 2, 1,-1, 0, 0, 1, 0, 0, 2, 1,-1,
     3 1, 0,-1, 0, 0, 2, 1,-1, 1, 0, 1, 0, 0, 2, 1,-1, 1, 1, 1, 0, 0,
     4 2, 1, 0,-1,-2, 0, 0, 0, 2, 1, 0,-1,-1, 0, 0, 0, 2, 1, 0,-1, 0,
     5 0, 0, 0, 2, 1, 0, 0,-1, 0, 0, 0, 2, 1, 0, 0, 0,-1, 0, 0, 2, 1,
     6 0, 0, 0, 0, 0, 0, 2, 1, 0, 0, 1, 0, 0, 0, 2, 1, 0, 1,-1, 0, 0,
     7 0, 2, 1, 0, 0, 2, 0, 0, 0, 2, 1, 0, 1, 0, 0, 0, 0, 2, 1, 0, 1,
     8 0, 0, 0, 0, 2, 1, 0, 1, 1, 0, 0, 0, 2, 1, 0, 1, 2, 0, 0, 0, 2,
     9 1, 1,-1, 0,-1, 0, 0, 2, 1, 1, 0, 0,-1, 0, 0, 2, 1, 1, 0, 0, 0,
     1 0, 0, 2, 1, 1, 0, 1, 0, 0, 0, 2, 1, 1, 1, 0,-1, 0, 0, 2, 1, 1,
     2 1, 1,-1, 0, 0, 2, 1, 2,-2, 0, 0, 0, 0, 2, 1, 2,-1,-1, 0, 0, 0,
     3 2, 1, 2,-1, 0, 0, 0, 0, 2, 1, 2,-1, 1, 0, 0, 0, 2, 1, 2,-1, 2,
     4 0, 0, 0, 2, 1, 3,-1, 0,-1, 0, 0, 2, 1, 3,-1, 1,-1, 0, 0, 2, 2,
     5-5, 0, 0, 3, 0, 0, 2, 2,-4, 0, 0, 2, 0, 0, 2, 2,-2, 0, 0, 0,-2,
     6 0, 2, 2,-2, 0, 0, 0, 0,-2, 2, 2,-3, 0,-1, 1, 0, 0, 2, 2,-3, 0,
     7 0, 0, 0, 0, 2, 2,-3, 0, 0, 1, 0, 0, 2, 2,-2, 0, 0, 0,-1, 0, 2,
     8 2,-2, 0, 0, 0, 0,-1, 2, 2,-2, 0,-2, 0, 0, 0, 2, 2,-2, 0,-1, 0,
     9 0, 0, 2, 2,-2, 0, 0, 0, 0, 0, 2, 2,-2, 1, 0, 0, 0, 0, 2, 2,-2,
     1 1, 1, 0, 0, 0, 2, 2,-2, 2, 0, 0, 0, 0, 2, 2,-2, 2, 1, 0, 0, 0,
     2 2, 2,-1, 0,-1,-1, 0, 0, 2, 2,-1, 0, 0,-1, 0, 0, 2, 2,-1, 0, 0,
     3 1, 0, 0, 2, 2,-1, 0, 1, 1, 0, 0, 2, 2,-1, 0, 2, 1, 0, 0, 2, 2,
     4 0,-2,-1, 0, 0, 0, 2, 2, 0,-2, 0, 0, 0, 0, 2, 2, 0,-1,-1, 0, 0,
     5 0, 2, 2, 0,-1, 0, 0, 0, 0, 2, 2, 0,-1, 1, 0, 0, 0, 2, 2, 0, 0,
     6-1, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 2, 2, 0, 0, 0, 0, 0, 0, 2,
     7 2, 0, 0, 1, 0, 0, 0, 2, 2, 0, 0, 1, 0, 0, 0, 2, 2, 0, 0, 2, 0,
     8 0, 0, 2, 2, 0, 1, 0, 0, 0, 0, 2, 2, 0, 1, 1, 0, 0, 0, 2, 2, 1,
     9 0, 0,-1, 0, 0, 2, 2, 1, 0, 1,-1, 0, 0, 2, 2, 1, 0, 2,-1, 0, 0,
     1 2, 2, 2,-2, 0, 0, 0, 0, 2, 2, 2,-2, 1, 0, 0, 0, 2, 2, 2, 0, 0,
     2-2, 0, 0, 2, 2, 2, 0, 0, 0, 0, 0, 2, 2, 2, 0, 1, 0, 0, 0, 2, 2,
     3 2, 0, 2, 0, 0, 0, 2, 2, 3, 0, 0,-1, 0, 0, 2, 3,-4, 1,-1, 0, 0,
     4 0, 2, 3,-4, 1, 0, 0, 0, 0, 2, 3,-3, 0, 0, 0, 0, 0, 2, 3,-3, 1,
     5 0, 1, 0, 0, 2, 3,-3, 1, 1, 1, 0, 0, 2, 3,-2,-1,-1, 0, 0, 0, 2,
     6 3,-2,-1, 0, 0, 0, 0, 2, 3,-2, 0, 0, 0, 0, 0, 2, 3,-2, 0, 1, 0,
     7 0, 0, 2, 3,-2, 1,-1, 0, 0, 0, 2, 3,-2, 1, 0, 0, 0, 0, 2, 3,-2,
     8 1, 1, 0, 0, 0, 2, 3,-2, 1, 2, 0, 0, 0, 2, 3,-1,-1, 0, 1, 0, 0,
     9 2, 3,-1,-1, 1, 1, 0, 0, 2, 3,-1, 0, 0, 0, 0, 0, 2, 3,-1, 0, 1,
     1 0, 0, 0, 2, 3,-1, 1, 0,-1, 0, 0, 2, 3, 0,-2, 0, 0, 0, 0, 2, 3,
     2 0,-1,-1, 0, 0, 0, 2, 3, 0,-1, 0, 0, 0, 0, 2, 3, 0,-1, 0, 0, 0,
     3 0, 2, 3, 0,-1, 1, 0, 0, 0, 2, 3, 0, 0,-1, 0, 0, 0, 2, 3, 0,-1,
     4 2, 0, 0, 0, 2, 3, 0, 0, 0, 0, 0, 0, 2, 3, 0, 0, 1, 0, 0, 0, 2,
     5 3, 0, 0, 2, 0, 0, 0, 2, 3, 0, 1, 0, 0, 0, 0, 2, 3, 0, 1, 1, 0,
     6 0, 0, 2, 3, 0, 1, 2, 0, 0, 0, 2, 3, 0, 1, 3, 0, 0, 0, 2, 3, 1,
     7-1, 0,-1, 0, 0, 2, 3, 1,-1, 1,-1, 0, 0, 2, 3, 2,-1, 0, 0, 0, 0,
     8 2, 3, 2,-1, 1, 0, 0, 0, 2, 4,-4, 0,-1, 0, 0, 0, 2, 4,-4, 2, 0,
     9 0, 0, 0, 2, 4,-4, 2, 1, 0, 0, 0, 2, 4,-3, 0, 0, 1, 0, 0, 2, 4,
     1-3, 0, 1, 1, 0, 0, 2, 4,-2,-1, 0, 0, 0, 0, 2, 4,-2, 0,-1, 0, 0,
     2 0, 2, 4,-2, 0, 0, 0, 0, 0, 2, 4,-2, 0, 1, 0, 0, 0, 2, 4,-2, 0,
     3 2, 0, 0, 0, 2, 4,-2, 1, 0, 0, 0, 0, 2, 4,-2, 1, 1, 0, 0, 0, 2,
     4 4,-1, 0, 0,-1, 0, 0, 2, 4, 0,-2, 0, 0, 0, 0, 2, 4, 0,-2, 1, 0,
     5 0, 0, 2, 4, 0,-2, 2, 0, 0, 0, 2, 4, 0,-1, 0, 0, 0, 0, 2, 4, 0,
     6-1, 1, 0, 0, 0, 2, 4, 0,-1, 2, 0, 0, 0, 2, 4, 0, 0, 0, 0, 0, 0,
     7 2, 4, 0, 0, 1, 0, 0, 0, 2, 4, 0, 0, 2, 0, 0, 0, 2, 4, 0, 0, 3,
     8 0, 0, 0, 2, 5,-4, 1, 0, 0, 0, 0, 2, 5,-4, 1, 1, 0, 0, 0, 2, 5,
     9-3,-1, 0, 1, 0, 0, 2, 5,-2,-1, 0, 0, 0, 0, 2, 5,-2,-1, 1, 0, 0,
     1 0, 2, 5,-2, 0, 0, 0, 0, 0, 2, 5,-2, 0, 1, 0, 0, 0, 2, 5,-2, 1,
     2 0, 0, 0, 0, 2, 5,-2, 1, 1, 0, 0, 0, 2, 5,-2, 1, 2, 0, 0, 0, 2,
     3 5, 0,-3, 0, 0, 0, 0, 2, 5, 0,-3, 1, 0, 0, 0, 2, 5, 0,-2, 0, 0,
     4 0, 0, 2, 5, 0,-1, 0, 0, 0, 0, 2, 5, 0,-1, 1, 0, 0, 0, 2, 5, 0,
     5-1, 2, 0, 0, 0, 2, 5, 0, 0, 0, 0, 0, 0, 2, 5, 0,-1, 3, 0, 0, 0,
     6 2, 5, 0, 0, 1, 0, 0, 0, 2, 6,-4, 0, 0, 0, 0, 0, 2, 6,-2,-2, 0,
     7 0, 0, 0, 2, 6,-2,-2, 1, 0, 0, 0, 2, 6,-2, 0, 0, 0, 0, 0, 2, 6,
     8-2, 0, 1, 0, 0, 0, 2, 6,-2, 0, 2, 0, 0, 0, 2, 6, 0,-2, 0, 0, 0,
     9 0, 2, 6, 0,-2, 1, 0, 0, 0, 2, 6, 0,-2, 2, 0, 0, 0, 2, 7,-2,-1,
     1 0, 0, 0, 0, 2, 7,-2,-1, 1, 0, 0, 0, 3,-4, 0, 4, 0, 0, 0, 0, 3,
     2-4, 2, 2, 0, 0, 0, 0, 3,-4, 4, 0, 0, 0, 0, 0, 3,-3, 0, 2, 0, 0,
     3 0, 0, 3,-3, 0, 3, 0, 0, 0, 0, 3,-3, 2, 0, 0, 0, 0, 0, 3,-3, 2,
     4 1,-1, 0, 0, 0, 3,-3, 2, 1, 0, 0, 0, 0, 3,-3, 3, 1, 0,-1, 0, 0,
     5 3,-3, 4,-1, 0, 0, 0, 0, 3,-2,-1, 2, 0, 1, 0, 0, 3,-2, 0, 1,-1,
     6 0, 0, 0, 3,-2, 0, 1, 0, 0, 0, 0, 3,-2, 0, 2,-1, 0, 0, 0, 3,-2,
     7 0, 2, 0, 0, 0, 0, 3,-2, 1, 0, 0, 1, 0, 0, 3,-2, 1, 2, 0,-1, 0,
     8 0, 3,-2, 2,-1, 0, 0, 0, 0, 3,-2, 2, 0,-1, 0, 0, 0, 3,-2, 2, 0,
     9 0, 0, 0, 0, 3,-2, 3, 0, 0,-1, 0, 0, 3,-2, 4,-2, 0, 0, 0, 0, 3,
     1-1,-2, 3, 0, 0, 0, 0, 3,-1,-1, 1, 0, 1, 0, 0, 3,-1, 0,-1,-2, 0,
     2 0, 0, 3,-1, 0, 0,-1, 0, 0, 0, 3,-1, 0, 0, 0, 0, 0, 0, 3,-1, 0,
     3 1,-1, 0, 0, 0, 3,-1, 0, 1, 0, 0, 0, 0, 3,-1, 1,-1, 0, 1, 0, 0,
     4 3,-1, 1, 0, 0, 0, 0, 0, 3,-1, 1, 1, 0,-1, 0, 0, 3,-1, 2,-1,-1,
     5 0, 0, 0, 3,-1, 2,-1, 0, 0, 0, 0, 3,-1, 2, 1, 0, 0, 0, 0, 3,-1,
     6 3,-1, 0,-1, 0, 0, 3, 0,-2, 0,-2, 0, 0, 0, 3, 0,-2, 2, 0, 0, 0,
     7 0, 3, 0,-1, 0, 0, 1, 0, 0, 3, 0, 0,-1, 0, 0, 0, 0, 3, 0, 0, 0,
     8-2, 0, 0, 0, 3, 0, 0, 0,-1, 0, 0, 0, 3, 0, 0, 0, 0, 0, 0, 0, 3,
     9 0, 0, 1, 0, 0, 0, 0, 3, 0, 0, 2, 0, 0, 0, 0, 3, 0, 0, 2, 1, 0,
     1 0, 0, 3, 0, 1, 0, 0,-1, 0, 0, 3, 0, 2,-2, 0, 0, 0, 0, 3, 0, 2,
     2 0, 0, 0, 0, 0, 3, 1,-3, 1, 0, 1, 0, 0, 3, 1,-2, 1,-1, 0, 0, 0,
     3 3, 1,-2, 1, 0, 0, 0, 0, 3, 1, 0,-1,-1, 0, 0, 0, 3, 1, 0,-1, 0,
     4 0, 0, 0, 3, 1, 0, 0,-1, 0, 0, 0, 3, 1, 0, 0, 0, 0, 0, 0, 3, 1,
     5 0, 0, 1, 0, 0, 0, 3, 1, 0, 1,-1, 0, 0, 0, 3, 1, 0, 1, 0, 0, 0,
     6 0, 3, 1, 0, 1, 1, 0, 0, 0, 3, 1, 0, 1, 2, 0, 0, 0, 3, 1, 2,-1,
     7 0, 0, 0, 0, 3, 1, 2,-1, 1, 0, 0, 0, 3, 2,-2, 0,-1, 0, 0, 0, 3,
     8 2, 0, 0,-1, 0, 0, 0, 3, 2, 0, 0, 0, 0, 0, 0, 3, 2, 0, 0, 1, 0,
     9 0, 0, 3, 2, 0, 0, 2, 0, 0, 0, 3, 3,-3, 0, 0, 0, 0, 0, 3, 3,-2,
     1 1, 0, 0, 0, 0, 3, 3,-2, 1, 1, 0, 0, 0, 3, 3, 0,-1, 0, 0, 0, 0,
     2 3, 3, 0,-1, 1, 0, 0, 0, 3, 3, 0, 0, 0, 0, 0, 0, 3, 3, 0, 0, 1,
     3 0, 0, 0, 3, 4,-2, 0, 0, 0, 0, 0, 3, 4,-2, 0, 1, 0, 0, 0, 3, 4,
     4 0, 0, 0, 0, 0, 0, 3, 4, 0, 0, 1, 0, 0, 0, 3, 4, 0, 0, 2, 0, 0,
     5 0, 3, 5, 0,-1, 0, 0, 0, 0, 3, 5, 0,-1, 1, 0, 0, 0, 4,-2, 0, 2,
     6 0, 0, 0, 0, 4,-2, 2, 0, 0, 0, 0, 0, 4,-1, 0, 1, 0, 0, 0, 0, 4,
     7-1, 2,-1, 0, 0, 0, 0, 4, 0, 0, 0,-1, 0, 0, 0, 4, 0, 0, 0, 0, 0,
     8 0, 0, 4, 1, 0,-1, 0, 0, 0, 0, 4, 1, 0, 1, 0, 0, 0, 0, 4, 2, 0,
     9 0, 0, 0, 0, 0, 4, 2, 0, 0, 1, 0, 0, 0/
      data avc/ 10.82249467, 11.22116207, 11.29180932, 11.29401572,
     2 11.36466297, 11.36686937, 11.40793605, 11.43972303, 11.76089496,
     3 11.76333037, 11.76553678, 11.79732375, 11.83154221, 11.83374861,
     4 11.83618402, 11.83839043, 11.87945711, 11.90903767, 11.91124408,
     5 11.95231076, 11.98409773, 12.26884480, 12.29621504, 12.30306326,
     6 12.30526967, 12.30770508, 12.30991148, 12.33949205, 12.34169846,
     7 12.34633831, 12.35097816, 12.36906869, 12.37591691, 12.37812332,
     8 12.37835232, 12.38055873, 12.38276513, 12.39204876, 12.41455211,
     9 12.41919000, 12.41919196, 12.42162541, 12.42383181, 12.45341238,
     1 12.45561879, 12.46490241, 12.46710882, 12.49447906, 12.49668547,
     2 12.76773609, 12.78143254, 12.81101310, 12.81321951, 12.83838334,
     3 12.84058975, 12.84279615, 12.84500256, 12.84523156, 12.84743797,
     4 12.84964437, 12.84987337, 12.85207978, 12.85428619, 12.85892800,
     5 12.86356982, 12.88386676, 12.88607316, 12.88850661, 12.89071105,
     6 12.89071301, 12.89314646, 12.89535287, 12.91344340, 12.92029162,
     7 12.92249803, 12.92272703, 12.92493343, 12.92713984, 12.93178165,
     8 12.93642347, 12.93862987, 12.96356667, 12.96600011, 12.96820652,
     9 12.99778709, 12.99999349, 13.00463531, 13.00927320, 13.00927712,
     1 13.01148353, 13.04106017, 13.05034380, 13.30990439, 13.31211080,
     2 13.32116543, 13.32360083, 13.32580724, 13.35295240, 13.35538781,
     3 13.35759422, 13.36223407, 13.38275805, 13.38496445, 13.38960627,
     4 13.39181267, 13.39401908, 13.39402104, 13.39424808, 13.39645449,
     5 13.39866089, 13.39866089, 13.40109630, 13.40330271, 13.40550911,
     6 13.40794452, 13.41015093, 13.42824146, 13.43044787, 13.43288131,
     7 13.43508576, 13.43508772, 13.43752117, 13.43972757, 13.43973150,
     8 13.44193790, 13.46710173, 13.46930814, 13.47151455, 13.47151455,
     9 13.47394995, 13.47615636, 13.47859177, 13.48079817, 13.48300458,
     1 13.51037482, 13.51258123, 13.51722304, 13.52186485, 13.52407126,
     2 13.55364790, 13.55365183, 13.55585823, 13.59471851, 13.82911527,
     3 13.85427910, 13.85648551, 13.86090224, 13.86333373, 13.86554013,
     4 13.86797554, 13.87018195, 13.89976251, 13.90196892, 13.90660877,
     5 13.90661074, 13.91125255, 13.92933916, 13.93398097, 13.93618738,
     6 13.93641638, 13.93839379, 13.93862279, 13.94082919, 13.94082919,
     7 13.94303560, 13.94303560, 13.94524201, 13.94524201, 13.94547101,
     8 13.94767741, 13.94988382, 13.95011282, 13.95231923, 13.95452563,
     9 13.95673204, 13.97946243, 13.98189587, 13.98410228, 13.98410620,
     1 13.98631261, 13.98874409, 13.98874605, 13.99338591, 14.01368285,
     2 14.01588925, 14.01832466, 14.02053107, 14.02273747, 14.02296647,
     3 14.02516896, 14.02517288, 14.02737929, 14.02958569, 14.05695593,
     4 14.06159775, 14.06403315, 14.06623956, 14.06844597, 14.09802653,
     5 14.10023294, 14.10730624, 14.37128357, 14.37348998, 14.40086021,
     6 14.40770843, 14.41014384, 14.41235025, 14.41455665, 14.44413722,
     7 14.44634363, 14.44877707, 14.45098348, 14.45098544, 14.45562726,
     8 14.45783366, 14.48299749, 14.48520390, 14.48741031, 14.48763931,
     9 14.48984571, 14.49205016, 14.49205212, 14.49205408, 14.49425853,
     1 14.49448753, 14.49646493, 14.49669393, 14.49669393, 14.49890034,
     2 14.50110675, 14.50133575, 14.52847698, 14.52848091, 14.53311880,
     3 14.53312076, 14.53532717, 14.53776061, 14.53996702, 14.56490577,
     4 14.56734118, 14.56954759, 14.57175399, 14.57396040, 14.57418940,
     5 14.57639581, 14.58103762, 14.58324403, 14.61061426, 14.61282067,
     6 14.83573132, 14.87679800, 14.90755459, 14.91565827, 14.91786468,
     7 14.92132644, 14.92714831, 14.95451855, 14.95672495, 14.95893136,
     8 14.95893528, 14.96136677, 14.96357317, 14.96577958, 14.96600858,
     9 14.96821499, 14.97042139, 14.99779163, 14.99999804, 15.00000196,
     1 15.00220837, 15.02737220, 15.02957861, 15.03422042, 15.03642683,
     2 15.03665583, 15.03863323, 15.03886223, 15.03886223, 15.04106864,
     3 15.04106864, 15.04107256, 15.04327505, 15.04327505, 15.04548145,
     4 15.04571045, 15.04791686, 15.05255867, 15.05476508, 15.07992891,
     5 15.08213532, 15.08213924, 15.08434173, 15.11392229, 15.11612870,
     6 15.11856411, 15.12077051, 15.12320200, 15.12320592, 15.12541233,
     7 15.12761873, 15.12982514, 15.15498897, 15.16427260, 15.16647901,
     8 15.20533928, 15.42824601, 15.43045634, 15.46687924, 15.47152302,
     9 15.47372942, 15.49889325, 15.50109966, 15.50330607, 15.50574147,
     1 15.50794788, 15.51015429, 15.51038329, 15.51258969, 15.51479610,
     2 15.51700251, 15.54437667, 15.54658307, 15.54901652, 15.55122293,
     3 15.55365637, 15.58080153, 15.58323694, 15.58544335, 15.58544335,
     4 15.58764975, 15.58787875, 15.58985616, 15.59008320, 15.59008516,
     5 15.59229157, 15.59449797, 15.59472697, 15.59693338, 15.59913979,
     6 15.60134619, 15.62651002, 15.62871643, 15.66758063, 15.66978703,
     7 15.67199344, 15.97262071, 15.97483104, 15.98411075, 15.98631715,
     8 16.01589772, 16.01810413, 16.04547437, 16.05232259, 16.05475799,
     9 16.05696440, 16.05917081, 16.06137721, 16.06160621, 16.06381262,
     1 16.06624803, 16.08875137, 16.09339123, 16.09803108, 16.09803500,
     2 16.10024141, 16.12761165, 16.12981805, 16.13202446, 16.13225346,
     3 16.13445987, 16.13666627, 16.13887268, 16.13910168, 16.13910168,
     4 16.14130809, 16.14130809, 16.14351449, 16.14572090, 16.17088473,
     5 16.18016836, 16.18237476, 16.21195533, 16.21416174, 16.48741877,
     6 16.52848545, 16.53069186, 16.56027243, 16.56247883, 16.56955605,
     7 16.57176246, 16.59913270, 16.60133911, 16.60354551, 16.60598092,
     8 16.60818733, 16.61062273, 16.61282914, 16.61503555, 16.64240578,
     9 16.64240971, 16.64461611, 16.64704956, 16.64925597, 16.67419276,
     1 16.67639917, 16.67883457, 16.68104098, 16.68347639, 16.68568279,
     2 16.68788920, 16.68811820, 16.69009561, 16.69032461, 16.69253101,
     3 16.69717283, 16.72454306, 16.72674947, 16.75633004, 17.03179348,
     4 17.07286016, 17.07506657, 17.08214379, 17.11393076, 17.11613717,
     5 17.14571381, 17.14792022, 17.15035563, 17.15499744, 17.15720385,
     6 17.15941025, 17.21856746, 17.22785109, 17.23005750, 17.23226391,
     7 17.23249291, 17.23469931, 17.23690572, 17.61723487, 17.62651849,
     8 17.62872490, 17.65830547, 17.69008852, 17.69937215, 17.70157855,
     9 17.70378496, 17.77222580, 17.77443220, 18.17089320, 18.24374685,
     1 18.24595326, 25.79070966, 25.86356331, 25.93641696, 26.26223071,
     2 26.33044255, 26.33508436, 26.37615104, 26.40329620, 26.40793801,
     3 26.44900469, 26.48079167, 26.80196360, 26.80439901, 26.80660542,
     4 26.83839239, 26.87261085, 26.87481725, 26.87725266, 26.87945907,
     5 26.91124604, 26.91588589, 26.92052575, 26.94767091, 26.95010631,
     6 26.95231272, 26.99337940, 27.02516637, 27.27812647, 27.30991344,
     7 27.33728368, 27.33949009, 27.34169649, 27.34413190, 27.34633831,
     8 27.34877372, 27.35098012, 27.38276710, 27.38740695, 27.39204680,
     9 27.41013733, 27.41698555, 27.41919196, 27.42162737, 27.42383377,
     1 27.45562075, 27.46025864, 27.46026060, 27.46269405, 27.46490045,
     2 27.49204561, 27.49448102, 27.49668743, 27.50596713, 27.53775411,
     3 27.56954108, 27.80880473, 27.81785936, 27.82250118, 27.84964634,
     4 27.85208174, 27.85428815, 27.88165839, 27.88386479, 27.88607120,
     5 27.88630020, 27.88850661, 27.89071301, 27.89071498, 27.89314842,
     6 27.89535483, 27.89999664, 27.92493540, 27.92713984, 27.92714180,
     7 27.93177969, 27.93178165, 27.93421510, 27.93642151, 27.95451204,
     8 27.96136026, 27.96356667, 27.96379567, 27.96600207, 27.96820848,
     9 27.97285029, 27.97749211, 27.97969851, 27.99999545, 28.00463335,
     1 28.00463531, 28.00706875, 28.00927516, 28.03885573, 28.04106213,
     2 28.04570395, 28.05034184, 28.05034576, 28.05255217, 28.08212881,
     3 28.32580920, 28.35317944, 28.35759618, 28.36223407, 28.36466947,
     4 28.36687588, 28.39402104, 28.39645645, 28.39866286, 28.40330271,
     5 28.42382669, 28.42603309, 28.43044983, 28.43067491, 28.43288131,
     6 28.43508772, 28.43508968, 28.43531672, 28.43752313, 28.43972953,
     7 28.43972953, 28.44437135, 28.44657775, 28.44901316, 28.45121957,
     8 28.46931010, 28.47151651, 28.47394995, 28.47615440, 28.47615636,
     9 28.47858981, 28.48079621, 28.50794137, 28.50817037, 28.51037678,
     1 28.51258319, 28.51501859, 28.51722500, 28.52186289, 28.52186681,
     2 28.52407322, 28.52627963, 28.54901001, 28.55144346, 28.55364987,
     3 28.55829168, 28.56293349, 28.59471654, 28.59472047, 28.59692687,
     4 28.85648747, 28.87018391, 28.89534774, 28.89755415, 28.90197088,
     5 28.90440237, 28.90660877, 28.90904418, 28.91125059, 28.94083115,
     6 28.94303756, 28.94767741, 28.95231727, 28.97040780, 28.97725602,
     7 28.97946243, 28.97969143, 28.98189783, 28.98189783, 28.98410424,
     8 28.98410424, 28.98631065, 28.98631065, 28.98653965, 28.98874409,
     9 28.98874605, 28.99095246, 28.99118146, 28.99315887, 28.99338787,
     1 28.99559427, 28.99780068, 29.01589121, 29.02053107, 29.02296451,
     2 29.02517092, 29.02517484, 29.02738125, 29.02981273, 29.02981469,
     3 29.05475149, 29.05695789, 29.05939330, 29.06159971, 29.06380611,
     4 29.06403511, 29.06623760, 29.06624152, 29.06844793, 29.07065433,
     5 29.09802457, 29.10266639, 29.10730820, 29.10951461, 29.13909517,
     6 29.14130158, 29.37349194, 29.41235221, 29.41455862, 29.44192885,
     7 29.44877707, 29.45341889, 29.45562529, 29.48741227, 29.49205212,
     8 29.49205408, 29.49669197, 29.49669590, 29.49890230, 29.52406613,
     9 29.52627254, 29.52847895, 29.53091435, 29.53311880, 29.53312076,
     1 29.53532717, 29.53555617, 29.53753357, 29.53776257, 29.53776257,
     2 29.53996898, 29.54217539, 29.56954562, 29.57418744, 29.57418940,
     3 29.57639581, 29.57882925, 29.58103566, 29.60597441, 29.60840982,
     4 29.61061623, 29.61282263, 29.61502904, 29.65168290, 29.65388931,
     5 29.87679996, 29.91786664, 29.92479017, 29.94862323, 29.95672691,
     6 29.95893136, 29.95893332, 29.96239508, 29.97431161, 29.99558719,
     7 29.99779359, 30.00000000, 30.00464181, 30.00684822, 30.00928363,
     8 30.01149003, 30.03886027, 30.04106668, 30.04107060, 30.04327701,
     9 30.04548342, 30.07064725, 30.07285365, 30.07528906, 30.07749547,
     1 30.07970187, 30.07993087, 30.08213728, 30.08213728, 30.08434369,
     2 30.08434369, 30.08655009, 30.08677909, 30.08898550, 30.12320396,
     3 30.12541037, 30.12761677, 30.15499093, 30.15719734, 30.16427064,
     4 30.16427456, 30.16648097, 30.16868737, 30.20534124, 30.46931465,
     5 30.47152105, 30.50794788, 30.51259166, 30.51479806, 30.54216830,
     6 30.54437471, 30.54901652, 30.55122293, 30.55145193, 30.55365833,
     7 30.55586474, 30.55807115, 30.58544531, 30.58765171, 30.59008516,
     8 30.59229157, 30.59472501, 30.62187017, 30.62430558, 30.62651199,
     9 30.62651199, 30.62871839, 30.62894739, 30.63092480, 30.63115380,
     1 30.63336021, 30.63556661, 30.63579561, 30.63800202, 30.64020843,
     2 30.64241483, 30.66757866, 30.66978507, 30.70864927, 30.71085567,
     3 31.01368935, 31.02517939, 31.02738579, 31.05696636, 31.05917277,
     4 31.09339123, 31.09582663, 31.09803304, 31.10023945, 31.10244585,
     5 31.10267485, 31.10488126, 31.13909972, 31.17088669, 31.17309310,
     6 31.17529951, 31.17552851, 31.17773491, 31.17994132, 31.18017032,
     7 31.18237673, 31.18458313, 31.18678954, 31.56955409, 31.57176050,
     8 31.60134107, 31.64240775, 31.64461415, 31.64704956, 31.64925597,
     9 31.65169137, 31.65389778, 31.65610419, 31.71526140, 31.71746781,
     1 31.71990321, 31.72454503, 31.72675143, 31.72895784, 31.72918684,
     2 31.73116425, 31.73139325, 32.11392880, 32.18678245, 32.18898886,
     3 32.19606608, 32.19827249, 32.20047889, 32.26891973, 32.27112614,
     4 32.27333255, 32.74044079, 32.74264719, 41.29865754, 41.37151119,
     5 41.44436484, 41.83839043, 41.84303224, 41.91124408, 41.91367949,
     6 41.91588589, 41.95695257, 41.98873955, 42.34634027, 42.38055873,
     7 42.38276513, 42.38520054, 42.38740695, 42.41919392, 42.42847363,
     8 42.45561879, 42.45805419, 42.46026060, 42.50132728, 42.53311425,
     9 42.85892800, 42.89071498, 42.91808521, 42.92493343, 42.92713984,
     1 42.92957525, 42.93178165, 42.96356863, 42.96820848, 42.97284833,
     2 43.00242890, 43.00463531, 43.01391893, 43.04570199, 43.38960627,
     3 43.40330271, 43.43508968, 43.47151455, 43.47174355, 43.47394995,
     4 43.47615636, 43.48079817, 43.48543999, 43.48764639, 43.51722304,
     5 43.54901001, 43.55829364, 43.90661074, 43.94547101, 43.94767741,
     6 44.01832466, 44.02053107, 44.02296647, 44.02517288, 44.02737929,
     7 44.02760829, 44.02981469, 44.03202110, 44.03422751, 44.10266835,
     8 44.10487475, 44.48984571, 44.57198299, 44.57418940, 44.57639581,
     9 44.57860221, 45.00000000, 45.04571045, 45.04791686, 45.11856411,
     1 45.12077051, 45.12320592, 45.12541233, 45.59008516, 45.59229157,
     2 45.67222244, 45.67442885, 45.67663525, 46.21659715, 46.21880355,
     3 56.87945907, 56.95231272, 57.42383377, 57.49668743, 57.96600207,
     4 57.96820848, 58.51258319, 58.52186681, 59.06624152, 59.06844793/
      data amc/   0.000010,   0.000010,   0.000010,   0.000060,
     2   0.000010,   0.000070,   0.000010,   0.000010,  -0.000010,
     3   0.000020,   0.000110,  -0.000010,  -0.000010,  -0.000030,
     4   0.000080,   0.000460,   0.000030,   0.000050,   0.000280,
     5   0.000030,   0.000010,  -0.000020,   0.000000,  -0.000040,
     6  -0.000100,   0.000200,   0.001070,   0.000000,  -0.000050,
     7  -0.000010,   0.000020,  -0.000010,  -0.000040,  -0.000100,
     8  -0.000010,   0.000520,   0.002780,  -0.000010,  -0.000010,
     9   0.000000,  -0.000010,   0.000030,   0.000210,   0.000100,
     1   0.000530,  -0.000020,   0.000010,   0.000010,   0.000060,
     2  -0.000010,  -0.000030,  -0.000020,  -0.000120,  -0.000010,
     3  -0.000050,   0.000000,   0.000010,  -0.000010,  -0.000220,
     4  -0.000580,  -0.000040,   0.001800,   0.009540,  -0.000010,
     5  -0.000010,  -0.000020,  -0.000160,  -0.000010,   0.000000,
     6  -0.000100,   0.000020,   0.000140,  -0.000010,  -0.000040,
     7  -0.000100,  -0.000060,   0.002170,   0.011520,  -0.000040,
     8  -0.000090,   0.000030,  -0.000020,   0.000140,   0.000770,
     9   0.000060,   0.000350,   0.000000,   0.000030,  -0.000070,
     1   0.000040,   0.000030,  -0.000010,  -0.000010,  -0.000060,
     2   0.000010,  -0.000040,  -0.000230,   0.000010,  -0.000090,
     3  -0.000600,   0.000010,  -0.000050,  -0.000270,  -0.000060,
     4  -0.000830,  -0.002110,   0.000050,  -0.000410,   0.013600,
     5   0.072130,   0.000020,   0.000010,  -0.000130,   0.000010,
     6  -0.000190,  -0.000020,  -0.000020,  -0.000130,  -0.000070,
     7  -0.000010,  -0.000390,   0.000100,   0.000670,   0.000010,
     8   0.000000,  -0.000070,   0.002580,   0.013700,   0.000000,
     9   0.000020,  -0.000180,   0.000020,  -0.000780,   0.000240,
     1   0.000110,   0.000630,  -0.000010,  -0.000050,   0.000000,
     2   0.000020,  -0.000150,   0.000040,  -0.000010,  -0.000040,
     3  -0.000020,  -0.000160,  -0.000010,   0.000010,   0.000020,
     4  -0.000190,  -0.001130,  -0.000150,  -0.001290,   0.000050,
     5   0.000000,   0.000030,   0.000010,   0.000000,   0.000040,
     6   0.000020,   0.000110,  -0.002170,   0.071080,   0.000010,
     7   0.376760,   0.000090,   0.000010,   0.000000,   0.000160,
     8  -0.001080,   0.000140,   0.000070,  -0.002420,  -0.000390,
     9   0.000010,  -0.000010,   0.000110,   0.001140,   0.000050,
     1  -0.000030,   0.000000,   0.000020,  -0.000030,  -0.000040,
     2  -0.000210,   0.000030,  -0.000210,   0.000020,   0.000140,
     3   0.000010,  -0.004910,   0.001070,   0.000070,  -0.000010,
     4   0.000000,   0.000010,  -0.000320,   0.000020,  -0.000090,
     5  -0.000010,  -0.000010,  -0.000020,  -0.000130,   0.000000,
     6   0.000020,   0.000030,  -0.000620,  -0.002780,  -0.000010,
     7  -0.000040,   0.000010,   0.000060,   0.000010,   0.000140,
     8   0.000030,   0.000170,  -0.001970,  -0.010650,  -0.000030,
     9   0.000970,  -0.000010,  -0.006600,  -0.000030,   0.000850,
     1   0.000850,  -0.000010,  -0.029630,  -0.000010,  -0.005940,
     2   0.000160,  -0.000010,   0.000010,   0.000030,  -0.000010,
     3   0.000160,   0.000030,  -0.000180,  -0.000040,  -0.000010,
     4   0.000160,  -0.005660,  -0.001240,   0.000020,  -0.000020,
     5   0.000010,   0.000020,   0.000020,  -0.000240,  -0.000050,
     6   0.000010,   0.000410,   0.000000,  -0.000080,   0.010250,
     7   0.000010,   0.000000,   0.000140,  -0.001970,   0.175300,
     8  -0.000110,   0.000000,  -0.000060,   0.000000,   0.000010,
     9  -0.000260,  -0.000050,   0.000020,  -0.001460,  -0.004140,
     1   0.000100,   0.000010,  -0.000090,   0.000050,  -0.000360,
     2  -0.000060,   0.000040,   0.010490,   0.000010,  -0.529870,
     3  -0.000090,   0.000010,  -0.071880,  -0.000010,   0.001540,
     4  -0.000130,  -0.000050,   0.000010,   0.000010,  -0.000010,
     5  -0.004140,   0.000060,  -0.000070,  -0.000260,  -0.000070,
     6  -0.000020,   0.000000,  -0.000100,  -0.007540,   0.000280,
     7   0.000140,   0.000010,   0.000000,  -0.000430,   0.000010,
     8  -0.000010,  -0.000030,  -0.000010,  -0.000010,  -0.000240,
     9  -0.000040,   0.000020,  -0.000160,   0.000020,  -0.000010,
     1  -0.000070,   0.000000,   0.000180,  -0.005660,  -0.001120,
     2   0.000020,  -0.000180,  -0.000030,   0.000160,   0.000020,
     3   0.000030,  -0.000020,   0.000860,  -0.029630,  -0.000010,
     4  -0.005870,   0.000070,   0.000120,  -0.000020,  -0.002410,
     5  -0.000970,  -0.000080,   0.000450,   0.000280,   0.000170,
     6   0.000020,   0.000150,   0.000020,   0.000110,   0.000090,
     7   0.000030,  -0.000020,  -0.000010,  -0.000090,  -0.000010,
     8  -0.000320,  -0.000060,  -0.000010,  -0.000010,  -0.000150,
     9  -0.004910,  -0.000960,   0.000020,  -0.000070,  -0.000030,
     1   0.000000,  -0.000030,   0.000020,   0.000050,  -0.000040,
     2  -0.000020,   0.000050,  -0.002420,  -0.000480,   0.000010,
     3  -0.000390,  -0.000150,  -0.000010,  -0.016210,  -0.000010,
     4  -0.010380,  -0.000010,  -0.002170,  -0.000140,   0.000020,
     5   0.000050,   0.000020,   0.000040,   0.000020,  -0.000010,
     6  -0.000150,  -0.000020,  -0.000050,  -0.000010,  -0.000030,
     7  -0.000010,  -0.000030,  -0.000770,  -0.000150,  -0.000060,
     8  -0.000020,  -0.000590,  -0.000370,  -0.000070,   0.000010,
     9  -0.000020,  -0.000010,   0.000010,   0.000010,  -0.000190,
     1  -0.000030,  -0.000040,  -0.000010,  -0.003100,  -0.001980,
     2  -0.000410,  -0.000090,  -0.000020,  -0.000070,  -0.000020,
     3   0.000010,   0.000020,   0.000010,   0.000010,  -0.000010,
     4  -0.000070,  -0.000010,  -0.000010,  -0.000030,  -0.000020,
     5  -0.000090,  -0.000010,  -0.000010,  -0.000490,  -0.000310,
     6  -0.000060,  -0.000010,  -0.000410,  -0.000260,  -0.000050,
     7  -0.000020,  -0.000020,   0.000000,  -0.000010,  -0.000020,
     8  -0.000010,   0.000000,  -0.000010,  -0.000120,  -0.000070,
     9  -0.000010,  -0.000040,  -0.000030,  -0.000010,  -0.000020,
     1  -0.000010,   0.000010,   0.000030,   0.000010,   0.000020,
     2  -0.000010,   0.000150,   0.000010,   0.000000,   0.000180,
     3   0.000020,   0.000030,  -0.000030,  -0.000010,   0.000260,
     4  -0.000020,  -0.000010,  -0.000080,  -0.000040,   0.001110,
     5  -0.000010,   0.000000,   0.000090,  -0.000010,  -0.000020,
     6   0.000680,   0.000090,   0.000040,  -0.000010,  -0.000040,
     7  -0.000020,   0.000000,   0.000010,  -0.000040,  -0.000270,
     8  -0.000090,   0.002580,  -0.000120,  -0.000040,   0.000050,
     9  -0.000020,  -0.000040,  -0.000270,  -0.000250,   0.006700,
     1  -0.000020,  -0.000010,  -0.000030,  -0.000010,   0.000500,
     2  -0.000010,  -0.000040,   0.001290,   0.000020,   0.000140,
     3   0.000010,  -0.000020,   0.000000,  -0.000080,   0.000010,
     4   0.000010,  -0.000310,  -0.000130,   0.000010,   0.000030,
     5   0.000010,  -0.000260,  -0.001560,   0.000040,  -0.000850,
     6   0.023000,   0.000010,   0.000010,   0.000000,  -0.000390,
     7  -0.000010,  -0.000240,  -0.000010,   0.000350,  -0.000030,
     8  -0.000050,  -0.000290,   0.000010,  -0.001030,   0.027760,
     9   0.000030,   0.000010,  -0.000010,  -0.000010,  -0.000010,
     1  -0.000060,  -0.000060,   0.001870,  -0.000030,   0.000840,
     2   0.000000,   0.000090,   0.000010,  -0.000020,   0.000070,
     3  -0.000010,  -0.000140,  -0.000010,   0.000030,   0.000010,
     4  -0.000560,   0.000020,   0.000040,  -0.001460,   0.000040,
     5   0.000020,  -0.000660,  -0.000020,   0.000050,  -0.000960,
     6  -0.005690,   0.000140,   0.000090,  -0.006480,   0.173880,
     7   0.000010,   0.000100,   0.000010,   0.000040,   0.000010,
     8   0.000010,  -0.000320,   0.000030,  -0.000020,  -0.000930,
     9  -0.000050,   0.001620,   0.000010,   0.000010,  -0.001230,
     1   0.033020,   0.000000,   0.000140,   0.000020,   0.000160,
     2  -0.000110,  -0.000010,   0.000000,  -0.000050,   0.001520,
     3   0.000010,   0.000010,   0.000050,   0.000030,  -0.000020,
     4  -0.000010,  -0.000110,   0.000010,  -0.000390,  -0.000030,
     5   0.000010,   0.000070,   0.000090,  -0.002720,   0.000070,
     6  -0.003120,   0.000130,  -0.000010,   0.000030,   0.000050,
     7   0.000320,   0.000470,  -0.033880,  -0.000010,   0.908180,
     8   0.000060,   0.000010,  -0.000010,  -0.000050,  -0.000010,
     9   0.000850,   0.000160,  -0.000010,   0.000000,   0.000520,
     1   0.000180,   0.000030,   0.000010,  -0.000030,  -0.000050,
     2   0.002740,  -0.000010,   0.000010,   0.000000,   0.000000,
     3   0.000010,  -0.000510,  -0.000010,   0.000160,   0.000030,
     4  -0.000010,   0.000030,   0.001060,  -0.000510,   0.000170,
     5  -0.000020,   0.000000,   0.000070,  -0.000010,   0.000020,
     6   0.000000,  -0.000010,   0.000010,  -0.000320,   0.000020,
     7   0.000020,   0.000300,  -0.006690,  -0.000100,   0.000150,
     8  -0.000010,   0.000010,  -0.000030,  -0.000010,  -0.000030,
     9   0.000930,  -0.025670,  -0.000310,  -0.000020,   0.005250,
     1   0.000980,  -0.000110,  -0.000030,   0.006420,   0.000000,
     2   0.002830,   0.000400,   0.000030,   0.000000,  -0.000030,
     3  -0.000010,   0.000030,   0.000020,   0.000000,  -0.000020,
     4   0.001220,   0.000590,   0.000060,   0.000050,   0.000020,
     5   0.000030,   0.001000,   0.000010,  -0.000020,   0.000030,
     6   0.000000,   0.024700,   0.000020,   0.000010,  -0.000030,
     7   0.000940,   0.422530,   0.000050,   0.000010,   0.000050,
     8   0.000020,  -0.000010,  -0.003530,   0.000890,  -0.000050,
     9  -0.000010,   0.000040,   0.000010,  -0.000010,   0.000280,
     1   0.000050,  -0.001470,   0.114860,   0.000040,   0.034240,
     2   0.000010,   0.003710,   0.000020,   0.000010,   0.000900,
     3   0.000030,   0.000000,   0.000050,   0.000030,   0.000020,
     4   0.000780,  -0.000040,  -0.000030,   0.000040,   0.000010,
     5   0.000000,  -0.000030,   0.000050,   0.000020,   0.000080,
     6   0.000060,   0.000060,   0.000010,  -0.000020,   0.001220,
     7   0.000530,   0.000050,   0.000040,   0.000010,  -0.000030,
     8  -0.000010,   0.000000,   0.000020,  -0.000120,   0.006420,
     9   0.000000,   0.002790,  -0.000010,   0.000300,   0.000480,
     1   0.000310,   0.000060,  -0.000040,  -0.000040,  -0.000030,
     2  -0.000010,  -0.000030,  -0.000010,  -0.000010,  -0.000010,
     3   0.000010,   0.000020,   0.000000,   0.000070,   0.000030,
     4   0.000000,   0.000020,   0.001060,   0.000450,   0.000040,
     5   0.000010,   0.000010,  -0.000010,   0.000520,   0.000220,
     6   0.000020,   0.000070,   0.000050,   0.000010,   0.001680,
     7   0.001450,   0.000470,   0.000060,   0.000030,   0.000010,
     8   0.000010,   0.000160,   0.000070,   0.000010,   0.000000,
     9   0.000060,   0.000050,   0.000010,   0.000040,   0.000010,
     1   0.000000,   0.000320,   0.000270,   0.000090,   0.000010,
     2   0.000010,   0.000010,   0.000010,   0.000020,   0.000000,
     3   0.000050,   0.000040,   0.000010,   0.000040,   0.000030,
     4   0.000010,   0.000010,   0.000010,  -0.000010,  -0.000030,
     5  -0.000010,   0.000000,  -0.000070,   0.000000,   0.000010,
     6  -0.000170,  -0.000010,  -0.000030,   0.000000,   0.000000,
     7   0.000030,   0.000030,  -0.000560,   0.000000,  -0.000010,
     8   0.000000,   0.000030,  -0.000560,  -0.000030,  -0.000020,
     9   0.000010,   0.000030,   0.000010,   0.000010,   0.000080,
     1   0.000180,  -0.003260,   0.000000,   0.000010,  -0.000030,
     2   0.000030,  -0.000600,   0.000000,  -0.000020,   0.000000,
     3   0.000070,   0.000060,   0.000000,  -0.000010,   0.000660,
     4  -0.011880,  -0.000010,  -0.000030,  -0.000010,  -0.000050,
     5   0.000020,  -0.000040,   0.000000,  -0.000010,   0.000160,
     6  -0.000030,   0.000670,   0.000000,  -0.000070,  -0.000010,
     7   0.000010,  -0.000250,  -0.000110,  -0.000010,  -0.000040,
     8  -0.000020,  -0.000010,   0.000050,  -0.001540,  -0.000670,
     9  -0.000070,  -0.000010,  -0.000010,   0.000000,  -0.000080,
     1  -0.000030,  -0.000010,   0.000000,  -0.000010,   0.000000,
     2  -0.000060,  -0.000050,  -0.000010,  -0.000010,  -0.000010,
     3   0.000010,   0.000010,   0.000050,   0.000010,  -0.000010,
     4   0.000160,  -0.000010,   0.000000,   0.000020,   0.000010/
      data amc2/   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,  -0.000002,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,  -0.000005,  -0.000007,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,  -0.000005,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,  -0.000001,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000001,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000002,   0.000000,  -0.000003,  -0.000003,
     5  -0.000035,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000001,   0.000000,  -0.000001,   0.000000,
     8   0.000000,   0.000000,   0.000000,  -0.000006,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000002,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000003,   0.000020,   0.000000,
     7  -0.000178,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000002,   0.000000,
     9   0.000000,   0.000000,   0.000000,  -0.000002,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000002,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,  -0.000001,   0.000005,   0.000000,
     9  -0.000001,   0.000000,  -0.000005,   0.000000,  -0.000001,
     1   0.000002,   0.000000,   0.000013,   0.000000,  -0.000001,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000003,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,  -0.000030,
     7   0.000000,   0.000000,   0.000000,  -0.000006,  -0.000083,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000005,   0.000015,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,  -0.000008,   0.000000,   0.000224,
     3   0.000000,   0.000000,  -0.000019,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000013,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000011,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000002,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000012,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000002,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000003,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000002,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000026,   0.000000,
     4   0.000012,   0.000000,   0.000001,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000005,   0.000002,
     2   0.000001,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000003,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,  -0.000001,   0.000002,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,  -0.000003,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000003,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000002,   0.000000,   0.000000,  -0.000002,   0.000015,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,  -0.000002,   0.000000,   0.000000,   0.000001,
     1   0.000002,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,  -0.000002,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,  -0.000001,   0.000000,
     6   0.000008,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000020,   0.000000,   0.000086,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,  -0.000001,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2  -0.000007,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9  -0.000001,  -0.000002,   0.000000,   0.000000,  -0.000001,
     1   0.000000,   0.000000,   0.000000,  -0.000008,   0.000000,
     2  -0.000002,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4  -0.000001,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,  -0.000002,   0.000000,   0.000000,   0.000000,
     6   0.000000,  -0.000059,   0.000000,   0.000000,   0.000000,
     7  -0.000004,   0.000040,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000010,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,  -0.000002,  -0.000121,   0.000000,  -0.000021,
     2   0.000000,  -0.000002,   0.000000,   0.000000,  -0.000001,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,  -0.000001,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,  -0.000007,
     9   0.000000,  -0.000003,   0.000000,  -0.000001,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,  -0.000002,
     7  -0.000002,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,  -0.000001,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4  -0.000002,   0.000000,   0.000000,   0.000000,   0.000000,
     5   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     6   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     7   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     8   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     9   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     1   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     2   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     3   0.000000,   0.000000,   0.000000,   0.000000,   0.000000,
     4   0.000000,   0.000000,   0.000000,   0.000000,   0.000000/
      end
